/*========================== begin_copyright_notice ============================

Copyright (C) 2023 Intel Corporation

SPDX-License-Identifier: MIT

============================= end_copyright_notice ===========================*/

//     File Name:  md_metric_sets_ACM_GT2.cpp
//
//     Abstract:   C++ automated generated file that defines Metric Sets
//                 for each Concurrent Group

#include "md_metric_sets_ACM_GT2.h"
#include <algorithm>

#if MD_INCLUDE_ACM_GT2_METRICS

namespace MetricsDiscoveryInternal::MetricSets_ACM_GT2_PipelineStatistics
{
    CPipelineStatsMetricSet::CPipelineStatsMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CPipelineStatsMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "", 0, 0, 0x80000206, 0, 0, "", 0, "Intel_Raw_Pipeline_Statistics_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "IAVertices", "Input vertices",
                          "The total number of vertices that entered the 3D Pipeline.",
                          "3D Pipe/Input Assembler", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_IA * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "vertices", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "IAPrimitives", "Input primitives",
                          "The total number of rendering primitives assembled and put into the input assembly stage of the 3D Pipeline.",
                          "3D Pipe/Input Assembler", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_IA * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsInvocations", "VS per vertex invocations",
                          "The total number of times a vertex shader was invoked. 3D rendering invokes the vertex shader once per vertex.",
                          "3D Pipe/Vertex Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_VS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsInvocations", "HS invocations",
                          "The total number of times a hull shader was invoked.",
                          "3D Pipe/Hull Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_HS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,hull|control,HS|TCS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsInvocations", "DS invocations",
                          "The total number of times a domain shader was invoked.",
                          "3D Pipe/Domain Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_DS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,domain|evaluation,DS|TES", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsInvocations", "GS per triangle invocations",
                          "The total number of times a geometry shader was invoked per triangle.",
                          "3D Pipe/Geometry Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_GS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsPrimitives", "Post-GS primitives",
                          "The total number of primitives that flowed through from GS to the clipper if GS was enabled.",
                          "3D Pipe/Geometry Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_GS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ClipperInvocations", "Clipper invocations",
                          "The total number of primitives sent to the Clipper.",
                          "3D Pipe/Clipper", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CL * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ClipperPrimitives", "Clipper primitives",
                          "The total number of primitives that flowed out of the Clipper.",
                          "3D Pipe/Clipper", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CL * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsInvocations", "PS invocations",
                          "The total number of times a pixel shader was invoked. 3D rendering invokes a pixel shader once per pixel or subsample.",
                          "3D Pipe/Pixel Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_PS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS,pixel|fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsInvocations", "CS invocations",
                          "The total number of times a compute shader was invoked.",
                          "3D Pipe/Compute Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CpsInvocations", "CPS invocations",
                          "The total number of times a coarse shader was invoked.",
                          "3D Pipe/Compute Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
        }

        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
} // namespace MetricsDiscoveryInternal::MetricSets_ACM_GT2_PipelineStatistics

namespace MetricsDiscoveryInternal::MetricSets_ACM_GT2_OA
{
    void AddInformationSet( CConcurrentGroup* concurrentGroup )
    {
        CInformation* information = nullptr;
        information               = concurrentGroup->AddInformation( "QueryBeginTime", "Query Begin Time", "The measurement begin time.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM | API_TYPE_MEDIA, INFORMATION_TYPE_TIMESTAMP, "ns", nullptr, 0 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" );
            information->SetDeltaReportReadEquation( "qw@0x1c0" );
            information->SetOverflowFunction( "NS_TIME" );
        }

        information = concurrentGroup->AddInformation( "CoreFrequencyMHz", "GPU Core Frequency", "The last GPU core (unslice) frequency in the measurement.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM, INFORMATION_TYPE_VALUE, "MHz", nullptr, 1 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 0x1ff AND 16666 UMUL 1000 UDIV" );
            information->SetDeltaReportReadEquation( "qw@0x218 1000000 UDIV" );
        }

        information = concurrentGroup->AddInformation( "XveSliceFrequencyMHz", "XVE Slice Frequency", "The last GPU Vector Engine Unit slice frequency in the measurement.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_VALUE, "MHz", nullptr, 2 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 25 >> dw@0x0 9 >> 0x3 AND OR 16666 UMUL 1000 UDIV" );
        }

        information = concurrentGroup->AddInformation( "ReportReason", "Report Reason", "The reason of the report.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_REPORT_REASON, nullptr, nullptr, 3 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "0x40 dw@0x0 19 >> 0x3f AND 0x0 == UMUL dw@0x0 19 >> 0x3f AND OR" );
        }

        information = concurrentGroup->AddInformation( "ContextIdValid", "Context ID Valid", "When set indicates render context is valid", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_FLAG, nullptr, nullptr, 4 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 16 >> 0x1 AND" );
        }

        information = concurrentGroup->AddInformation( "ContextId", "Context ID", "The context tag in which report has been taken.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_CONTEXT_ID_TAG, nullptr, nullptr, 5 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x08 0xfc7fffbf AND dw@0x0 16 >> 0x1 AND UMUL" );
        }

        information = concurrentGroup->AddInformation( "CoreFrequencyChanged", "GPU Core Frequency Changed", "The flag indicating that GPU core frequency has changed.", "Exception", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 6 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x214" );
        }

        information = concurrentGroup->AddInformation( "QuerySplitOccurred", "Query Split Occurred", "The flag indicating that query has been split during execution on the GPU.", "Exception", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 7 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x210" );
        }

        information = concurrentGroup->AddInformation( "ReportId", "Query report id", "Query report identification number.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_VALUE, nullptr, nullptr, 8 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x220" );
        }

        information = concurrentGroup->AddInformation( "ReportsCount", "Query reports count", "The number of available query reports.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_VALUE, nullptr, nullptr, 9 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x224" );
        }

        information = concurrentGroup->AddInformation( "OverrunOccured", "Query Overrun Occurred", "The flag indicating that Oa buffer has been overran.", "Exception", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 10 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1dc" );
        }

        information = concurrentGroup->AddInformation( "SampleSequence", "Sample sequence", "Number identifying report sequence.", "Report Meta Data", API_TYPE_BBSTREAM, INFORMATION_TYPE_VALUE, nullptr, nullptr, 11 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 0x7f AND" );
        }

        information = concurrentGroup->AddInformation( "SamplePhase", "Sample phase", "Buffer execution phase.", "Report Meta Data", API_TYPE_BBSTREAM, INFORMATION_TYPE_SAMPLE_PHASE, nullptr, nullptr, 12 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 7 >> 0x01 AND" );
        }

        information = concurrentGroup->AddInformation( "GpuNode", "Gpu node", "GPU node buffer was sent to.", "Report Meta Data", API_TYPE_BBSTREAM, INFORMATION_TYPE_GPU_NODE, nullptr, nullptr, 13 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 8 >> 0x07 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryTimer", "Mid Query Timer", "The flag indicating that timer report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 14 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x01 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryProgramming", "Mid Query Programming", "The flag indicating that counter programming report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 15 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x02 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryMarker", "Mid Query Marker", "The flag indicating that query marker report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 16 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x04 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryCtxSwitch", "Mid Query Context Switch", "The flag indicating that context switch report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 17 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x08 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryC6", "Mid Query C6", "The flag indicating that C6 report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 18 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x10 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryFreqChange", "Mid Query Freq Change", "The flag indicating that frequency change report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 19 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x20 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryMmioTrigger", "Mid Query Mmio Trigger", "The flag indicating that mmio trigger report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 20 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x40 AND" );
        }

        information = concurrentGroup->AddInformation( "StreamMarker", "Stream marker", "Stream marker value.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_VALUE, nullptr, nullptr, 21 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x08 dw@0x0 19 >> 0x8 AND 0x0 == UMUL" );
        }

        information = concurrentGroup->AddInformation( "ReportError", "Query report error", "An error in the query execution, the received report should be ignored.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 22 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x13 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportLost", "Query report lost", "Begin or end query report has not been triggered due to hw limitations.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 23 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x01 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportInconsistent", "Query report inconsistent", "The contextId inconsistency in the Oa buffer within the query window.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 24 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x02 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportCtxSwitchLost", "Query report context switch lost", "Oa buffer has not been browsed to find context switch reports to filter out unfamiliar contexts from the query report.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 25 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x08 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportWithoutWorkload", "Query report missing workload", "Missing workload between query begin and query end.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 26 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x10 AND" );
        }
    }

    CRenderBasicMetricSet::CRenderBasicMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderBasicMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsThreads", "VS Threads Dispatched",
                          "The total number of vertex shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x14" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsThreads", "HS Threads Dispatched",
                          "The total number of hull shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", "oa.fixed", 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsThreads", "DS Threads Dispatched",
                          "The total number of domain shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", "oa.fixed", 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x1c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsThreads", "GS Threads Dispatched",
                          "The total number of geometry shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x24:0xa5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsThreads", "PS Threads Dispatched",
                          "The total number of pixel shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", "oa.fixed", 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x28:0xa6" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsThreads", "CS Threads Dispatched",
                          "The total number of compute shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveActive", "XVE Active",
                          "The percentage of time in which the Execution Units were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveStall", "XVE Stall",
                          "The percentage of time in which the Execution Units were stalled.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveThreadOccupancy", "XVE Thread Occupancy",
                          "The percentage of time in which hardware threads occupied XVEs.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuEmActive", "EM And FPU Pipes Active",
                          "The percentage of time in which XVE EM INT and FPU INT64 pipelines were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsFpuActive", "VS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a vertex shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsEmActive", "VS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a vertex shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsSendActive", "VS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a vertex shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsFpuActive", "PS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a pixel shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsEmActive", "PS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a pixel shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsSendActive", "PS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a pixel shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "RasterizedPixels", "Rasterized Pixels",
                          "The total number of rasterized pixels.",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,pixel|fragment", "oa.fixed", 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x64:0xb5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepthTestFails", "Early Hi-Depth Test Fails",
                          "The total number of pixels dropped on early hierarchical depth test.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", "oa.fixed", 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x68:0xb6" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "EarlyDepthTestFails", "Early Depth Test Fails",
                          "The total number of pixels dropped on early depth test.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", "oa.fixed", 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x6c:0xb7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplesKilledInPs", "Samples Killed in PS",
                          "The total number of samples or pixels dropped in pixel shaders.",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", "oa.fixed", 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelsFailingPostPsTests", "Pixels Failing Tests",
                          "The total number of pixels dropped on post-PS alpha, stencil, or depth tests.",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS,pixel|fragment", "oa.fixed", 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x74" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplesWritten", "Samples Written",
                          "The total number of samples or pixels written to all render targets.",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", "oa.fixed", 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplesBlended", "Samples Blended",
                          "The total number of blended samples or pixels written to all render targets.",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", "oa.fixed", 26 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x7c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplerTexels", "Sampler Texels",
                          "The total number of texels seen on input (with 2x2 accuracy) in all sampler units.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "texels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 27 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x80:0xbc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplerTexelMisses", "Sampler Texels Misses",
                          "The total number of texels lookups (with 2x2 accuracy) that missed L1 sampler cache.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_BATCH | USAGE_FLAG_FRAME | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "texels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 28 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x84:0xbd" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SlmReads", "SLM Bytes Read",
                          "The total number of reads from shared local memory.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 29 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x88:0xbe" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x100" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $XeCoreTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SlmWrites", "SLM Writes",
                          "The total number of writes into shared local memory.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 30 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x8c:0xbf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x108" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $XeCoreTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderMemoryAccesses", "Shader Memory Accesses",
                          "The total number of shader memory accesses to L3.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 31 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x110" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderAtomics", "Shader Atomic Memory Accesses",
                          "The total number of shader atomic memory accesses.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 32 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x120" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderBarriers", "Shader Barrier Messages",
                          "The total number of shader barrier messages.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 33 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x9c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x128" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GtiReadThroughput", "GTI Read Throughput",
                          "The total number of GPU memory bytes read from GTI.",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 34 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "128 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks 512 UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GtiWriteThroughput", "GTI Write Throughput",
                          "The total number of GPU memory bytes written to GTI.",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 35 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "128 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks 512 UMUL" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "Sampler20Busy", "Sampler Slice2 Xe Core0 is busy",
                          "The percentage of time when sampler slice2 Xe core0 is busy",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 36 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SamplersBusy", "Samplers Busy",
                          "The percentage of time in which samplers or L1 cache are not idle.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 37 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$Sampler20Busy" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "Sampler20Bottleneck", "Sampler20 Bottleneck",
                          "The percentage of time in which Slice2 Sampler0 has been slowing down the pipe when processing XVE requests.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 38 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SamplerBottleneck", "Samplers Bottleneck",
                          "The percentage of time in which samplers have been slowing down the pipe when processing XVE requests.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_INDICATE | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 39 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$Sampler20Bottleneck" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e842800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02844000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14840037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00003008, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00011010, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x00050012, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00052051, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CComputeBasicMetricSet::CComputeBasicMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CComputeBasicMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsThreads", "CS Threads Dispatched",
                          "The total number of compute shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveActive", "XVE Active",
                          "The percentage of time in which the Execution Units were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveStall", "XVE Stall",
                          "The percentage of time in which the Execution Units were stalled.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "FpuActive", "XVE FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "EmActive", "EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XmxActive", "XMX Pipe Active",
                          "The percentage of time in which XVE XMX pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuEmActive", "EM And FPU Pipes Active",
                          "The percentage of time in which XVE EM INT and FPU INT64 pipelines were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuXmxActive", "XMX And FPU Pipes Active",
                          "The percentage of time in which XVE XMX and FPU INT64 pipelines were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveAvgIpcRate", "XVE AVG IPC Rate",
                          "The average rate of IPC calculated for 2 FPU pipelines.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_RATIO, RESULT_FLOAT, "number", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XveFpuEmActive $FpuActive $EmActive FADD $EmActive FSUB FDIV 1 FADD" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "2" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SendActive", "Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveThreadOccupancy", "XVE Thread Occupancy",
                          "The percentage of time in which hardware threads occupied XVEs.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x4c:0xaf FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x88 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuFlt16", "FPU FLT16 Instruction",
                          "The percentage of time in which FLT16 instruction were processed actively on FPU INT64 pipeline.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuFlt32", "FPU FLT32 Instruction",
                          "The percentage of time in which FLT32 instruction were processed actively on FPU INT64 pipeline.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuFlt64", "FPU FLT64 Instruction",
                          "The percentage of time in which FLT64 instruction were processed actively on FPU INT64 pipeline.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplerTexels", "Sampler Texels",
                          "The total number of texels seen on input (with 2x2 accuracy) in all sampler units.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "texels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x80:0xbc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplerTexelMisses", "Sampler Texels Misses",
                          "The total number of texels lookups (with 2x2 accuracy) that missed L1 sampler cache.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_BATCH | USAGE_FLAG_FRAME | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "texels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x84:0xbd" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SlmReads", "SLM Bytes Read",
                          "The total number of reads from shared local memory.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x88:0xbe" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x100" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $XeCoreTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SlmWrites", "SLM Writes",
                          "The total number of writes into shared local memory.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x8c:0xbf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x108" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $XeCoreTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderMemoryAccesses", "Shader Memory Accesses",
                          "The total number of shader memory accesses to L3.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x110" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderAtomics", "Shader Atomic Memory Accesses",
                          "The total number of shader atomic memory accesses.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x120" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderBarriers", "Shader Barrier Messages",
                          "The total number of shader barrier messages.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x9c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x128" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GtiReadThroughput", "GTI Read Throughput",
                          "The total number of GPU memory bytes read from GTI.",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "128 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks 512 UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GtiWriteThroughput", "GTI Write Throughput",
                          "The total number of GPU memory bytes written to GTI.",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 26 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "128 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks 512 UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00001000, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00003009, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x0000200a, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00006008, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe55c, 0x0000b007, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CAsyncComputeMetricSet::CAsyncComputeMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CAsyncComputeMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsThreads", "VS Threads Dispatched",
                          "The total number of vertex shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x14" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsThreads", "HS Threads Dispatched",
                          "The total number of hull shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", "oa.fixed", 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsThreads", "DS Threads Dispatched",
                          "The total number of domain shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", "oa.fixed", 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x1c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsThreads", "GS Threads Dispatched",
                          "The total number of geometry shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x24:0xa5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsThreads", "PS Threads Dispatched",
                          "The total number of pixel shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", "oa.fixed", 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x28:0xa6" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsThreads", "CS Threads Dispatched",
                          "The total number of compute shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "FpuActive", "XVE FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsFpuActive", "VS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a vertex shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsFpuActive", "PS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a pixel shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsFpuActive", "CS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a compute shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AsyncCsFpuActive", "ASYNC CS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a compute shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "EmActive", "EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsEmActive", "VS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a vertex shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsEmActive", "PS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a pixel shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsEmActive", "CS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a compute shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AsyncCsEmActive", "ASYNC CS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a compute shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveThreadOccupancy", "XVE Thread Occupancy",
                          "The percentage of time in which hardware threads occupied XVEs.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x54:0xb1 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x98 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveActive", "XVE Active",
                          "The percentage of time in which the Execution Units were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveStall", "XVE Stall",
                          "The percentage of time in which the Execution Units were stalled.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x5c:0xb3" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00010000, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00060050, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00001090, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x00051011, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00091061, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe55c, 0x00004008, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe65c, 0x00000005, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CXveActivity1MetricSet::CXveActivity1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CXveActivity1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsThreads", "VS Threads Dispatched",
                          "The total number of vertex shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x14" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsThreads", "HS Threads Dispatched",
                          "The total number of hull shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", "oa.fixed", 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsThreads", "DS Threads Dispatched",
                          "The total number of domain shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", "oa.fixed", 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x1c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsThreads", "GS Threads Dispatched",
                          "The total number of geometry shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x24:0xa5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsThreads", "PS Threads Dispatched",
                          "The total number of pixel shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", "oa.fixed", 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x28:0xa6" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsThreads", "CS Threads Dispatched",
                          "The total number of compute shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsFpuActive", "HS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a hull shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsFpuActive", "DS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a domain shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsFpuActive", "GS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a geometry shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsEmActive", "HS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a hull shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsEmActive", "DS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a domain shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsEmActive", "GS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a geometry shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsSendActive", "HS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a hull shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsSendActive", "DS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a domain shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsSendActive", "GS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a geometry shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsSendActive", "CS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a compute shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00030020, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00021040, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00041031, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x00032022, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00062042, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CGpuBusynessMetricSet::CGpuBusynessMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CGpuBusynessMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveActive", "XVE Active",
                          "The percentage of time in which the Execution Units were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveStall", "XVE Stall",
                          "The percentage of time in which the Execution Units were stalled.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveThreadOccupancy", "XVE Thread Occupancy",
                          "The percentage of time in which hardware threads occupied XVEs.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsThreads", "VS Threads Dispatched",
                          "The total number of vertex shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x14" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsThreads", "HS Threads Dispatched",
                          "The total number of hull shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", "oa.fixed", 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsThreads", "DS Threads Dispatched",
                          "The total number of domain shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", "oa.fixed", 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x1c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsThreads", "GS Threads Dispatched",
                          "The total number of geometry shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x24:0xa5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsThreads", "PS Threads Dispatched",
                          "The total number of pixel shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", "oa.fixed", 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x28:0xa6" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsThreads", "CS Threads Dispatched",
                          "The total number of compute shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "RenderBusy", "Render Ring Busy",
                          "The percentage of time when render command streamer was busy.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ComputeEngine1Busy", "ComputeEngine1 Ring Busy",
                          "The percentage of time when compute command streamer 1 was busy.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ComputeEngine2Busy", "ComputeEngine2 Ring Busy",
                          "The percentage of time when compute command streamer 2 was busy.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "BlitterBusy", "Blitter Ring Busy",
                          "The percentage of time when blitter command streamer was busy.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vdbox00Busy", "Vdbox00 Ring Busy",
                          "The percentage of time when vdbox00 command streamer was busy.",
                          "Media", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vebox0Busy", "Vebox0 Ring Busy",
                          "The percentage of time when vebox0 command streamer was busy.",
                          "Media", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vdbox10Busy", "Vdbox10 Ring Busy",
                          "The percentage of time when vdbox10 command streamer was busy.",
                          "Media", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vebox1Busy", "Vebox1 Ring Busy",
                          "The percentage of time when vebox1 command streamer was busy.",
                          "Media", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AnyComputeEngineBusy", "Any compute engine busy",
                          "The percentage of time when any compute engine is busy",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "RenderAndAnyComputeEngineBusy", "Render and any compute engines are simultaneously busy",
                          "The percentage of time when render and any compute engines are simultaneously busy",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420a2400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a131200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120a0014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00104000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02100002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00124000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00134000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a130024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420a2400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a131200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100a0014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00102400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00120400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00134000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a012400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c042400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24042400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c042400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36040009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40041200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02014500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040426e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060401f7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08041000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a04050c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c04091c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1604000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18040024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02084504, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00056800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803146a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000081, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile1MetricSet::CRenderPipeProfile1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf2Bottleneck", "VF2 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs2Bottleneck", "VS2 Bottleneck",
                          "The percentage of time in which VS2 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl2Bottleneck", "Clipper2 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs2Bottleneck", "HS2 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds2Bottleneck", "DS2 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs2Bottleneck", "GS2 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf2Bottleneck", "SF2 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So2Bottleneck", "SO2 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl2Stall", "CL2 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs2Stall", "HS2 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds2Stall", "DS2 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf2Stall", "SF2 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So2Stall", "SO2 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth20Bottleneck", "Hi-Depth20 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc20Bottleneck", "BC20 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032482, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030c21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile2MetricSet::CRenderPipeProfile2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf3Bottleneck", "VF3 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs3Bottleneck", "VS3 Bottleneck",
                          "The percentage of time in which VS3 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl3Bottleneck", "Clipper3 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs3Bottleneck", "HS3 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds3Bottleneck", "DS3 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs3Bottleneck", "GS3 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf3Bottleneck", "SF3 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So3Bottleneck", "SO3 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl3Stall", "CL3 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs3Stall", "HS3 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds3Stall", "DS3 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf3Stall", "SF3 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So3Stall", "SO3 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth30Bottleneck", "Hi-Depth30 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc30Bottleneck", "BC30 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032482, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030c21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile3MetricSet::CRenderPipeProfile3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf4Bottleneck", "VF4 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs4Bottleneck", "VS4 Bottleneck",
                          "The percentage of time in which VS4 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl4Bottleneck", "Clipper4 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs4Bottleneck", "HS4 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds4Bottleneck", "DS4 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs4Bottleneck", "GS4 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf4Bottleneck", "SF4 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So4Bottleneck", "SO4 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl4Stall", "CL4 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs4Stall", "HS4 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds4Stall", "DS4 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf4Stall", "SF4 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So4Stall", "SO4 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth40Bottleneck", "Hi-Depth40 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc40Bottleneck", "BC40 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a9a94, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x360318ea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030c21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile4MetricSet::CRenderPipeProfile4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf5Bottleneck", "VF5 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs5Bottleneck", "VS5 Bottleneck",
                          "The percentage of time in which VS5 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl5Bottleneck", "Clipper5 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs5Bottleneck", "HS5 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds5Bottleneck", "DS5 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs5Bottleneck", "GS5 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf5Bottleneck", "SF5 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So5Bottleneck", "SO5 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl5Stall", "CL5 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs5Stall", "HS5 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds5Stall", "DS5 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf5Stall", "SF5 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So5Stall", "SO5 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth50Bottleneck", "Hi-Depth50 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc50Bottleneck", "BC50 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031241, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030c21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3_1MetricSet::CL3_1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3_1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank0InputAvailable", "Quad1 L3 Bank0 Input Available",
                          "The percentage of time in which Quad1 L3 bank0 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank1InputAvailable", "Quad1 L3 Bank1 Input Available",
                          "The percentage of time in which Quad1 L3 bank1 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank2InputAvailable", "Quad1 L3 Bank2 Input Available",
                          "The percentage of time in which Quad1 L3 bank2 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank3InputAvailable", "Quad1 L3 Bank3 Input Available",
                          "The percentage of time in which Quad1 L3 bank3 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank4InputAvailable", "Quad1 L3 Bank4 Input Available",
                          "The percentage of time in which Quad1 L3 bank4 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank5InputAvailable", "Quad1 L3 Bank5 Input Available",
                          "The percentage of time in which Quad1 L3 bank5 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank6InputAvailable", "Quad1 L3 Bank6 Input Available",
                          "The percentage of time in which Quad1 L3 bank6 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank7InputAvailable", "Quad1 L3 Bank7 Input Available",
                          "The percentage of time in which Quad1 L3 bank7 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank0OutputReady", "Quad1 L3 Bank0 Output Ready",
                          "The percentage of time in which quad1 L3 bank0 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank1OutputReady", "Quad1 L3 Bank1 Output Ready",
                          "The percentage of time in which quad1 L3 bank1 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank2OutputReady", "Quad1 L3 Bank2 Output Ready",
                          "The percentage of time in which quad1 L3 bank2 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank3OutputReady", "Quad1 L3 Bank3 Output Ready",
                          "The percentage of time in which quad1 L3 bank3 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank4OutputReady", "Quad1 L3 Bank4 Output Ready",
                          "The percentage of time in which quad1 L3 bank4 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank5OutputReady", "Quad1 L3 Bank5 Output Ready",
                          "The percentage of time in which quad1 L3 bank5 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank6OutputReady", "Quad1 L3 Bank6 Output Ready",
                          "The percentage of time in which quad1 L3 bank6 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank7OutputReady", "Quad1 L3 Bank7 Output Ready",
                          "The percentage of time in which quad1 L3 bank7 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3_2MetricSet::CL3_2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3_2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank0InputAvailable", "Quad2 L3 Bank0 Input Available",
                          "The percentage of time in which Quad2 L3 bank0 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank1InputAvailable", "Quad2 L3 Bank1 Input Available",
                          "The percentage of time in which Quad2 L3 bank1 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank2InputAvailable", "Quad2 L3 Bank2 Input Available",
                          "The percentage of time in which Quad2 L3 bank2 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank3InputAvailable", "Quad2 L3 Bank3 Input Available",
                          "The percentage of time in which Quad2 L3 bank3 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank4InputAvailable", "Quad2 L3 Bank4 Input Available",
                          "The percentage of time in which Quad2 L3 bank4 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank5InputAvailable", "Quad2 L3 Bank5 Input Available",
                          "The percentage of time in which Quad2 L3 bank5 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank6InputAvailable", "Quad2 L3 Bank6 Input Available",
                          "The percentage of time in which Quad2 L3 bank6 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank7InputAvailable", "Quad2 L3 Bank7 Input Available",
                          "The percentage of time in which Quad2 L3 bank7 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank0OutputReady", "Quad2 L3 Bank0 Output Ready",
                          "The percentage of time in which quad2 L3 bank0 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank1OutputReady", "Quad2 L3 Bank1 Output Ready",
                          "The percentage of time in which quad2 L3 bank1 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank2OutputReady", "Quad2 L3 Bank2 Output Ready",
                          "The percentage of time in which quad2 L3 bank2 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank3OutputReady", "Quad2 L3 Bank3 Output Ready",
                          "The percentage of time in which quad2 L3 bank3 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank4OutputReady", "Quad2 L3 Bank4 Output Ready",
                          "The percentage of time in which quad2 L3 bank4 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank5OutputReady", "Quad2 L3 Bank5 Output Ready",
                          "The percentage of time in which quad2 L3 bank5 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank6OutputReady", "Quad2 L3 Bank6 Output Ready",
                          "The percentage of time in which quad2 L3 bank6 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank7OutputReady", "Quad2 L3 Bank7 Output Ready",
                          "The percentage of time in which quad2 L3 bank7 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler_1MetricSet::CSampler_1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler_1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "Sampler20InputAvailable", "Slice2 Xe Core0 Input Available",
                          "The percentage of time in which slice2 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "Sampler21InputAvailable", "Slice2 Xe Core1 Input Available",
                          "The percentage of time in which slice2 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "Sampler22InputAvailable", "Slice2 Xe Core2 Input Available",
                          "The percentage of time in which slice2 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "Sampler23InputAvailable", "Slice2 Xe Core3 Input Available",
                          "The percentage of time in which slice2 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "Sampler30InputAvailable", "Slice3 Xe Core0 Input Available",
                          "The percentage of time in which slice3 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "Sampler31InputAvailable", "Slice3 Xe Core1 Input Available",
                          "The percentage of time in which slice3 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "Sampler32InputAvailable", "Slice3 Xe Core2 Input Available",
                          "The percentage of time in which slice3 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "Sampler33InputAvailable", "Slice3 Xe Core3 Input Available",
                          "The percentage of time in which slice3 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "Sampler20OutputReady", "Slice2 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice2 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "Sampler21OutputReady", "Slice2 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice2 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "Sampler22OutputReady", "Slice2 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice2 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "Sampler23OutputReady", "Slice2 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice2 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "Sampler30OutputReady", "Slice3 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice3 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "Sampler31OutputReady", "Slice3 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice3 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "Sampler32OutputReady", "Slice3 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice3 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "Sampler33OutputReady", "Slice3 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice3 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f4f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030863, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x380301e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e17, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0307e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler_2MetricSet::CSampler_2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler_2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "Sampler40InputAvailable", "Slice4 Xe Core0 Input Available",
                          "The percentage of time in which slice4 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "Sampler41InputAvailable", "Slice4 Xe Core1 Input Available",
                          "The percentage of time in which slice4 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "Sampler42InputAvailable", "Slice4 Xe Core2 Input Available",
                          "The percentage of time in which slice4 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "Sampler43InputAvailable", "Slice4 Xe Core3 Input Available",
                          "The percentage of time in which slice4 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "Sampler50InputAvailable", "Slice5 Xe Core0 Input Available",
                          "The percentage of time in which slice5 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "Sampler51InputAvailable", "Slice5 Xe Core1 Input Available",
                          "The percentage of time in which slice5 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "Sampler52InputAvailable", "Slice5 Xe Core2 Input Available",
                          "The percentage of time in which slice5 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "Sampler53InputAvailable", "Slice5 Xe Core3 Input Available",
                          "The percentage of time in which slice5 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "Sampler40OutputReady", "Slice4 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice4 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "Sampler41OutputReady", "Slice4 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice4 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "Sampler42OutputReady", "Slice4 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice4 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "Sampler43OutputReady", "Slice4 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice4 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "Sampler50OutputReady", "Slice5 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice5 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "Sampler51OutputReady", "Slice5 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice5 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "Sampler52OutputReady", "Slice5 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice5 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "Sampler53OutputReady", "Slice5 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice5 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f4f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030863, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x380301e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e17, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0307e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CHDCAndSF1MetricSet::CHDCAndSF1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CHDCAndSF1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "NonSamplerShader20AccessStalledOnL3", "Slice2 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice2 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "NonSamplerShader21AccessStalledOnL3", "Slice2 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice2 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "NonSamplerShader22AccessStalledOnL3", "Slice2 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice2 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "NonSamplerShader23AccessStalledOnL3", "Slice2 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice2 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "NonSamplerShader30AccessStalledOnL3", "Slice3 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice3 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "NonSamplerShader31AccessStalledOnL3", "Slice3 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice3 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "NonSamplerShader32AccessStalledOnL3", "Slice3 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice3 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "NonSamplerShader33AccessStalledOnL3", "Slice3 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice3 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CHDCAndSF2MetricSet::CHDCAndSF2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CHDCAndSF2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly2DataReady", "Polygon (Slice2) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly3DataReady", "Polygon (Slice3) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly4DataReady", "Polygon (Slice4) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly5DataReady", "Polygon (Slice5) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue20Full", "SQ20 is full",
                          "The percentage of time when IDI0 SQ20 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue30Full", "SQ30 is full",
                          "The percentage of time when IDI0 SQ30 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue40Full", "SQ40 is full",
                          "The percentage of time when IDI0 SQ40 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue50Full", "SQ50 is full",
                          "The percentage of time when IDI0 SQ50 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0205001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050501c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c417000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c617000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c817000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca17000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14410180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16610006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204e000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34034e73, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CHDCAndSF3MetricSet::CHDCAndSF3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CHDCAndSF3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "NonSamplerShader40AccessStalledOnL3", "Slice4 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice4 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "NonSamplerShader41AccessStalledOnL3", "Slice4 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice4 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "NonSamplerShader42AccessStalledOnL3", "Slice4 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice4 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "NonSamplerShader43AccessStalledOnL3", "Slice4 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice4 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "NonSamplerShader50AccessStalledOnL3", "Slice5 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice5 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "NonSamplerShader51AccessStalledOnL3", "Slice5 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice5 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "NonSamplerShader52AccessStalledOnL3", "Slice5 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice5 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "NonSamplerShader53AccessStalledOnL3", "Slice5 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice5 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030ee2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0314e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRasterizerAndPixelBackend1MetricSet::CRasterizerAndPixelBackend1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRasterizerAndPixelBackend1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "Rasterizer2InputAvailable", "Slice2 Rasterizer Input Available",
                          "The percentage of time in which slice2 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "Rasterizer3OutputReady", "Slice3 Rasterizer Output Ready",
                          "The percentage of time in which slice3 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "Rasterizer4InputAvailable", "Slice4 Rasterizer Input Available",
                          "The percentage of time in which slice4 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "Rasterizer5OutputReady", "Slice5 Rasterizer Output Ready",
                          "The percentage of time in which slice5 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData20Ready", "Slice2 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice2  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData21Ready", "Slice2 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice2  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData30Ready", "Slice3 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice3  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData31Ready", "Slice3 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice3  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b67d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c77d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000383c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020535d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0405003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a45a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001b3c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b800a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11050dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01068000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308400f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a4005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11050037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01064000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02088aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c66, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x380304e2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001bfc7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02024555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02044555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02054555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02088aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000cfff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRasterizerAndPixelBackend2MetricSet::CRasterizerAndPixelBackend2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRasterizerAndPixelBackend2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "Rasterizer2OutputReady", "Slice2 Rasterizer Output Ready",
                          "The percentage of time in which slice2 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "Rasterizer3InputAvailable", "Slice3 Rasterizer Input Available",
                          "The percentage of time in which slice3 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "Rasterizer4OutputReady", "Slice4 Rasterizer Output Ready",
                          "The percentage of time in which slice4 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "Rasterizer5InputAvailable", "Slice5 Rasterizer Input Available",
                          "The percentage of time in which slice5 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData40Ready", "Slice4 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice4  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData41Ready", "Slice4 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice4  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData50Ready", "Slice5 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice5  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData51Ready", "Slice5 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice5  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00068000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030535d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0505003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b67d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c77d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303f8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a15a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000133f8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031ce4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00018007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02044000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000cfff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRasterizerAndPixelBackend3MetricSet::CRasterizerAndPixelBackend3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRasterizerAndPixelBackend3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput10Available", "PS10 Output Available",
                          "The percentage of time in which PS10 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues10Ready", "Pixel Values 10 Ready",
                          "The percentage of time in which pixel values 10 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput11Available", "PS11 Output Available",
                          "The percentage of time in which PS11 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues11Ready", "Pixel Values 11 Ready",
                          "The percentage of time in which pixel values 11 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput20Available", "PS20 Output Available",
                          "The percentage of time in which PS20 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues20Ready", "Pixel Values 20 Ready",
                          "The percentage of time in which pixel values 20 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput21Available", "PS21 Output Available",
                          "The percentage of time in which PS21 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues21Ready", "Pixel Values 21 Ready",
                          "The percentage of time in which pixel values 21 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180300c9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180800c9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030e70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020400a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080e70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180300c9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180800c9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030e70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080e70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL1MetricSet::CTDL1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "NonPSThread20ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice2 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice2 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "NonPSThread21ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice2 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice2 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "NonPSThread22ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice2 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice2 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "NonPSThread23ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice2 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice2 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "NonPSThread30ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice3 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice3 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "NonPSThread31ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice3 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice3 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "NonPSThread32ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice3 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice3 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "NonPSThread33ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice3 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice3 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ThreadHeader23ReadyPort0", "Thread Header Ready on Slice2 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice2 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ThreadHeader23ReadyPort1", "Thread Header Ready on Slice2 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice2 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ThreadHeader23ReadyPort2", "Thread Header Ready on Slice2 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice2 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ThreadHeader23ReadyPort3", "Thread Header Ready on Slice2 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice2 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ThreadHeader33ReadyPort0", "Thread Header Ready on Slice3 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice3 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ThreadHeader33ReadyPort1", "Thread Header Ready on Slice3 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice3 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ThreadHeader33ReadyPort2", "Thread Header Ready on Slice3 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice3 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ThreadHeader33ReadyPort3", "Thread Header Ready on Slice3 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice3 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL2MetricSet::CTDL2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "PSThread20ReadyForDispatch", "PS Thread Ready For Dispatch on Slice2 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice2 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "PSThread21ReadyForDispatch", "PS Thread Ready For Dispatch on Slice2 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice2 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "PSThread22ReadyForDispatch", "PS Thread Ready For Dispatch on Slice2 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice2 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "PSThread23ReadyForDispatch", "PS Thread Ready For Dispatch on Slice2 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice2 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "PSThread30ReadyForDispatch", "PS Thread Ready For Dispatch on Slice3 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice3 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "PSThread31ReadyForDispatch", "PS Thread Ready For Dispatch on Slice3 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice3 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "PSThread32ReadyForDispatch", "PS Thread Ready For Dispatch on Slice3 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice3 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "PSThread33ReadyForDispatch", "PS Thread Ready For Dispatch on Slice3 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice3 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL3MetricSet::CTDL3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ThreadHeader20Ready", "Thread Header Ready on Slice2 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice2 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ThreadHeader20ReadyPort0", "Thread Header Ready on Slice2 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice2 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ThreadHeader20ReadyPort1", "Thread Header Ready on Slice2 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice2 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ThreadHeader20ReadyPort2", "Thread Header Ready on Slice2 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice2 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ThreadHeader20ReadyPort3", "Thread Header Ready on Slice2 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice2 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ThreadHeader21Ready", "Thread Header Ready on Slice2 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice2 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ThreadHeader21ReadyPort0", "Thread Header Ready on Slice2 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice2 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ThreadHeader21ReadyPort1", "Thread Header Ready on Slice2 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice2 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ThreadHeader21ReadyPort2", "Thread Header Ready on Slice2 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice2 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ThreadHeader21ReadyPort3", "Thread Header Ready on Slice2 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice2 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ThreadHeader22Ready", "Thread Header Ready on Slice2 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice2 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ThreadHeader22ReadyPort0", "Thread Header Ready on Slice2 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice2 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ThreadHeader22ReadyPort1", "Thread Header Ready on Slice2 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice2 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ThreadHeader22ReadyPort2", "Thread Header Ready on Slice2 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice2 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ThreadHeader22ReadyPort3", "Thread Header Ready on Slice2 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice2 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ThreadHeader23Ready", "Thread Header Ready on Slice2 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice2 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL4MetricSet::CTDL4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ThreadHeader30Ready", "Thread Header Ready on Slice3 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice3 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ThreadHeader30ReadyPort0", "Thread Header Ready on Slice3 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice3 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ThreadHeader30ReadyPort1", "Thread Header Ready on Slice3 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice3 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ThreadHeader30ReadyPort2", "Thread Header Ready on Slice3 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice3 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ThreadHeader30ReadyPort3", "Thread Header Ready on Slice3 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice3 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ThreadHeader31Ready", "Thread Header Ready on Slice3 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice3 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ThreadHeader31ReadyPort0", "Thread Header Ready on Slice3 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice3 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ThreadHeader31ReadyPort1", "Thread Header Ready on Slice3 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice3 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ThreadHeader31ReadyPort2", "Thread Header Ready on Slice3 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice3 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ThreadHeader31ReadyPort3", "Thread Header Ready on Slice3 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice3 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ThreadHeader32Ready", "Thread Header Ready on Slice3 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice3 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ThreadHeader32ReadyPort0", "Thread Header Ready on Slice3 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice3 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ThreadHeader32ReadyPort1", "Thread Header Ready on Slice3 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice3 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ThreadHeader32ReadyPort2", "Thread Header Ready on Slice3 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice3 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ThreadHeader32ReadyPort3", "Thread Header Ready on Slice3 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice3 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ThreadHeader33Ready", "Thread Header Ready on Slice3 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice3 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL5MetricSet::CTDL5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "NonPSThread40ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice4 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice4 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "NonPSThread41ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice4 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice4 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "NonPSThread42ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice4 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice4 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "NonPSThread43ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice4 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice4 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "NonPSThread50ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice5 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice5 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "NonPSThread51ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice5 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice5 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "NonPSThread52ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice5 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice5 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "NonPSThread53ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice5 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice5 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ThreadHeader43ReadyPort0", "Thread Header Ready on Slice4 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice4 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ThreadHeader43ReadyPort1", "Thread Header Ready on Slice4 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice4 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ThreadHeader43ReadyPort2", "Thread Header Ready on Slice4 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice4 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ThreadHeader43ReadyPort3", "Thread Header Ready on Slice4 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice4 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ThreadHeader53ReadyPort0", "Thread Header Ready on Slice5 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice5 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ThreadHeader53ReadyPort1", "Thread Header Ready on Slice5 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice5 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ThreadHeader53ReadyPort2", "Thread Header Ready on Slice5 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice5 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ThreadHeader53ReadyPort3", "Thread Header Ready on Slice5 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice5 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL6MetricSet::CTDL6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "PSThread40ReadyForDispatch", "PS Thread Ready For Dispatch on Slice4 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice4 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "PSThread41ReadyForDispatch", "PS Thread Ready For Dispatch on Slice4 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice4 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "PSThread42ReadyForDispatch", "PS Thread Ready For Dispatch on Slice4 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice4 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "PSThread43ReadyForDispatch", "PS Thread Ready For Dispatch on Slice4 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice4 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "PSThread50ReadyForDispatch", "PS Thread Ready For Dispatch on Slice5 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice5 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "PSThread51ReadyForDispatch", "PS Thread Ready For Dispatch on Slice5 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice5 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "PSThread52ReadyForDispatch", "PS Thread Ready For Dispatch on Slice5 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice5 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "PSThread53ReadyForDispatch", "PS Thread Ready For Dispatch on Slice5 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice5 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL7MetricSet::CTDL7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ThreadHeader40Ready", "Thread Header Ready on Slice4 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice4 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ThreadHeader40ReadyPort0", "Thread Header Ready on Slice4 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice4 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ThreadHeader40ReadyPort1", "Thread Header Ready on Slice4 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice4 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ThreadHeader40ReadyPort2", "Thread Header Ready on Slice4 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice4 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ThreadHeader40ReadyPort3", "Thread Header Ready on Slice4 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice4 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ThreadHeader41Ready", "Thread Header Ready on Slice4 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice4 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ThreadHeader41ReadyPort0", "Thread Header Ready on Slice4 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice4 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ThreadHeader41ReadyPort1", "Thread Header Ready on Slice4 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice4 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ThreadHeader41ReadyPort2", "Thread Header Ready on Slice4 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice4 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ThreadHeader41ReadyPort3", "Thread Header Ready on Slice4 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice4 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ThreadHeader42Ready", "Thread Header Ready on Slice4 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice4 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ThreadHeader42ReadyPort0", "Thread Header Ready on Slice4 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice4 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ThreadHeader42ReadyPort1", "Thread Header Ready on Slice4 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice4 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ThreadHeader42ReadyPort2", "Thread Header Ready on Slice4 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice4 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ThreadHeader42ReadyPort3", "Thread Header Ready on Slice4 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice4 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ThreadHeader43Ready", "Thread Header Ready on Slice4 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice4 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL8MetricSet::CTDL8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ThreadHeader50Ready", "Thread Header Ready on Slice5 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice5 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ThreadHeader50ReadyPort0", "Thread Header Ready on Slice5 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice5 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ThreadHeader50ReadyPort1", "Thread Header Ready on Slice5 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice5 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ThreadHeader50ReadyPort2", "Thread Header Ready on Slice5 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice5 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ThreadHeader50ReadyPort3", "Thread Header Ready on Slice5 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice5 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ThreadHeader51Ready", "Thread Header Ready on Slice5 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice5 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ThreadHeader51ReadyPort0", "Thread Header Ready on Slice5 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice5 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ThreadHeader51ReadyPort1", "Thread Header Ready on Slice5 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice5 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ThreadHeader51ReadyPort2", "Thread Header Ready on Slice5 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice5 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ThreadHeader51ReadyPort3", "Thread Header Ready on Slice5 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice5 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ThreadHeader52Ready", "Thread Header Ready on Slice5 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice5 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ThreadHeader52ReadyPort0", "Thread Header Ready on Slice5 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice5 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ThreadHeader52ReadyPort1", "Thread Header Ready on Slice5 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice5 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ThreadHeader52ReadyPort2", "Thread Header Ready on Slice5 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice5 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ThreadHeader52ReadyPort3", "Thread Header Ready on Slice5 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice5 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ThreadHeader53Ready", "Thread Header Ready on Slice5 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice5 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTestOaMetricSet::CTestOaMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTestOaMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter0", "TestCounter0",
                          "HW test counter 0. Factor: 0.0",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter1", "TestCounter1",
                          "HW test counter 1. Factor: 1.0",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter2", "TestCounter2",
                          "HW test counter 2. Factor: 1.0",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter3", "TestCounter3",
                          "HW test counter 3. Factor: 0.5",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter4", "TestCounter4",
                          "HW test counter 4. Factor: 0.3333",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter5", "TestCounter5",
                          "HW test counter 5. Factor: 0.3333",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter6", "TestCounter6",
                          "HW test counter 6. Factor: 0.16666",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter7", "TestCounter7",
                          "HW test counter 7. Factor: 0.6666",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter8", "TestCounter8",
                          "HW test counter 8. Should be equal to 1 in IOStream or in OAG query mode",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter9", "TestCounter9 - OAR enable",
                          "HW test counter 9. Should be equal to 1 in query.",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080ff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000007, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00100002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00100002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00100082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x001000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00100001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ffe7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CAMFS1MetricSet::CAMFS1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CAMFS1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE0", "AMFS CACHE HIT SLICE0",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE0", "AMFS CACHE MISS SLICE0",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE0", "AMFS 4X4 SHADING REQUEST SLICE0",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE0", "AMFS STALL ANY INPUT SLICE0",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE0", "AMFS STALL ALL INPUT SLICE0",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08060248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0602ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00100180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000302, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff9f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x000003c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff87, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ffe7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CAMFS2MetricSet::CAMFS2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CAMFS2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE1", "AMFS CACHE HIT SLICE1",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE1", "AMFS CACHE MISS SLICE1",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE1", "AMFS 4X4 SHADING REQUEST SLICE1",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE1", "AMFS STALL ANY INPUT SLICE1",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE1", "AMFS STALL ALL INPUT SLICE1",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05060e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07060146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09060248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0602ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00100180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000302, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff9f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x000003c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff87, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ffe7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CAMFS3MetricSet::CAMFS3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CAMFS3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE2", "AMFS CACHE HIT SLICE2",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE2", "AMFS CACHE MISS SLICE2",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE2", "AMFS 4X4 SHADING REQUEST SLICE2",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE2", "AMFS STALL ANY INPUT SLICE2",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE2", "AMFS STALL ALL INPUT SLICE2",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08060248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0602ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00100180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000302, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff9f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x000003c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff87, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ffe7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CAMFS4MetricSet::CAMFS4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CAMFS4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE3", "AMFS CACHE HIT SLICE3",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE3", "AMFS CACHE MISS SLICE3",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE3", "AMFS 4X4 SHADING REQUEST SLICE3",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE3", "AMFS STALL ANY INPUT SLICE3",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE3", "AMFS STALL ALL INPUT SLICE3",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05060e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07060146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09060248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0602ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00100180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000302, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff9f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x000003c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff87, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ffe7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CAMFS5MetricSet::CAMFS5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CAMFS5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE0", "AMFS L3 ATOMIC SLICE0",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE1", "AMFS L3 ATOMIC SLICE1",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE2", "AMFS L3 ATOMIC SLICE2",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE3", "AMFS L3 ATOMIC SLICE3",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE0", "AMFS L3 ACCESS SLICE0",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE1", "AMFS L3 ACCESS SLICE1",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE2", "AMFS L3 ACCESS SLICE2",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE3", "AMFS L3 ACCESS SLICE3",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE0", "AMFS L3 WRITE SLICE0",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE1", "AMFS L3 WRITE SLICE1",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE2", "AMFS L3 WRITE SLICE2",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE3", "AMFS L3 WRITE SLICE3",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606018a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706018a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0206001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1406000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02087000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0306001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130603c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606018a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706018a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0206001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1206000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00011008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0306001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110603c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032029, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00010022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00010022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00008042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000eff7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe1MetricSet::CColorPipe1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE0", "RENDER CACHE HIT L3NODE0",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE1", "RENDER CACHE HIT L3NODE1",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE2", "RENDER CACHE HIT L3NODE2",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE0", "RENDER CACHE READ L3NODE0",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE1", "RENDER CACHE READ L3NODE1",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE2", "RENDER CACHE READ L3NODE2",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE0", "RENDER CACHE WRITE L3NODE0",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE1", "RENDER CACHE WRITE L3NODE1",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE2", "RENDER CACHE WRITE L3NODE2",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE0", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE0",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE1", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE1",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE2", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE2",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE0", "RENDER_CACHE_OUTPUT_READY _L3NODE0",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE1", "RENDER_CACHE_OUTPUT_READY _L3NODE1",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE2", "RENDER_CACHE_OUTPUT_READY _L3NODE2",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16087840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0309c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1203002e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040820, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02042082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050410, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051041, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080b80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080820, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16087840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080b80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000828a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a28a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002c30c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020c30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031488, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032291, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603012a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803120a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03120a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403012a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe2MetricSet::CColorPipe2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE3", "RENDER CACHE HIT L3NODE3",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE3", "RENDER CACHE READ L3NODE3",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE3", "RENDER CACHE WRITE L3NODE3",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE3", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE3",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE3", "RENDER_CACHE_OUTPUT_READY _L3NODE3",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030438, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe3MetricSet::CColorPipe3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE0", "COLOR PIPE CACHE LATENCY1 STALL CPIPE0",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE1", "COLOR PIPE CACHE LATENCY1 STALL CPIPE1",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE2", "COLOR PIPE CACHE LATENCY1 STALL CPIPE2",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE3", "COLOR PIPE CACHE LATENCY1 STALL CPIPE3",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE4", "COLOR PIPE CACHE LATENCY1 STALL CPIPE4",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE5", "COLOR PIPE CACHE LATENCY1 STALL CPIPE5",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE6", "COLOR PIPE CACHE LATENCY1 STALL CPIPE6",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE7", "COLOR PIPE CACHE LATENCY1 STALL CPIPE7",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE0", "COLOR PIPE CACHE LATENCY2 STALL L3NODE0",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE1", "COLOR PIPE CACHE LATENCY2 STALL L3NODE1",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE2", "COLOR PIPE CACHE LATENCY2 STALL L3NODE2",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE3", "COLOR PIPE CACHE LATENCY2 STALL L3NODE3",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE0", "PS OUTPUT AVAILABLE CPIPE0",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE1", "PS OUTPUT AVAILABLE CPIPE1",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12021c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13011030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009400c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04011100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00042055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000820aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031291, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030fe9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a031f1f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0325e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032481, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe4MetricSet::CColorPipe4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE0", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE0",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE1", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE1",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe5MetricSet::CColorPipe5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE2", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE2",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE3", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE3",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe6MetricSet::CColorPipe6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE4", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE4",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE5", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE5",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe7MetricSet::CColorPipe7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE6", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE6",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE7", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE7",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe8MetricSet::CColorPipe8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE2", "PS OUTPUT AVAILABLE CPIPE2",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE3", "PS OUTPUT AVAILABLE CPIPE3",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE4", "PS OUTPUT AVAILABLE CPIPE4",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE5", "PS OUTPUT AVAILABLE CPIPE5",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE6", "PS OUTPUT AVAILABLE CPIPE6",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE7", "PS OUTPUT AVAILABLE CPIPE7",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE0", "PIXEL POST PROCESS OUTPUT READY CPIPE0",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE1", "PIXEL POST PROCESS OUTPUT READY CPIPE1",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE2", "PIXEL POST PROCESS OUTPUT READY CPIPE2",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE3", "PIXEL POST PROCESS OUTPUT READY CPIPE3",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003300f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001300f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109100c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05011100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d010880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030481, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x380300e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030607, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032481, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe9MetricSet::CColorPipe9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE4", "PIXEL POST PROCESS OUTPUT READY CPIPE4",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE5", "PIXEL POST PROCESS OUTPUT READY CPIPE5",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE6", "PIXEL POST PROCESS OUTPUT READY CPIPE6",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE7", "PIXEL POST PROCESS OUTPUT READY CPIPE7",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE0", "RENDER CACHE ALLOC L3NODE0",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE1", "RENDER CACHE ALLOC L3NODE1",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE2", "RENDER CACHE ALLOC L3NODE2",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE3", "RENDER CACHE ALLOC L3NODE3",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180301e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180801e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000400a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180301e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180801e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2003f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x380323e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a031f1f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030fe7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe10MetricSet::CColorPipe10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE0", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE0",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe11MetricSet::CColorPipe11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE1", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE1",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe12MetricSet::CColorPipe12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE2", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE2",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe13MetricSet::CColorPipe13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE3", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE3",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe14MetricSet::CColorPipe14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE0", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE0",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe15MetricSet::CColorPipe15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE1", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE1",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe16MetricSet::CColorPipe16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE2", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE2",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CColorPipe17MetricSet::CColorPipe17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CColorPipe17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE3", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE3",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport1MetricSet::CDataport1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE0", "XVE DATAPORT READ MESSAGE COUNT XECORE0",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE1", "XVE DATAPORT READ MESSAGE COUNT XECORE1",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE0", "XVE DATAPORT WRITE MESSAGE COUNT XECORE0",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE1", "XVE DATAPORT WRITE MESSAGE COUNT XECORE1",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE0", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE0",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE1", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE1",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE0", "XVE DATAPORT FENCE MESSAGE COUNT XECORE0",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE1", "XVE DATAPORT FENCE MESSAGE COUNT XECORE1",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1081000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008481c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a320a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008afea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0fe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000febe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f5f7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport2MetricSet::CDataport2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE2", "XVE DATAPORT READ MESSAGE COUNT XECORE2",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE3", "XVE DATAPORT READ MESSAGE COUNT XECORE3",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE2", "XVE DATAPORT WRITE MESSAGE COUNT XECORE2",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE3", "XVE DATAPORT WRITE MESSAGE COUNT XECORE3",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE2", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE2",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE3", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE3",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE2", "XVE DATAPORT FENCE MESSAGE COUNT XECORE2",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE3", "XVE DATAPORT FENCE MESSAGE COUNT XECORE3",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c38002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c481c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c64001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c74001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e320a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e44e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a56a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02079056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000281c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c4001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000febe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f5f7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport3MetricSet::CDataport3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE4", "XVE DATAPORT READ MESSAGE COUNT XECORE4",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE5", "XVE DATAPORT READ MESSAGE COUNT XECORE5",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE4", "XVE DATAPORT WRITE MESSAGE COUNT XECORE4",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE5", "XVE DATAPORT WRITE MESSAGE COUNT XECORE5",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE4", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE4",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE5", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE5",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE4", "XVE DATAPORT FENCE MESSAGE COUNT XECORE4",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE5", "XVE DATAPORT FENCE MESSAGE COUNT XECORE5",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1181000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03838002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018481c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03864001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03874001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a320a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a44e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108afea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308b0fe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000febe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f5f7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport4MetricSet::CDataport4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE6", "XVE DATAPORT READ MESSAGE COUNT XECORE6",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE7", "XVE DATAPORT READ MESSAGE COUNT XECORE7",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE6", "XVE DATAPORT WRITE MESSAGE COUNT XECORE6",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE7", "XVE DATAPORT WRITE MESSAGE COUNT XECORE7",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE6", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE6",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE7", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE7",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE6", "XVE DATAPORT FENCE MESSAGE COUNT XECORE6",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE7", "XVE DATAPORT FENCE MESSAGE COUNT XECORE7",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c38002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c481c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c64001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c74001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e320a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e44e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e61054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e71054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a56a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03079056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010281c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c4001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000febe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f5f7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport5MetricSet::CDataport5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE8", "XVE DATAPORT READ MESSAGE COUNT XECORE8",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE9", "XVE DATAPORT READ MESSAGE COUNT XECORE9",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE8", "XVE DATAPORT WRITE MESSAGE COUNT XECORE8",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE9", "XVE DATAPORT WRITE MESSAGE COUNT XECORE9",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE8", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE8",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE9", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE9",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE8", "XVE DATAPORT FENCE MESSAGE COUNT XECORE8",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE9", "XVE DATAPORT FENCE MESSAGE COUNT XECORE9",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1081000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008481c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a320a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008afea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0fe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000febe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f5f7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport6MetricSet::CDataport6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE10", "XVE DATAPORT READ MESSAGE COUNT XECORE10",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE11", "XVE DATAPORT READ MESSAGE COUNT XECORE11",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE10", "XVE DATAPORT WRITE MESSAGE COUNT XECORE10",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE11", "XVE DATAPORT WRITE MESSAGE COUNT XECORE11",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE10", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE10",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE11", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE11",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE10", "XVE DATAPORT FENCE MESSAGE COUNT XECORE10",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE11", "XVE DATAPORT FENCE MESSAGE COUNT XECORE11",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c38002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c481c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c64001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c74001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e320a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e44e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a56a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02079056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000281c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c4001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000febe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f5f7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport7MetricSet::CDataport7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE12", "XVE DATAPORT READ MESSAGE COUNT XECORE12",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE13", "XVE DATAPORT READ MESSAGE COUNT XECORE13",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE12", "XVE DATAPORT WRITE MESSAGE COUNT XECORE12",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE13", "XVE DATAPORT WRITE MESSAGE COUNT XECORE13",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE12", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE12",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE13", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE13",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE12", "XVE DATAPORT FENCE MESSAGE COUNT XECORE12",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE13", "XVE DATAPORT FENCE MESSAGE COUNT XECORE13",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1181000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03838002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018481c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03864001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03874001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a320a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a44e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108afea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308b0fe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000febe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f5f7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport8MetricSet::CDataport8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE14", "XVE DATAPORT READ MESSAGE COUNT XECORE14",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE15", "XVE DATAPORT READ MESSAGE COUNT XECORE15",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE14", "XVE DATAPORT WRITE MESSAGE COUNT XECORE14",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE15", "XVE DATAPORT WRITE MESSAGE COUNT XECORE15",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE14", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE14",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE15", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE15",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE14", "XVE DATAPORT FENCE MESSAGE COUNT XECORE14",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE15", "XVE DATAPORT FENCE MESSAGE COUNT XECORE15",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c38002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c481c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c64001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c74001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10676, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e320a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e44e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e61054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e71054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a56a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03079056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010281c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c4001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000febe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f5f7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport9MetricSet::CDataport9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE0", "DATAPORT INPUT AVAILABLE XECORE0",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE1", "DATAPORT INPUT AVAILABLE XECORE1",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1881039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport10MetricSet::CDataport10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE2", "DATAPORT INPUT AVAILABLE XECORE2",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE3", "DATAPORT INPUT AVAILABLE XECORE3",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport11MetricSet::CDataport11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE4", "DATAPORT INPUT AVAILABLE XECORE4",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE5", "DATAPORT INPUT AVAILABLE XECORE5",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1981039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport12MetricSet::CDataport12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE6", "DATAPORT INPUT AVAILABLE XECORE6",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE7", "DATAPORT INPUT AVAILABLE XECORE7",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport13MetricSet::CDataport13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE8", "DATAPORT INPUT AVAILABLE XECORE8",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE9", "DATAPORT INPUT AVAILABLE XECORE9",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1881039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport14MetricSet::CDataport14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE10", "DATAPORT INPUT AVAILABLE XECORE10",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE11", "DATAPORT INPUT AVAILABLE XECORE11",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport15MetricSet::CDataport15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE12", "DATAPORT INPUT AVAILABLE XECORE12",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE13", "DATAPORT INPUT AVAILABLE XECORE13",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1981039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport16MetricSet::CDataport16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE14", "DATAPORT INPUT AVAILABLE XECORE14",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE15", "DATAPORT INPUT AVAILABLE XECORE15",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport17MetricSet::CDataport17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE0", "DATAPORT OUTPUT READY XECORE0",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE1", "DATAPORT OUTPUT READY XECORE1",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE2", "DATAPORT OUTPUT READY XECORE2",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE3", "DATAPORT OUTPUT READY XECORE3",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport18MetricSet::CDataport18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE4", "DATAPORT OUTPUT READY XECORE4",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE5", "DATAPORT OUTPUT READY XECORE5",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE6", "DATAPORT OUTPUT READY XECORE6",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE7", "DATAPORT OUTPUT READY XECORE7",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport19MetricSet::CDataport19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE8", "DATAPORT OUTPUT READY XECORE8",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE9", "DATAPORT OUTPUT READY XECORE9",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE10", "DATAPORT OUTPUT READY XECORE10",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE11", "DATAPORT OUTPUT READY XECORE11",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport20MetricSet::CDataport20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE12", "DATAPORT OUTPUT READY XECORE12",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE13", "DATAPORT OUTPUT READY XECORE13",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE14", "DATAPORT OUTPUT READY XECORE14",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE15", "DATAPORT OUTPUT READY XECORE15",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport21MetricSet::CDataport21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE0", "DATAPORT BYTE READ XECORE0",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE1", "DATAPORT BYTE READ XECORE1",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport22MetricSet::CDataport22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE2", "DATAPORT BYTE READ XECORE2",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE3", "DATAPORT BYTE READ XECORE3",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport23MetricSet::CDataport23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE4", "DATAPORT BYTE READ XECORE4",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE5", "DATAPORT BYTE READ XECORE5",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport24MetricSet::CDataport24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE6", "DATAPORT BYTE READ XECORE6",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE7", "DATAPORT BYTE READ XECORE7",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport25MetricSet::CDataport25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE8", "DATAPORT BYTE READ XECORE8",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE9", "DATAPORT BYTE READ XECORE9",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport26MetricSet::CDataport26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE10", "DATAPORT BYTE READ XECORE10",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE11", "DATAPORT BYTE READ XECORE11",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport27MetricSet::CDataport27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE12", "DATAPORT BYTE READ XECORE12",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE13", "DATAPORT BYTE READ XECORE13",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport28MetricSet::CDataport28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE14", "DATAPORT BYTE READ XECORE14",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE15", "DATAPORT BYTE READ XECORE15",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport29MetricSet::CDataport29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE0", "DATAPORT BYTE WRITE XECORE0",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE1", "DATAPORT BYTE WRITE XECORE1",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE2", "DATAPORT BYTE WRITE XECORE2",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE3", "DATAPORT BYTE WRITE XECORE3",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE4", "DATAPORT BYTE WRITE XECORE4",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE5", "DATAPORT BYTE WRITE XECORE5",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE6", "DATAPORT BYTE WRITE XECORE6",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE7", "DATAPORT BYTE WRITE XECORE7",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE8", "DATAPORT BYTE WRITE XECORE8",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE9", "DATAPORT BYTE WRITE XECORE9",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE10", "DATAPORT BYTE WRITE XECORE10",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE11", "DATAPORT BYTE WRITE XECORE11",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE12", "DATAPORT BYTE WRITE XECORE12",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE13", "DATAPORT BYTE WRITE XECORE13",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE14", "DATAPORT BYTE WRITE XECORE14",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE15", "DATAPORT BYTE WRITE XECORE15",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030ee2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0314e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport30MetricSet::CDataport30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE0", "XVE DATAPORT REGISTER REQUEST COUNT XECORE0",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE1", "XVE DATAPORT REGISTER REQUEST COUNT XECORE1",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE2", "XVE DATAPORT REGISTER REQUEST COUNT XECORE2",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE3", "XVE DATAPORT REGISTER REQUEST COUNT XECORE3",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE4", "XVE DATAPORT REGISTER REQUEST COUNT XECORE4",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE5", "XVE DATAPORT REGISTER REQUEST COUNT XECORE5",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE6", "XVE DATAPORT REGISTER REQUEST COUNT XECORE6",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE7", "XVE DATAPORT REGISTER REQUEST COUNT XECORE7",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport31MetricSet::CDataport31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE8", "XVE DATAPORT REGISTER REQUEST COUNT XECORE8",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE9", "XVE DATAPORT REGISTER REQUEST COUNT XECORE9",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE10", "XVE DATAPORT REGISTER REQUEST COUNT XECORE10",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE11", "XVE DATAPORT REGISTER REQUEST COUNT XECORE11",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE12", "XVE DATAPORT REGISTER REQUEST COUNT XECORE12",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE13", "XVE DATAPORT REGISTER REQUEST COUNT XECORE13",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE14", "XVE DATAPORT REGISTER REQUEST COUNT XECORE14",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE15", "XVE DATAPORT REGISTER REQUEST COUNT XECORE15",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport32MetricSet::CDataport32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE0", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE0",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 2 UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 2 UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE1", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE1",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport33MetricSet::CDataport33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE2", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE2",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE3", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE3",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport34MetricSet::CDataport34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE4", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE4",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE5", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE5",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport35MetricSet::CDataport35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE6", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE6",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE7", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE7",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport36MetricSet::CDataport36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE8", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE8",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE9", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE9",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport37MetricSet::CDataport37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE10", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE10",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE11", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE11",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport38MetricSet::CDataport38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE12", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE12",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE13", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE13",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport39MetricSet::CDataport39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE14", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE14",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE15", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE15",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport40MetricSet::CDataport40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE0", "DATAPORT TEXTURE CACHE ACCESS XECORE0",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE1", "DATAPORT TEXTURE CACHE ACCESS XECORE1",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE2", "DATAPORT TEXTURE CACHE ACCESS XECORE2",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE3", "DATAPORT TEXTURE CACHE ACCESS XECORE3",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE4", "DATAPORT TEXTURE CACHE ACCESS XECORE4",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE5", "DATAPORT TEXTURE CACHE ACCESS XECORE5",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE6", "DATAPORT TEXTURE CACHE ACCESS XECORE6",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE7", "DATAPORT TEXTURE CACHE ACCESS XECORE7",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE8", "DATAPORT TEXTURE CACHE ACCESS XECORE8",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE9", "DATAPORT TEXTURE CACHE ACCESS XECORE9",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE10", "DATAPORT TEXTURE CACHE ACCESS XECORE10",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE11", "DATAPORT TEXTURE CACHE ACCESS XECORE11",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE12", "DATAPORT TEXTURE CACHE ACCESS XECORE12",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE13", "DATAPORT TEXTURE CACHE ACCESS XECORE13",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE14", "DATAPORT TEXTURE CACHE ACCESS XECORE14",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE15", "DATAPORT TEXTURE CACHE ACCESS XECORE15",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030ee2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0314e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport41MetricSet::CDataport41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE0", "DATAPORT TEXTURE CACHE HIT XECORE0",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE1", "DATAPORT TEXTURE CACHE HIT XECORE1",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE2", "DATAPORT TEXTURE CACHE HIT XECORE2",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE3", "DATAPORT TEXTURE CACHE HIT XECORE3",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE4", "DATAPORT TEXTURE CACHE HIT XECORE4",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE5", "DATAPORT TEXTURE CACHE HIT XECORE5",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE6", "DATAPORT TEXTURE CACHE HIT XECORE6",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE7", "DATAPORT TEXTURE CACHE HIT XECORE7",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE8", "DATAPORT TEXTURE CACHE HIT XECORE8",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE9", "DATAPORT TEXTURE CACHE HIT XECORE9",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE10", "DATAPORT TEXTURE CACHE HIT XECORE10",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE11", "DATAPORT TEXTURE CACHE HIT XECORE11",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE12", "DATAPORT TEXTURE CACHE HIT XECORE12",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE13", "DATAPORT TEXTURE CACHE HIT XECORE13",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE14", "DATAPORT TEXTURE CACHE HIT XECORE14",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE15", "DATAPORT TEXTURE CACHE HIT XECORE15",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2081001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2181001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2081001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2181001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030ee2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0314e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe1MetricSet::CDepthPipe1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE0", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE0",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE0", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE0",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe2MetricSet::CDepthPipe2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE1", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE1",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE1", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE1",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe3MetricSet::CDepthPipe3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE2", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE2",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE2", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE2",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe4MetricSet::CDepthPipe4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE3", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE3",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE3", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE3",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe5MetricSet::CDepthPipe5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE4", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE4",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE4", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE4",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe6MetricSet::CDepthPipe6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE5", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE5",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE5", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE5",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe7MetricSet::CDepthPipe7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE6", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE6",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE6", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE6",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe8MetricSet::CDepthPipe8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE7", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE7",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE7", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE7",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe9MetricSet::CDepthPipe9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE0", "HIZ DEPTH TEST AMBIG NP ZPIPE0",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe10MetricSet::CDepthPipe10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE1", "HIZ DEPTH TEST AMBIG NP ZPIPE1",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe11MetricSet::CDepthPipe11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE2", "HIZ DEPTH TEST AMBIG NP ZPIPE2",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe12MetricSet::CDepthPipe12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE3", "HIZ DEPTH TEST AMBIG NP ZPIPE3",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe13MetricSet::CDepthPipe13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE4", "HIZ DEPTH TEST AMBIG NP ZPIPE4",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe14MetricSet::CDepthPipe14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE5", "HIZ DEPTH TEST AMBIG NP ZPIPE5",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe15MetricSet::CDepthPipe15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE6", "HIZ DEPTH TEST AMBIG NP ZPIPE6",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe16MetricSet::CDepthPipe16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE7", "HIZ DEPTH TEST AMBIG NP ZPIPE7",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe17MetricSet::CDepthPipe17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE0", "HIZ DEPTH TEST AMBIG P ZPIPE0",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe18MetricSet::CDepthPipe18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE1", "HIZ DEPTH TEST AMBIG P ZPIPE1",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe19MetricSet::CDepthPipe19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE2", "HIZ DEPTH TEST AMBIG P ZPIPE2",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe20MetricSet::CDepthPipe20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE3", "HIZ DEPTH TEST AMBIG P ZPIPE3",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe21MetricSet::CDepthPipe21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE4", "HIZ DEPTH TEST AMBIG P ZPIPE4",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe22MetricSet::CDepthPipe22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE5", "HIZ DEPTH TEST AMBIG P ZPIPE5",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe23MetricSet::CDepthPipe23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE6", "HIZ DEPTH TEST AMBIG P ZPIPE6",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe24MetricSet::CDepthPipe24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE7", "HIZ DEPTH TEST AMBIG P ZPIPE7",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe25MetricSet::CDepthPipe25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE0", "HIZ DEPTH TEST FAIL NP ZPIPE0",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe26MetricSet::CDepthPipe26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE1", "HIZ DEPTH TEST FAIL NP ZPIPE1",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe27MetricSet::CDepthPipe27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE2", "HIZ DEPTH TEST FAIL NP ZPIPE2",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe28MetricSet::CDepthPipe28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE3", "HIZ DEPTH TEST FAIL NP ZPIPE3",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe29MetricSet::CDepthPipe29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE4", "HIZ DEPTH TEST FAIL NP ZPIPE4",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe30MetricSet::CDepthPipe30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE5", "HIZ DEPTH TEST FAIL NP ZPIPE5",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe31MetricSet::CDepthPipe31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE6", "HIZ DEPTH TEST FAIL NP ZPIPE6",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe32MetricSet::CDepthPipe32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE7", "HIZ DEPTH TEST FAIL NP ZPIPE7",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe33MetricSet::CDepthPipe33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE0", "HIZ DEPTH TEST FAIL P ZPIPE0",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe34MetricSet::CDepthPipe34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE1", "HIZ DEPTH TEST FAIL P ZPIPE1",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe35MetricSet::CDepthPipe35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE2", "HIZ DEPTH TEST FAIL P ZPIPE2",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe36MetricSet::CDepthPipe36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE3", "HIZ DEPTH TEST FAIL P ZPIPE3",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe37MetricSet::CDepthPipe37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE4", "HIZ DEPTH TEST FAIL P ZPIPE4",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe38MetricSet::CDepthPipe38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE5", "HIZ DEPTH TEST FAIL P ZPIPE5",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe39MetricSet::CDepthPipe39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE6", "HIZ DEPTH TEST FAIL P ZPIPE6",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe40MetricSet::CDepthPipe40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE7", "HIZ DEPTH TEST FAIL P ZPIPE7",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe41MetricSet::CDepthPipe41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE0", "HIZ DEPTH TEST PASS P ZPIPE0",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe42MetricSet::CDepthPipe42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE1", "HIZ DEPTH TEST PASS P ZPIPE1",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe43MetricSet::CDepthPipe43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE2", "HIZ DEPTH TEST PASS P ZPIPE2",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe44MetricSet::CDepthPipe44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE3", "HIZ DEPTH TEST PASS P ZPIPE3",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe45MetricSet::CDepthPipe45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE4", "HIZ DEPTH TEST PASS P ZPIPE4",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe46MetricSet::CDepthPipe46MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe46MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE5", "HIZ DEPTH TEST PASS P ZPIPE5",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe47MetricSet::CDepthPipe47MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe47MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE6", "HIZ DEPTH TEST PASS P ZPIPE6",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe48MetricSet::CDepthPipe48MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe48MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE7", "HIZ DEPTH TEST PASS P ZPIPE7",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe49MetricSet::CDepthPipe49MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe49MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE0", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE0",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE1", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE1",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE2", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE2",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE3", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE3",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE4", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE4",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE5", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE5",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE6", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE6",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE7", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE7",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE0", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE0",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE1", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE1",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE2", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE2",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE3", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE3",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE4", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE4",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE5", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE5",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE6", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE6",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE7", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE7",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001b0b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00024040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01012020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01021010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b6080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c6002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010b0b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0302e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032481, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDepthPipe50MetricSet::CDepthPipe50MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDepthPipe50MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE0", "IZ OUTPUT READY ZPIPE0",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE1", "IZ OUTPUT READY ZPIPE1",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE2", "IZ OUTPUT READY ZPIPE2",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE3", "IZ OUTPUT READY ZPIPE3",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE4", "IZ OUTPUT READY ZPIPE4",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE5", "IZ OUTPUT READY ZPIPE5",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE6", "IZ OUTPUT READY ZPIPE6",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE7", "IZ OUTPUT READY ZPIPE7",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01012000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032481, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CFrontEnd1MetricSet::CFrontEnd1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CFrontEnd1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS0", "COMMAND PARSER COMPUTE ENGINE BUSY CCS0",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS1", "COMMAND PARSER COMPUTE ENGINE BUSY CCS1",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY", "COMMAND PARSER COMPUTE ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS0 $COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS1 FADD 2 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_RENDER_ENGINE_BUSY", "COMMAND PARSER RENDER ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the 3D queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY", "COMMAND PARSER COPY ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOX0", "COMMAND PARSER VIDEO ENGINE BUSY VDBOX0",
                          "Percentage of time in which there is a context loaded and active on the media queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOX1", "COMMAND PARSER VIDEO ENGINE BUSY VDBOX1",
                          "Percentage of time in which there is a context loaded and active on the media queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENHANCEMENT_ENGINE_BUSY_VEBOX0", "COMMAND PARSER VIDEO ENHANCEMENT ENGINE BUSY VEBOX0",
                          "Percentage of time in which there is a context loaded and active on the video enhancement queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENHANCEMENT_ENGINE_BUSY_VEBOX1", "COMMAND PARSER VIDEO ENHANCEMENT ENGINE BUSY VEBOX1",
                          "Percentage of time in which there is a context loaded and active on the video enhancement queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENGINE_BUSY", "COMMAND PARSER VIDEO ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the media queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOX0 $COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOX1 FADD 2 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENHANCEMENT_ENGINE_BUSY", "COMMAND PARSER VIDEO ENHANCEMENT ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the video enhancement queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$COMMAND_PARSER_VIDEO_ENHANCEMENT_ENGINE_BUSY_VEBOX0 $COMMAND_PARSER_VIDEO_ENHANCEMENT_ENGINE_BUSY_VEBOX1 FADD 2 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS0", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT CCS0",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS1", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT CCS1",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS0 $$COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS1 UADD" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_RENDER_ENGINE_DISPATCH_KERNEL_COUNT", "COMMAND PARSER RENDER ENGINE DISPATCH KERNEL COUNT",
                          "Number of compute walker commands parsed on the 3D engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_FLUSH_COUNT", "COMMAND PARSER FLUSH COUNT",
                          "Number of Stalling flushes at the top of the pipe",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_RENDER_ENGINE_DRAW_COUNT", "COMMAND PARSER RENDER ENGINE DRAW COUNT",
                          "Number of DRAW and MESH commands parsed on the 3D engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420a7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a133e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02100084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02120004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00134000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420a7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a133e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02100021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02120001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00134000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a130940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2804001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24047c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3004001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c047c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4404001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40043e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040436fb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06043e69, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08048c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c040900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1604076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1804000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050066, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034892, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040324a4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031460, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0306a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03146a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CGeometry1MetricSet::CGeometry1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CGeometry1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE0", "CLIPPER INPUT VERTEX SLICE0",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE1", "CLIPPER INPUT VERTEX SLICE1",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE2", "CLIPPER INPUT VERTEX SLICE2",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE3", "CLIPPER INPUT VERTEX SLICE3",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE0", "STREAMOUT OUTPUT VERTEX COUNT SLICE0",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE1", "STREAMOUT OUTPUT VERTEX COUNT SLICE1",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE2", "STREAMOUT OUTPUT VERTEX COUNT SLICE2",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE3", "STREAMOUT OUTPUT VERTEX COUNT SLICE3",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16070034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0609034a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00098000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a9000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15070d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090285, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020803fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c09034a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00092000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0956, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00011e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13070d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090285, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1109000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203124a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030849, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e50, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0302e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c03f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffd7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000febf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00003002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000f9ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f5ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CGeometry2MetricSet::CGeometry2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CGeometry2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE0", "VERTEX FETCH INPUT AVAILABLE SLICE0",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE1", "VERTEX FETCH INPUT AVAILABLE SLICE1",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE2", "VERTEX FETCH INPUT AVAILABLE SLICE2",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE3", "VERTEX FETCH INPUT AVAILABLE SLICE3",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE0", "VERTEX FETCH OUTPUT READY SLICE0",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE1", "VERTEX FETCH OUTPUT READY SLICE1",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE2", "VERTEX FETCH OUTPUT READY SLICE2",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE3", "VERTEX FETCH OUTPUT READY SLICE3",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE0", "CLIPPER INPUT AVAILABLE SLICE0",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE1", "CLIPPER INPUT AVAILABLE SLICE1",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE2", "CLIPPER INPUT AVAILABLE SLICE2",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE3", "CLIPPER INPUT AVAILABLE SLICE3",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE0", "CLIPPER OUTPUT READY SLICE0",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE1", "CLIPPER OUTPUT READY SLICE1",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE2", "CLIPPER OUTPUT READY SLICE2",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE3", "CLIPPER OUTPUT READY SLICE3",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080c0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0604, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070a09c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150a0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031188, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008c0c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a6040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00011188, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090a09c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130a0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203124a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x360304a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031264, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031424, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cc33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000133cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CGeometry3MetricSet::CGeometry3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CGeometry3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE0", "STRIPSFAN OUTPUT READY SLICE0",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE1", "STRIPSFAN OUTPUT READY SLICE1",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE2", "STRIPSFAN OUTPUT READY SLICE2",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE3", "STRIPSFAN OUTPUT READY SLICE3",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE0", "VS OUTPUT READY SLICE0",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE1", "VS OUTPUT READY SLICE1",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE2", "VS OUTPUT READY SLICE2",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE3", "VS OUTPUT READY SLICE3",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE0", "CLIPPER PRIMITIVE CULL SLICE0",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE1", "CLIPPER PRIMITIVE CULL SLICE1",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE2", "CLIPPER PRIMITIVE CULL SLICE2",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE3", "CLIPPER PRIMITIVE CULL SLICE3",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034302, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04096800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a50a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c302, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba00a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a100a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa560, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090904b4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x360308c9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030a25, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a031e51, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0305e2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1403f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001cf03, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CGeometry4MetricSet::CGeometry4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CGeometry4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE0", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE0",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE1", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE1",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE2", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE2",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE3", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE3",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE0", "CLIPPER PRIMITIVE OUTPUT SLICE0",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE1", "CLIPPER PRIMITIVE OUTPUT SLICE1",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE2", "CLIPPER PRIMITIVE OUTPUT SLICE2",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE3", "CLIPPER PRIMITIVE OUTPUT SLICE3",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060902cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a9000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090306, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020803fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0902cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0956, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00011e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090306, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1109094b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203124a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c03f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000142, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffd7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000a02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000febf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00003002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000f9ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00005002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f5ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CGeometry5MetricSet::CGeometry5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CGeometry5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE0", "STRIPSFAN OBJECTS CULL SLICE0",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE1", "STRIPSFAN OBJECTS CULL SLICE1",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE2", "STRIPSFAN OBJECTS CULL SLICE2",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE3", "STRIPSFAN OBJECTS CULL SLICE3",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE0", "STRIPSFAN OBJECT COUNT SLICE0",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE1", "STRIPSFAN OBJECT COUNT SLICE1",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE2", "STRIPSFAN OBJECT COUNT SLICE2",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE3", "STRIPSFAN OBJECT COUNT SLICE3",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE0", "CLIPPER TRANSACTION OUTPUT SLICE0",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE1", "CLIPPER TRANSACTION OUTPUT SLICE1",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE2", "CLIPPER TRANSACTION OUTPUT SLICE2",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE3", "CLIPPER TRANSACTION OUTPUT SLICE3",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1409002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00087030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1309002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a1020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030311, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080703, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1009002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0509, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010311, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f09002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0102, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031291, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x320314a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x360324a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031929, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache1MetricSet::CL1Cache1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE0", "LOAD STORE CACHE INPUT AVAILABLE XECORE0",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE1", "LOAD STORE CACHE INPUT AVAILABLE XECORE1",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE2", "LOAD STORE CACHE INPUT AVAILABLE XECORE2",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE3", "LOAD STORE CACHE INPUT AVAILABLE XECORE3",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache2MetricSet::CL1Cache2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE4", "LOAD STORE CACHE INPUT AVAILABLE XECORE4",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE5", "LOAD STORE CACHE INPUT AVAILABLE XECORE5",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE6", "LOAD STORE CACHE INPUT AVAILABLE XECORE6",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE7", "LOAD STORE CACHE INPUT AVAILABLE XECORE7",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache3MetricSet::CL1Cache3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE8", "LOAD STORE CACHE INPUT AVAILABLE XECORE8",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE9", "LOAD STORE CACHE INPUT AVAILABLE XECORE9",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE10", "LOAD STORE CACHE INPUT AVAILABLE XECORE10",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE11", "LOAD STORE CACHE INPUT AVAILABLE XECORE11",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache4MetricSet::CL1Cache4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE12", "LOAD STORE CACHE INPUT AVAILABLE XECORE12",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE13", "LOAD STORE CACHE INPUT AVAILABLE XECORE13",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE14", "LOAD STORE CACHE INPUT AVAILABLE XECORE14",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE15", "LOAD STORE CACHE INPUT AVAILABLE XECORE15",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache5MetricSet::CL1Cache5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE0", "LOAD STORE CACHE OUTPUT READY XECORE0",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE1", "LOAD STORE CACHE OUTPUT READY XECORE1",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE2", "LOAD STORE CACHE OUTPUT READY XECORE2",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE3", "LOAD STORE CACHE OUTPUT READY XECORE3",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache6MetricSet::CL1Cache6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE4", "LOAD STORE CACHE OUTPUT READY XECORE4",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE5", "LOAD STORE CACHE OUTPUT READY XECORE5",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE6", "LOAD STORE CACHE OUTPUT READY XECORE6",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE7", "LOAD STORE CACHE OUTPUT READY XECORE7",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache7MetricSet::CL1Cache7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE8", "LOAD STORE CACHE OUTPUT READY XECORE8",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE9", "LOAD STORE CACHE OUTPUT READY XECORE9",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE10", "LOAD STORE CACHE OUTPUT READY XECORE10",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE11", "LOAD STORE CACHE OUTPUT READY XECORE11",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache8MetricSet::CL1Cache8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE12", "LOAD STORE CACHE OUTPUT READY XECORE12",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE13", "LOAD STORE CACHE OUTPUT READY XECORE13",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE14", "LOAD STORE CACHE OUTPUT READY XECORE14",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE15", "LOAD STORE CACHE OUTPUT READY XECORE15",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache9MetricSet::CL1Cache9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE0", "LOAD STORE CACHE L3 READ XECORE0",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE1", "LOAD STORE CACHE L3 READ XECORE1",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE2", "LOAD STORE CACHE L3 READ XECORE2",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE3", "LOAD STORE CACHE L3 READ XECORE3",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE4", "LOAD STORE CACHE L3 READ XECORE4",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE5", "LOAD STORE CACHE L3 READ XECORE5",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE6", "LOAD STORE CACHE L3 READ XECORE6",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE7", "LOAD STORE CACHE L3 READ XECORE7",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache10MetricSet::CL1Cache10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE8", "LOAD STORE CACHE L3 READ XECORE8",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE9", "LOAD STORE CACHE L3 READ XECORE9",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE10", "LOAD STORE CACHE L3 READ XECORE10",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE11", "LOAD STORE CACHE L3 READ XECORE11",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE12", "LOAD STORE CACHE L3 READ XECORE12",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE13", "LOAD STORE CACHE L3 READ XECORE13",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE14", "LOAD STORE CACHE L3 READ XECORE14",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE15", "LOAD STORE CACHE L3 READ XECORE15",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache11MetricSet::CL1Cache11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE0", "LOAD STORE CACHE L3 WRITE XECORE0",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE1", "LOAD STORE CACHE L3 WRITE XECORE1",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE2", "LOAD STORE CACHE L3 WRITE XECORE2",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE3", "LOAD STORE CACHE L3 WRITE XECORE3",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE4", "LOAD STORE CACHE L3 WRITE XECORE4",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE5", "LOAD STORE CACHE L3 WRITE XECORE5",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE6", "LOAD STORE CACHE L3 WRITE XECORE6",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE7", "LOAD STORE CACHE L3 WRITE XECORE7",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache12MetricSet::CL1Cache12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE8", "LOAD STORE CACHE L3 WRITE XECORE8",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE9", "LOAD STORE CACHE L3 WRITE XECORE9",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE10", "LOAD STORE CACHE L3 WRITE XECORE10",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE11", "LOAD STORE CACHE L3 WRITE XECORE11",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE12", "LOAD STORE CACHE L3 WRITE XECORE12",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE13", "LOAD STORE CACHE L3 WRITE XECORE13",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE14", "LOAD STORE CACHE L3 WRITE XECORE14",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE15", "LOAD STORE CACHE L3 WRITE XECORE15",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030e77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache13MetricSet::CL1Cache13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE0", "LOAD STORE CACHE ACCESS XECORE0",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE1", "LOAD STORE CACHE ACCESS XECORE1",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE2", "LOAD STORE CACHE ACCESS XECORE2",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE3", "LOAD STORE CACHE ACCESS XECORE3",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache14MetricSet::CL1Cache14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE4", "LOAD STORE CACHE ACCESS XECORE4",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE5", "LOAD STORE CACHE ACCESS XECORE5",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE6", "LOAD STORE CACHE ACCESS XECORE6",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE7", "LOAD STORE CACHE ACCESS XECORE7",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache15MetricSet::CL1Cache15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE8", "LOAD STORE CACHE ACCESS XECORE8",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE9", "LOAD STORE CACHE ACCESS XECORE9",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE10", "LOAD STORE CACHE ACCESS XECORE10",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE11", "LOAD STORE CACHE ACCESS XECORE11",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache16MetricSet::CL1Cache16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE12", "LOAD STORE CACHE ACCESS XECORE12",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE13", "LOAD STORE CACHE ACCESS XECORE13",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE14", "LOAD STORE CACHE ACCESS XECORE14",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE15", "LOAD STORE CACHE ACCESS XECORE15",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache17MetricSet::CL1Cache17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE0", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE0",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE1", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE1",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE2", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE2",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE3", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE3",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache18MetricSet::CL1Cache18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE4", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE4",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE5", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE5",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE6", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE6",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE7", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE7",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache19MetricSet::CL1Cache19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE8", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE8",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE9", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE9",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE10", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE10",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE11", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE11",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache20MetricSet::CL1Cache20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE12", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE12",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE13", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE13",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE14", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE14",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE15", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE15",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache21MetricSet::CL1Cache21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE0", "LOAD STORE CACHE HIT XECORE0",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE1", "LOAD STORE CACHE HIT XECORE1",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache22MetricSet::CL1Cache22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE2", "LOAD STORE CACHE HIT XECORE2",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE3", "LOAD STORE CACHE HIT XECORE3",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030231, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache23MetricSet::CL1Cache23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE4", "LOAD STORE CACHE HIT XECORE4",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE5", "LOAD STORE CACHE HIT XECORE5",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache24MetricSet::CL1Cache24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE6", "LOAD STORE CACHE HIT XECORE6",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE7", "LOAD STORE CACHE HIT XECORE7",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030231, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache25MetricSet::CL1Cache25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE8", "LOAD STORE CACHE HIT XECORE8",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE9", "LOAD STORE CACHE HIT XECORE9",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache26MetricSet::CL1Cache26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE10", "LOAD STORE CACHE HIT XECORE10",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE11", "LOAD STORE CACHE HIT XECORE11",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030231, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache27MetricSet::CL1Cache27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE12", "LOAD STORE CACHE HIT XECORE12",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE13", "LOAD STORE CACHE HIT XECORE13",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache28MetricSet::CL1Cache28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE14", "LOAD STORE CACHE HIT XECORE14",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE15", "LOAD STORE CACHE HIT XECORE15",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030231, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache29MetricSet::CL1Cache29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE0", "SLM BANK CONFLICT COUNT XECORE0",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x288914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1089079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1489038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache30MetricSet::CL1Cache30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE1", "SLM BANK CONFLICT COUNT XECORE1",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache31MetricSet::CL1Cache31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE2", "SLM BANK CONFLICT COUNT XECORE2",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache32MetricSet::CL1Cache32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE3", "SLM BANK CONFLICT COUNT XECORE3",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache33MetricSet::CL1Cache33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE4", "SLM BANK CONFLICT COUNT XECORE4",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x298914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1189079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1589038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache34MetricSet::CL1Cache34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE5", "SLM BANK CONFLICT COUNT XECORE5",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache35MetricSet::CL1Cache35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE6", "SLM BANK CONFLICT COUNT XECORE6",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache36MetricSet::CL1Cache36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE7", "SLM BANK CONFLICT COUNT XECORE7",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache37MetricSet::CL1Cache37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE8", "SLM BANK CONFLICT COUNT XECORE8",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x288914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1089079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1489038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache38MetricSet::CL1Cache38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE9", "SLM BANK CONFLICT COUNT XECORE9",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache39MetricSet::CL1Cache39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE10", "SLM BANK CONFLICT COUNT XECORE10",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache40MetricSet::CL1Cache40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE11", "SLM BANK CONFLICT COUNT XECORE11",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache41MetricSet::CL1Cache41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE12", "SLM BANK CONFLICT COUNT XECORE12",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x298914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1189079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1589038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache42MetricSet::CL1Cache42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE13", "SLM BANK CONFLICT COUNT XECORE13",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache43MetricSet::CL1Cache43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE14", "SLM BANK CONFLICT COUNT XECORE14",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache44MetricSet::CL1Cache44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE15", "SLM BANK CONFLICT COUNT XECORE15",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache45MetricSet::CL1Cache45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE0", "SLM ACCESS COUNT XECORE0",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE1", "SLM ACCESS COUNT XECORE1",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE2", "SLM ACCESS COUNT XECORE2",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE3", "SLM ACCESS COUNT XECORE3",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1687000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1288000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1688000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache46MetricSet::CL1Cache46MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache46MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE4", "SLM ACCESS COUNT XECORE4",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE5", "SLM ACCESS COUNT XECORE5",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE6", "SLM ACCESS COUNT XECORE6",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE7", "SLM ACCESS COUNT XECORE7",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1787000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1388000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1788000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache47MetricSet::CL1Cache47MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache47MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE8", "SLM ACCESS COUNT XECORE8",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE9", "SLM ACCESS COUNT XECORE9",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE10", "SLM ACCESS COUNT XECORE10",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE11", "SLM ACCESS COUNT XECORE11",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1687000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1288000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1688000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache48MetricSet::CL1Cache48MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache48MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE12", "SLM ACCESS COUNT XECORE12",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE13", "SLM ACCESS COUNT XECORE13",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE14", "SLM ACCESS COUNT XECORE14",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE15", "SLM ACCESS COUNT XECORE15",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1787000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1388000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1788000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache49MetricSet::CL1Cache49MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache49MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE0", "XVE SLM READ MESSAGE COUNT XECORE0",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE1", "XVE SLM READ MESSAGE COUNT XECORE1",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache50MetricSet::CL1Cache50MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache50MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE2", "XVE SLM READ MESSAGE COUNT XECORE2",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE3", "XVE SLM READ MESSAGE COUNT XECORE3",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache51MetricSet::CL1Cache51MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache51MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE4", "XVE SLM READ MESSAGE COUNT XECORE4",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE5", "XVE SLM READ MESSAGE COUNT XECORE5",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache52MetricSet::CL1Cache52MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache52MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE6", "XVE SLM READ MESSAGE COUNT XECORE6",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE7", "XVE SLM READ MESSAGE COUNT XECORE7",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache53MetricSet::CL1Cache53MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache53MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE8", "XVE SLM READ MESSAGE COUNT XECORE8",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE9", "XVE SLM READ MESSAGE COUNT XECORE9",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache54MetricSet::CL1Cache54MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache54MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE10", "XVE SLM READ MESSAGE COUNT XECORE10",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE11", "XVE SLM READ MESSAGE COUNT XECORE11",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache55MetricSet::CL1Cache55MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache55MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE12", "XVE SLM READ MESSAGE COUNT XECORE12",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE13", "XVE SLM READ MESSAGE COUNT XECORE13",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache56MetricSet::CL1Cache56MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache56MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE14", "XVE SLM READ MESSAGE COUNT XECORE14",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE15", "XVE SLM READ MESSAGE COUNT XECORE15",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache57MetricSet::CL1Cache57MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache57MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE0", "XVE SLM WRITE MESSAGE COUNT XECORE0",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE1", "XVE SLM WRITE MESSAGE COUNT XECORE1",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache58MetricSet::CL1Cache58MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache58MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE2", "XVE SLM WRITE MESSAGE COUNT XECORE2",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE3", "XVE SLM WRITE MESSAGE COUNT XECORE3",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache59MetricSet::CL1Cache59MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache59MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE4", "XVE SLM WRITE MESSAGE COUNT XECORE4",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE5", "XVE SLM WRITE MESSAGE COUNT XECORE5",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache60MetricSet::CL1Cache60MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache60MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE6", "XVE SLM WRITE MESSAGE COUNT XECORE6",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE7", "XVE SLM WRITE MESSAGE COUNT XECORE7",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache61MetricSet::CL1Cache61MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache61MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE8", "XVE SLM WRITE MESSAGE COUNT XECORE8",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE9", "XVE SLM WRITE MESSAGE COUNT XECORE9",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache62MetricSet::CL1Cache62MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache62MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE10", "XVE SLM WRITE MESSAGE COUNT XECORE10",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE11", "XVE SLM WRITE MESSAGE COUNT XECORE11",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache63MetricSet::CL1Cache63MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache63MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE12", "XVE SLM WRITE MESSAGE COUNT XECORE12",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE13", "XVE SLM WRITE MESSAGE COUNT XECORE13",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache64MetricSet::CL1Cache64MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache64MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE14", "XVE SLM WRITE MESSAGE COUNT XECORE14",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE15", "XVE SLM WRITE MESSAGE COUNT XECORE15",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache65MetricSet::CL1Cache65MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache65MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE0", "XVE SLM ATOMIC MESSAGE COUNT XECORE0",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE0", "XVE SLM FENCE MESSAGE COUNT XECORE0",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache66MetricSet::CL1Cache66MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache66MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE1", "XVE SLM ATOMIC MESSAGE COUNT XECORE1",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE1", "XVE SLM FENCE MESSAGE COUNT XECORE1",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache67MetricSet::CL1Cache67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE2", "XVE SLM ATOMIC MESSAGE COUNT XECORE2",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE2", "XVE SLM FENCE MESSAGE COUNT XECORE2",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache68MetricSet::CL1Cache68MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache68MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE3", "XVE SLM ATOMIC MESSAGE COUNT XECORE3",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE3", "XVE SLM FENCE MESSAGE COUNT XECORE3",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache69MetricSet::CL1Cache69MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache69MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE4", "XVE SLM ATOMIC MESSAGE COUNT XECORE4",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE4", "XVE SLM FENCE MESSAGE COUNT XECORE4",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache70MetricSet::CL1Cache70MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache70MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE5", "XVE SLM ATOMIC MESSAGE COUNT XECORE5",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE5", "XVE SLM FENCE MESSAGE COUNT XECORE5",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache71MetricSet::CL1Cache71MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache71MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE6", "XVE SLM ATOMIC MESSAGE COUNT XECORE6",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE6", "XVE SLM FENCE MESSAGE COUNT XECORE6",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache72MetricSet::CL1Cache72MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache72MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE7", "XVE SLM ATOMIC MESSAGE COUNT XECORE7",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE7", "XVE SLM FENCE MESSAGE COUNT XECORE7",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache73MetricSet::CL1Cache73MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache73MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE8", "XVE SLM ATOMIC MESSAGE COUNT XECORE8",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE8", "XVE SLM FENCE MESSAGE COUNT XECORE8",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache74MetricSet::CL1Cache74MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache74MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE9", "XVE SLM ATOMIC MESSAGE COUNT XECORE9",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE9", "XVE SLM FENCE MESSAGE COUNT XECORE9",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache75MetricSet::CL1Cache75MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache75MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE10", "XVE SLM ATOMIC MESSAGE COUNT XECORE10",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE10", "XVE SLM FENCE MESSAGE COUNT XECORE10",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache76MetricSet::CL1Cache76MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache76MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE11", "XVE SLM ATOMIC MESSAGE COUNT XECORE11",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE11", "XVE SLM FENCE MESSAGE COUNT XECORE11",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache77MetricSet::CL1Cache77MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache77MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE12", "XVE SLM ATOMIC MESSAGE COUNT XECORE12",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE12", "XVE SLM FENCE MESSAGE COUNT XECORE12",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache78MetricSet::CL1Cache78MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache78MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE13", "XVE SLM ATOMIC MESSAGE COUNT XECORE13",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE13", "XVE SLM FENCE MESSAGE COUNT XECORE13",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache79MetricSet::CL1Cache79MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache79MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE14", "XVE SLM ATOMIC MESSAGE COUNT XECORE14",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE14", "XVE SLM FENCE MESSAGE COUNT XECORE14",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache80MetricSet::CL1Cache80MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache80MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE15", "XVE SLM ATOMIC MESSAGE COUNT XECORE15",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE15", "XVE SLM FENCE MESSAGE COUNT XECORE15",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00044002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache81MetricSet::CL1Cache81MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache81MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE0", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE0",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE1", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE1",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE2", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE2",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE3", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE3",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache82MetricSet::CL1Cache82MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache82MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE4", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE4",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE5", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE5",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE6", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE6",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE7", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE7",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache83MetricSet::CL1Cache83MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache83MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE8", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE8",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE9", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE9",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE10", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE10",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE11", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE11",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache84MetricSet::CL1Cache84MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache84MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE12", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE12",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE13", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE13",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE14", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE14",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE15", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE15",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache85MetricSet::CL1Cache85MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache85MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE0", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE0",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE1", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE1",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE2", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE2",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE3", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE3",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache86MetricSet::CL1Cache86MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache86MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE4", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE4",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE5", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE5",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE6", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE6",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE7", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE7",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache87MetricSet::CL1Cache87MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache87MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE8", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE8",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE9", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE9",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE10", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE10",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE11", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE11",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache88MetricSet::CL1Cache88MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache88MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE12", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE12",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE13", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE13",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE14", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE14",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE15", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE15",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache89MetricSet::CL1Cache89MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache89MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE0",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE1", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE1",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache90MetricSet::CL1Cache90MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache90MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE2", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE2",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE3", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE3",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache91MetricSet::CL1Cache91MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache91MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE4", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE4",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE5", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE5",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache92MetricSet::CL1Cache92MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache92MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE6", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE6",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE7", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE7",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache93MetricSet::CL1Cache93MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache93MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE8", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE8",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE9", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE9",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache94MetricSet::CL1Cache94MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache94MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE10", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE10",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE11", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE11",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache95MetricSet::CL1Cache95MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache95MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE12", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE12",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE13", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE13",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache96MetricSet::CL1Cache96MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache96MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE14", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE14",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE15", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE15",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache97MetricSet::CL1Cache97MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache97MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE0",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE1", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE1",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache98MetricSet::CL1Cache98MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache98MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE2", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE2",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE3", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE3",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache99MetricSet::CL1Cache99MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache99MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE4", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE4",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE5", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE5",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache100MetricSet::CL1Cache100MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache100MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE6", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE6",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE7", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE7",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache101MetricSet::CL1Cache101MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache101MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE8", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE8",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE9", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE9",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache102MetricSet::CL1Cache102MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache102MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE10", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE10",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE11", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE11",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache103MetricSet::CL1Cache103MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache103MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE12", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE12",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE13", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE13",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache104MetricSet::CL1Cache104MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache104MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE14", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE14",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE15", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE15",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache105MetricSet::CL1Cache105MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache105MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE0",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE0",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache106MetricSet::CL1Cache106MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache106MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE1", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE1",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE1", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE1",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache107MetricSet::CL1Cache107MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache107MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE2", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE2",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE2", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE2",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache108MetricSet::CL1Cache108MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache108MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE3", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE3",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE3", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE3",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache109MetricSet::CL1Cache109MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache109MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE4", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE4",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE4", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE4",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache110MetricSet::CL1Cache110MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache110MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE5", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE5",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE5", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE5",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache111MetricSet::CL1Cache111MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache111MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE6", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE6",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE6", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE6",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache112MetricSet::CL1Cache112MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache112MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE7", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE7",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE7", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE7",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache113MetricSet::CL1Cache113MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache113MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE8", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE8",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE8", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE8",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache114MetricSet::CL1Cache114MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache114MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE9", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE9",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE9", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE9",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache115MetricSet::CL1Cache115MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache115MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE10", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE10",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE10", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE10",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache116MetricSet::CL1Cache116MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache116MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE11", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE11",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE11", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE11",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache117MetricSet::CL1Cache117MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache117MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE12", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE12",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE12", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE12",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache118MetricSet::CL1Cache118MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache118MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE13", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE13",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE13", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE13",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache119MetricSet::CL1Cache119MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache119MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE14", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE14",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE14", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE14",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache120MetricSet::CL1Cache120MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache120MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE15", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE15",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE15", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE15",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e905c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90de7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000dfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000beff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x000077ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache121MetricSet::CL1Cache121MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache121MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK0_XECORE0", "LOAD STORE CACHE BYTE READ BANK0 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK0_XECORE0", "SLM BYTE READ BANK0 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c89034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache122MetricSet::CL1Cache122MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache122MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK0_XECORE1", "LOAD STORE CACHE BYTE READ BANK0 XECORE1",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_BYTE_READ_BANK0_XECORE1", "SLM BYTE READ BANK0 XECORE1",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache123MetricSet::CL1Cache123MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache123MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK0_XECORE2", "LOAD STORE CACHE BYTE READ BANK0 XECORE2",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_BYTE_READ_BANK0_XECORE2", "SLM BYTE READ BANK0 XECORE2",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache124MetricSet::CL1Cache124MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache124MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK0_XECORE3", "LOAD STORE CACHE BYTE READ BANK0 XECORE3",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_BYTE_READ_BANK0_XECORE3", "SLM BYTE READ BANK0 XECORE3",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache125MetricSet::CL1Cache125MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache125MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK1_XECORE0", "LOAD STORE CACHE BYTE READ BANK1 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK1_XECORE0", "SLM BYTE READ BANK1 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048700e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148707d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890797, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890658, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8906da, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c89075c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache126MetricSet::CL1Cache126MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache126MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK1_XECORE1", "LOAD STORE CACHE BYTE READ BANK1 XECORE1",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_BYTE_READ_BANK1_XECORE1", "SLM BYTE READ BANK1 XECORE1",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a700e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a70452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a707d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90797, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90658, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa906da, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca9075c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache127MetricSet::CL1Cache127MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache127MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK1_XECORE2", "LOAD STORE CACHE BYTE READ BANK1 XECORE2",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_BYTE_READ_BANK1_XECORE2", "SLM BYTE READ BANK1 XECORE2",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c700e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c70452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c707d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90797, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90658, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac906da, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc9075c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache128MetricSet::CL1Cache128MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache128MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK1_XECORE3", "LOAD STORE CACHE BYTE READ BANK1 XECORE3",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_BYTE_READ_BANK1_XECORE3", "SLM BYTE READ BANK1 XECORE3",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e700e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e707d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90797, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90658, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae906da, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce9075c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache129MetricSet::CL1Cache129MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache129MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK2_XECORE0", "LOAD STORE CACHE BYTE READ BANK2 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK2_XECORE0", "SLM BYTE READ BANK2 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22890c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a880140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8800c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108803c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890a68, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890aea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890b6c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0089fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache130MetricSet::CL1Cache130MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache130MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK2_XECORE1", "LOAD STORE CACHE BYTE READ BANK2 XECORE1",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_BYTE_READ_BANK2_XECORE1", "SLM BYTE READ BANK2 XECORE1",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca800c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a803c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90a68, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90aea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90b6c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache131MetricSet::CL1Cache131MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache131MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK2_XECORE2", "LOAD STORE CACHE BYTE READ BANK2 XECORE2",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_BYTE_READ_BANK2_XECORE2", "SLM BYTE READ BANK2 XECORE2",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac80140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc800c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec80042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c803c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90a68, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90aea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90b6c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache132MetricSet::CL1Cache132MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache132MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK2_XECORE3", "LOAD STORE CACHE BYTE READ BANK2 XECORE3",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_BYTE_READ_BANK2_XECORE3", "SLM BYTE READ BANK2 XECORE3",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae80140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce800c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e803c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90a68, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90aea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90b6c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache133MetricSet::CL1Cache133MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache133MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK3_XECORE0", "LOAD STORE CACHE BYTE READ BANK3 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK3_XECORE0", "SLM BYTE READ BANK3 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a880540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8804d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108807d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890fb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890efa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890f7c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0089fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache134MetricSet::CL1Cache134MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache134MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK3_XECORE1", "LOAD STORE CACHE BYTE READ BANK3 XECORE1",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_BYTE_READ_BANK3_XECORE1", "SLM BYTE READ BANK3 XECORE1",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca804d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a807d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90fb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90efa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90f7c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache135MetricSet::CL1Cache135MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache135MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK3_XECORE2", "LOAD STORE CACHE BYTE READ BANK3 XECORE2",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_BYTE_READ_BANK3_XECORE2", "SLM BYTE READ BANK3 XECORE2",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac80540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc804d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec80452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c807d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90fb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90efa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90f7c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache136MetricSet::CL1Cache136MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache136MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK3_XECORE3", "LOAD STORE CACHE BYTE READ BANK3 XECORE3",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_BYTE_READ_BANK3_XECORE3", "SLM BYTE READ BANK3 XECORE3",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae80540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce804d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e807d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90fb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90efa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90f7c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache137MetricSet::CL1Cache137MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache137MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK0_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK0 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK0_XECORE0", "SLM BYTE WRITE BANK0 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10870105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache138MetricSet::CL1Cache138MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache138MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK0_XECORE1", "LOAD STORE CACHE BYTE WRITE BANK0 XECORE1",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK0_XECORE1", "SLM BYTE WRITE BANK0 XECORE1",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache139MetricSet::CL1Cache139MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache139MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK0_XECORE2", "LOAD STORE CACHE BYTE WRITE BANK0 XECORE2",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK0_XECORE2", "SLM BYTE WRITE BANK0 XECORE2",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache140MetricSet::CL1Cache140MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache140MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK0_XECORE3", "LOAD STORE CACHE BYTE WRITE BANK0 XECORE3",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK0_XECORE3", "SLM BYTE WRITE BANK0 XECORE3",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache141MetricSet::CL1Cache141MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache141MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK1_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK1 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK1_XECORE0", "SLM BYTE WRITE BANK1 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10870515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890790, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890513, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache142MetricSet::CL1Cache142MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache142MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK1_XECORE1", "LOAD STORE CACHE BYTE WRITE BANK1 XECORE1",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK1_XECORE1", "SLM BYTE WRITE BANK1 XECORE1",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a70493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a70411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90790, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90513, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache143MetricSet::CL1Cache143MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache143MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK1_XECORE2", "LOAD STORE CACHE BYTE WRITE BANK1 XECORE2",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK1_XECORE2", "SLM BYTE WRITE BANK1 XECORE2",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec70580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c70515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c70493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c70411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90790, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90513, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache144MetricSet::CL1Cache144MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache144MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK1_XECORE3", "LOAD STORE CACHE BYTE WRITE BANK1 XECORE3",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK1_XECORE3", "SLM BYTE WRITE BANK1 XECORE3",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e70411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90790, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90513, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache145MetricSet::CL1Cache145MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache145MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK2_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK2 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK2_XECORE0", "SLM BYTE WRITE BANK2 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22890c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a880180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c880105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10880001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890ba0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088908a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890923, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8909a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0089fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache146MetricSet::CL1Cache146MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache146MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK2_XECORE1", "LOAD STORE CACHE BYTE WRITE BANK2 XECORE1",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK2_XECORE1", "SLM BYTE WRITE BANK2 XECORE1",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca80105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a80001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90ba0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a908a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90923, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca909a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache147MetricSet::CL1Cache147MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache147MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK2_XECORE2", "LOAD STORE CACHE BYTE WRITE BANK2 XECORE2",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK2_XECORE2", "SLM BYTE WRITE BANK2 XECORE2",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac80180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc80105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec80083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c80001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90ba0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c908a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90923, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc909a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache148MetricSet::CL1Cache148MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache148MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK2_XECORE3", "LOAD STORE CACHE BYTE WRITE BANK2 XECORE3",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK2_XECORE3", "SLM BYTE WRITE BANK2 XECORE3",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae80180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce80105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e80001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90ba0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e908a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90923, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce909a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache149MetricSet::CL1Cache149MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache149MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK3_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK3 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK3_XECORE0", "SLM BYTE WRITE BANK3 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a880580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c880515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10880411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890fb0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0089fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache150MetricSet::CL1Cache150MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache150MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK3_XECORE1", "LOAD STORE CACHE BYTE WRITE BANK3 XECORE1",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK3_XECORE1", "SLM BYTE WRITE BANK3 XECORE1",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca80515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a80411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90fb0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache151MetricSet::CL1Cache151MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache151MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK3_XECORE2", "LOAD STORE CACHE BYTE WRITE BANK3 XECORE2",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK3_XECORE2", "SLM BYTE WRITE BANK3 XECORE2",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac80580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc80515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec80493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c80411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90fb0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache152MetricSet::CL1Cache152MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache152MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK3_XECORE3", "LOAD STORE CACHE BYTE WRITE BANK3 XECORE3",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK3_XECORE3", "SLM BYTE WRITE BANK3 XECORE3",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae80580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce80515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e80411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90fb0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache153MetricSet::CL1Cache153MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache153MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE0", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE0",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE1", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE1",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE2", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE2",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE3", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE3",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache154MetricSet::CL1Cache154MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache154MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE4", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE4",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE5", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE5",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE6", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE6",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE7", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE7",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache155MetricSet::CL1Cache155MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache155MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE8", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE8",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE9", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE9",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE10", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE10",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE11", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE11",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache156MetricSet::CL1Cache156MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache156MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE12", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE12",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE13", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE13",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE14", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE14",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE15", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE15",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache1MetricSet::CL3Cache1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK0", "L3 BANK INPUT AVAILABLE L3BANK0",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK1", "L3 BANK INPUT AVAILABLE L3BANK1",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK2", "L3 BANK INPUT AVAILABLE L3BANK2",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK3", "L3 BANK INPUT AVAILABLE L3BANK3",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK4", "L3 BANK INPUT AVAILABLE L3BANK4",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK5", "L3 BANK INPUT AVAILABLE L3BANK5",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK6", "L3 BANK INPUT AVAILABLE L3BANK6",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK7", "L3 BANK INPUT AVAILABLE L3BANK7",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK0", "L3 OUTPUT READY L3BANK0",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK1", "L3 OUTPUT READY L3BANK1",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK2", "L3 OUTPUT READY L3BANK2",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK3", "L3 OUTPUT READY L3BANK3",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK4", "L3 OUTPUT READY L3BANK4",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK5", "L3 OUTPUT READY L3BANK5",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK6", "L3 OUTPUT READY L3BANK6",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK7", "L3 OUTPUT READY L3BANK7",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache2MetricSet::CL3Cache2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK8", "L3 BANK INPUT AVAILABLE L3BANK8",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK9", "L3 BANK INPUT AVAILABLE L3BANK9",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK10", "L3 BANK INPUT AVAILABLE L3BANK10",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK11", "L3 BANK INPUT AVAILABLE L3BANK11",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK12", "L3 BANK INPUT AVAILABLE L3BANK12",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK13", "L3 BANK INPUT AVAILABLE L3BANK13",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK14", "L3 BANK INPUT AVAILABLE L3BANK14",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK15", "L3 BANK INPUT AVAILABLE L3BANK15",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK8", "L3 OUTPUT READY L3BANK8",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK9", "L3 OUTPUT READY L3BANK9",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK10", "L3 OUTPUT READY L3BANK10",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK11", "L3 OUTPUT READY L3BANK11",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK12", "L3 OUTPUT READY L3BANK12",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK13", "L3 OUTPUT READY L3BANK13",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK14", "L3 OUTPUT READY L3BANK14",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK15", "L3 OUTPUT READY L3BANK15",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache3MetricSet::CL3Cache3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK0", "L3 READ L3BANK0",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK1", "L3 READ L3BANK1",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK2", "L3 READ L3BANK2",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK3", "L3 READ L3BANK3",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK4", "L3 READ L3BANK4",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK5", "L3 READ L3BANK5",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK6", "L3 READ L3BANK6",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK7", "L3 READ L3BANK7",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK0", "L3 WRITE L3BANK0",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK1", "L3 WRITE L3BANK1",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK2", "L3 WRITE L3BANK2",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK3", "L3 WRITE L3BANK3",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK4", "L3 WRITE L3BANK4",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK5", "L3 WRITE L3BANK5",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK6", "L3 WRITE L3BANK6",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK7", "L3 WRITE L3BANK7",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b6005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c6140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache4MetricSet::CL3Cache4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK8", "L3 READ L3BANK8",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK9", "L3 READ L3BANK9",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK10", "L3 READ L3BANK10",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK11", "L3 READ L3BANK11",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK12", "L3 READ L3BANK12",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK13", "L3 READ L3BANK13",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK14", "L3 READ L3BANK14",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK15", "L3 READ L3BANK15",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK8", "L3 WRITE L3BANK8",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK9", "L3 WRITE L3BANK9",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK10", "L3 WRITE L3BANK10",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK11", "L3 WRITE L3BANK11",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK12", "L3 WRITE L3BANK12",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK13", "L3 WRITE L3BANK13",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK14", "L3 WRITE L3BANK14",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK15", "L3 WRITE L3BANK15",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b6005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c6140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache5MetricSet::CL3Cache5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK0", "L3 HIT L3BANK0",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK1", "L3 HIT L3BANK1",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK2", "L3 HIT L3BANK2",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK3", "L3 HIT L3BANK3",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK4", "L3 HIT L3BANK4",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK5", "L3 HIT L3BANK5",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK6", "L3 HIT L3BANK6",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK7", "L3 HIT L3BANK7",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK0", "L3 MISS L3BANK0",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK1", "L3 MISS L3BANK1",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK2", "L3 MISS L3BANK2",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK3", "L3 MISS L3BANK3",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK4", "L3 MISS L3BANK4",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK5", "L3 MISS L3BANK5",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK6", "L3 MISS L3BANK6",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK7", "L3 MISS L3BANK7",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b2001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c2040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache6MetricSet::CL3Cache6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK8", "L3 HIT L3BANK8",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK9", "L3 HIT L3BANK9",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK10", "L3 HIT L3BANK10",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK11", "L3 HIT L3BANK11",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK12", "L3 HIT L3BANK12",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK13", "L3 HIT L3BANK13",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK14", "L3 HIT L3BANK14",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK15", "L3 HIT L3BANK15",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK8", "L3 MISS L3BANK8",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK9", "L3 MISS L3BANK9",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK10", "L3 MISS L3BANK10",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK11", "L3 MISS L3BANK11",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK12", "L3 MISS L3BANK12",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK13", "L3 MISS L3BANK13",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK14", "L3 MISS L3BANK14",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK15", "L3 MISS L3BANK15",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b2001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c2040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache7MetricSet::CL3Cache7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK0", "DATAPORT L3 READ L3BANK0",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK1", "DATAPORT L3 READ L3BANK1",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK2", "DATAPORT L3 READ L3BANK2",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK3", "DATAPORT L3 READ L3BANK3",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK4", "DATAPORT L3 READ L3BANK4",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK5", "DATAPORT L3 READ L3BANK5",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK6", "DATAPORT L3 READ L3BANK6",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK7", "DATAPORT L3 READ L3BANK7",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK0", "DATAPORT L3 WRITE L3BANK0",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK1", "DATAPORT L3 WRITE L3BANK1",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK2", "DATAPORT L3 WRITE L3BANK2",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK3", "DATAPORT L3 WRITE L3BANK3",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK4", "DATAPORT L3 WRITE L3BANK4",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK5", "DATAPORT L3 WRITE L3BANK5",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK6", "DATAPORT L3 WRITE L3BANK6",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK7", "DATAPORT L3 WRITE L3BANK7",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache8MetricSet::CL3Cache8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK8", "DATAPORT L3 READ L3BANK8",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK9", "DATAPORT L3 READ L3BANK9",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK10", "DATAPORT L3 READ L3BANK10",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK11", "DATAPORT L3 READ L3BANK11",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK12", "DATAPORT L3 READ L3BANK12",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK13", "DATAPORT L3 READ L3BANK13",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK14", "DATAPORT L3 READ L3BANK14",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK15", "DATAPORT L3 READ L3BANK15",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK8", "DATAPORT L3 WRITE L3BANK8",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK9", "DATAPORT L3 WRITE L3BANK9",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK10", "DATAPORT L3 WRITE L3BANK10",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK11", "DATAPORT L3 WRITE L3BANK11",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK12", "DATAPORT L3 WRITE L3BANK12",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK13", "DATAPORT L3 WRITE L3BANK13",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK14", "DATAPORT L3 WRITE L3BANK14",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK15", "DATAPORT L3 WRITE L3BANK15",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache9MetricSet::CL3Cache9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK0", "ICACHE L3 READ L3BANK0",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK1", "ICACHE L3 READ L3BANK1",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK2", "ICACHE L3 READ L3BANK2",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK3", "ICACHE L3 READ L3BANK3",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK4", "ICACHE L3 READ L3BANK4",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK5", "ICACHE L3 READ L3BANK5",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK6", "ICACHE L3 READ L3BANK6",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK7", "ICACHE L3 READ L3BANK7",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK0", "ICACHE L3 HIT L3BANK0",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK1", "ICACHE L3 HIT L3BANK1",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK2", "ICACHE L3 HIT L3BANK2",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK3", "ICACHE L3 HIT L3BANK3",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK4", "ICACHE L3 HIT L3BANK4",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK5", "ICACHE L3 HIT L3BANK5",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK6", "ICACHE L3 HIT L3BANK6",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK7", "ICACHE L3 HIT L3BANK7",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache10MetricSet::CL3Cache10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK8", "ICACHE L3 READ L3BANK8",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK9", "ICACHE L3 READ L3BANK9",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK10", "ICACHE L3 READ L3BANK10",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK11", "ICACHE L3 READ L3BANK11",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK12", "ICACHE L3 READ L3BANK12",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK13", "ICACHE L3 READ L3BANK13",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK14", "ICACHE L3 READ L3BANK14",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK15", "ICACHE L3 READ L3BANK15",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK8", "ICACHE L3 HIT L3BANK8",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK9", "ICACHE L3 HIT L3BANK9",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK10", "ICACHE L3 HIT L3BANK10",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK11", "ICACHE L3 HIT L3BANK11",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK12", "ICACHE L3 HIT L3BANK12",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK13", "ICACHE L3 HIT L3BANK13",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK14", "ICACHE L3 HIT L3BANK14",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK15", "ICACHE L3 HIT L3BANK15",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache11MetricSet::CL3Cache11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK0", "L3 BANK ACTIVE L3BANK0",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK1", "L3 BANK ACTIVE L3BANK1",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK2", "L3 BANK ACTIVE L3BANK2",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK3", "L3 BANK ACTIVE L3BANK3",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK0", "L3 BANK STALL L3BANK0",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK1", "L3 BANK STALL L3BANK1",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK2", "L3 BANK STALL L3BANK2",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK3", "L3 BANK STALL L3BANK3",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0006a015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085a95, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031809, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache12MetricSet::CL3Cache12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK4", "L3 BANK ACTIVE L3BANK4",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK5", "L3 BANK ACTIVE L3BANK5",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK6", "L3 BANK ACTIVE L3BANK6",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK7", "L3 BANK ACTIVE L3BANK7",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK4", "L3 BANK STALL L3BANK4",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK5", "L3 BANK STALL L3BANK5",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK6", "L3 BANK STALL L3BANK6",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK7", "L3 BANK STALL L3BANK7",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x134b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f6b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x054c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x134c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003a015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004a56a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02049bfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache13MetricSet::CL3Cache13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK8", "L3 BANK ACTIVE L3BANK8",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK9", "L3 BANK ACTIVE L3BANK9",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK10", "L3 BANK ACTIVE L3BANK10",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK11", "L3 BANK ACTIVE L3BANK11",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK8", "L3 BANK STALL L3BANK8",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK9", "L3 BANK STALL L3BANK9",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK10", "L3 BANK STALL L3BANK10",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK11", "L3 BANK STALL L3BANK11",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0006a015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085a95, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031809, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache14MetricSet::CL3Cache14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK12", "L3 BANK ACTIVE L3BANK12",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK13", "L3 BANK ACTIVE L3BANK13",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK14", "L3 BANK ACTIVE L3BANK14",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK15", "L3 BANK ACTIVE L3BANK15",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK12", "L3 BANK STALL L3BANK12",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK13", "L3 BANK STALL L3BANK13",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK14", "L3 BANK STALL L3BANK14",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK15", "L3 BANK STALL L3BANK15",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x134b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f6b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x054c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x134c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003a015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004a56a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02049bfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache15MetricSet::CL3Cache15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK0", "SAMPLER L3 READ L3BANK0",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK1", "SAMPLER L3 READ L3BANK1",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK2", "SAMPLER L3 READ L3BANK2",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK3", "SAMPLER L3 READ L3BANK3",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK4", "SAMPLER L3 READ L3BANK4",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK5", "SAMPLER L3 READ L3BANK5",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK6", "SAMPLER L3 READ L3BANK6",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK7", "SAMPLER L3 READ L3BANK7",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK0", "SAMPLER L3 HIT L3BANK0",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK1", "SAMPLER L3 HIT L3BANK1",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK2", "SAMPLER L3 HIT L3BANK2",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK3", "SAMPLER L3 HIT L3BANK3",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK4", "SAMPLER L3 HIT L3BANK4",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK5", "SAMPLER L3 HIT L3BANK5",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK6", "SAMPLER L3 HIT L3BANK6",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK7", "SAMPLER L3 HIT L3BANK7",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache16MetricSet::CL3Cache16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK8", "SAMPLER L3 READ L3BANK8",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK9", "SAMPLER L3 READ L3BANK9",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK10", "SAMPLER L3 READ L3BANK10",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK11", "SAMPLER L3 READ L3BANK11",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK12", "SAMPLER L3 READ L3BANK12",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK13", "SAMPLER L3 READ L3BANK13",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK14", "SAMPLER L3 READ L3BANK14",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK15", "SAMPLER L3 READ L3BANK15",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK8", "SAMPLER L3 HIT L3BANK8",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK9", "SAMPLER L3 HIT L3BANK9",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK10", "SAMPLER L3 HIT L3BANK10",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK11", "SAMPLER L3 HIT L3BANK11",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK12", "SAMPLER L3 HIT L3BANK12",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK13", "SAMPLER L3 HIT L3BANK13",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK14", "SAMPLER L3 HIT L3BANK14",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK15", "SAMPLER L3 HIT L3BANK15",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache17MetricSet::CL3Cache17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK0", "L3 SUPERQ FULL L3BANK0",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK1", "L3 SUPERQ FULL L3BANK1",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK2", "L3 SUPERQ FULL L3BANK2",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK3", "L3 SUPERQ FULL L3BANK3",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK4", "L3 SUPERQ FULL L3BANK4",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK5", "L3 SUPERQ FULL L3BANK5",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK6", "L3 SUPERQ FULL L3BANK6",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK7", "L3 SUPERQ FULL L3BANK7",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c1183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204fa5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000500a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f5a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031c24, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache18MetricSet::CL3Cache18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK8", "L3 SUPERQ FULL L3BANK8",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK9", "L3 SUPERQ FULL L3BANK9",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK10", "L3 SUPERQ FULL L3BANK10",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK11", "L3 SUPERQ FULL L3BANK11",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK12", "L3 SUPERQ FULL L3BANK12",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK13", "L3 SUPERQ FULL L3BANK13",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK14", "L3 SUPERQ FULL L3BANK14",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK15", "L3 SUPERQ FULL L3BANK15",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c1183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204fa5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000500a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f5a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031c24, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache19MetricSet::CL3Cache19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK0", "COLOR L3 HIT L3BANK0",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK1", "COLOR L3 HIT L3BANK1",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK2", "COLOR L3 HIT L3BANK2",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK3", "COLOR L3 HIT L3BANK3",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK4", "COLOR L3 HIT L3BANK4",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK5", "COLOR L3 HIT L3BANK5",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK6", "COLOR L3 HIT L3BANK6",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK7", "COLOR L3 HIT L3BANK7",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK8", "COLOR L3 HIT L3BANK8",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK9", "COLOR L3 HIT L3BANK9",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK10", "COLOR L3 HIT L3BANK10",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK11", "COLOR L3 HIT L3BANK11",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK12", "COLOR L3 HIT L3BANK12",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK13", "COLOR L3 HIT L3BANK13",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK14", "COLOR L3 HIT L3BANK14",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK15", "COLOR L3 HIT L3BANK15",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache20MetricSet::CL3Cache20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK0", "Z L3 HIT L3BANK0",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK1", "Z L3 HIT L3BANK1",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK2", "Z L3 HIT L3BANK2",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK3", "Z L3 HIT L3BANK3",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK4", "Z L3 HIT L3BANK4",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK5", "Z L3 HIT L3BANK5",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK6", "Z L3 HIT L3BANK6",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK7", "Z L3 HIT L3BANK7",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK8", "Z L3 HIT L3BANK8",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK9", "Z L3 HIT L3BANK9",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK10", "Z L3 HIT L3BANK10",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK11", "Z L3 HIT L3BANK11",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK12", "Z L3 HIT L3BANK12",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK13", "Z L3 HIT L3BANK13",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK14", "Z L3 HIT L3BANK14",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK15", "Z L3 HIT L3BANK15",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache21MetricSet::CL3Cache21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK0", "DATAPORT L3 HIT L3BANK0",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK1", "DATAPORT L3 HIT L3BANK1",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK2", "DATAPORT L3 HIT L3BANK2",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK3", "DATAPORT L3 HIT L3BANK3",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK4", "DATAPORT L3 HIT L3BANK4",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK5", "DATAPORT L3 HIT L3BANK5",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK6", "DATAPORT L3 HIT L3BANK6",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK7", "DATAPORT L3 HIT L3BANK7",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK8", "DATAPORT L3 HIT L3BANK8",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK9", "DATAPORT L3 HIT L3BANK9",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK10", "DATAPORT L3 HIT L3BANK10",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK11", "DATAPORT L3 HIT L3BANK11",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK12", "DATAPORT L3 HIT L3BANK12",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK13", "DATAPORT L3 HIT L3BANK13",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK14", "DATAPORT L3 HIT L3BANK14",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK15", "DATAPORT L3 HIT L3BANK15",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache22MetricSet::CL3Cache22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK0", "L3 ATOMIC ACCESS L3BANK0",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK1", "L3 ATOMIC ACCESS L3BANK1",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK2", "L3 ATOMIC ACCESS L3BANK2",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK3", "L3 ATOMIC ACCESS L3BANK3",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK4", "L3 ATOMIC ACCESS L3BANK4",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK5", "L3 ATOMIC ACCESS L3BANK5",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK6", "L3 ATOMIC ACCESS L3BANK6",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK7", "L3 ATOMIC ACCESS L3BANK7",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK8", "L3 ATOMIC ACCESS L3BANK8",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK9", "L3 ATOMIC ACCESS L3BANK9",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK10", "L3 ATOMIC ACCESS L3BANK10",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK11", "L3 ATOMIC ACCESS L3BANK11",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK12", "L3 ATOMIC ACCESS L3BANK12",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK13", "L3 ATOMIC ACCESS L3BANK13",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK14", "L3 ATOMIC ACCESS L3BANK14",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK15", "L3 ATOMIC ACCESS L3BANK15",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory1MetricSet::CMemory1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI0", "GPU MEMORY BYTE READ SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI1", "GPU MEMORY BYTE READ SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI2", "GPU MEMORY BYTE READ SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI3", "GPU MEMORY BYTE READ SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI0", "GPU MEMORY BYTE WRITE SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI1", "GPU MEMORY BYTE WRITE SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI2", "GPU MEMORY BYTE WRITE SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI3", "GPU MEMORY BYTE WRITE SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI0", "GPU MEMORY BYTE READ BW SQIDI0",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI0 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI1", "GPU MEMORY BYTE READ BW SQIDI1",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI1 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI2", "GPU MEMORY BYTE READ BW SQIDI2",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI2 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI3", "GPU MEMORY BYTE READ BW SQIDI3",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI3 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI0", "GPU MEMORY BYTE WRITE BW SQIDI0",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI0 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI1", "GPU MEMORY BYTE WRITE BW SQIDI1",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI1 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI2", "GPU MEMORY BYTE WRITE BW SQIDI2",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI2 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI3", "GPU MEMORY BYTE WRITE BW SQIDI3",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI3 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GPU_MEMORY_BYTE_READ_SQIDI0 $GPU_MEMORY_BYTE_READ_SQIDI1 UADD $GPU_MEMORY_BYTE_READ_SQIDI2 UADD $GPU_MEMORY_BYTE_READ_SQIDI3 UADD 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GPU_MEMORY_BYTE_WRITE_SQIDI0 $GPU_MEMORY_BYTE_WRITE_SQIDI1 UADD $GPU_MEMORY_BYTE_WRITE_SQIDI2 UADD $GPU_MEMORY_BYTE_WRITE_SQIDI3 UADD 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW", "GPU MEMORY BYTE READ BW",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBPS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW", "GPU MEMORY BYTE WRITE BW",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBPS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18413800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18613800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18813800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12410004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16410005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10610100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14610140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204b0b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090b0b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory2MetricSet::CMemory2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI0", "GPU MEMORY READ SQIDI0",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI1", "GPU MEMORY READ SQIDI1",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI2", "GPU MEMORY READ SQIDI2",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI3", "GPU MEMORY READ SQIDI3",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ", "GPU MEMORY READ",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_READ_SQIDI0 $$GPU_MEMORY_READ_SQIDI1 UADD $$GPU_MEMORY_READ_SQIDI2 UADD $$GPU_MEMORY_READ_SQIDI3 UADD" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18413800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a410140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18613800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a610140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18813800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a810140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14410180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1641000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1461000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a1000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020900af, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory3MetricSet::CMemory3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI0", "GPU MEMORY WRITE SQIDI0",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI1", "GPU MEMORY WRITE SQIDI1",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI2", "GPU MEMORY WRITE SQIDI2",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI3", "GPU MEMORY WRITE SQIDI3",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE", "GPU MEMORY WRITE",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_WRITE_SQIDI0 $$GPU_MEMORY_WRITE_SQIDI1 UADD $$GPU_MEMORY_WRITE_SQIDI2 UADD $$GPU_MEMORY_WRITE_SQIDI3 UADD" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HOST_TO_GPUMEM_TRANSACTION_READ", "HOST TO GPUMEM TRANSACTION READ",
                          "Number of host reads to GPU local (HBM) memory (downstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HOST_TO_GPUMEM_TRANSACTION_WRITE", "HOST TO GPUMEM TRANSACTION WRITE",
                          "Number of host writes to GPU local (HBM) memory (downstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100900ac, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a097ac0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18413800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18613800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18813800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16410007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x146101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory4MetricSet::CMemory4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI0", "GPU MEMORY 32B TRANSACTION READ SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI1", "GPU MEMORY 32B TRANSACTION READ SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI2", "GPU MEMORY 32B TRANSACTION READ SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI3", "GPU MEMORY 32B TRANSACTION READ SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI0", "GPU MEMORY 64B TRANSACTION READ SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI1", "GPU MEMORY 64B TRANSACTION READ SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI2", "GPU MEMORY 64B TRANSACTION READ SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI3", "GPU MEMORY 64B TRANSACTION READ SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10420251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10620251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a20251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0041c0c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06420207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e420185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00420000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00613030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04620207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c620185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00620000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810c0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a820185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900af, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020900af, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory5MetricSet::CMemory5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI0", "GPU MEMORY 32B TRANSACTION WRITE SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI1", "GPU MEMORY 32B TRANSACTION WRITE SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI2", "GPU MEMORY 32B TRANSACTION WRITE SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI3", "GPU MEMORY 32B TRANSACTION WRITE SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI0", "GPU MEMORY 64B TRANSACTION WRITE SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI1", "GPU MEMORY 64B TRANSACTION WRITE SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI2", "GPU MEMORY 64B TRANSACTION WRITE SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI3", "GPU MEMORY 64B TRANSACTION WRITE SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1042000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1062000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1082000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00418800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a420100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e420080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00420000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00614400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a620004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e620002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00620000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00812200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a11100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204b0b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090b0b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory6MetricSet::CMemory6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI0", "GPU MEMORY ACTIVE SQIDI0",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI1", "GPU MEMORY ACTIVE SQIDI1",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI2", "GPU MEMORY ACTIVE SQIDI2",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI3", "GPU MEMORY ACTIVE SQIDI3",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI0", "GPU MEMORY REQUEST QUEUE FULL SQIDI0",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI1", "GPU MEMORY REQUEST QUEUE FULL SQIDI1",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI2", "GPU MEMORY REQUEST QUEUE FULL SQIDI2",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI3", "GPU MEMORY REQUEST QUEUE FULL SQIDI3",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE", "GPU MEMORY ACTIVE",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GPU_MEMORY_ACTIVE_SQIDI0 $GPU_MEMORY_ACTIVE_SQIDI1 FADD $GPU_MEMORY_ACTIVE_SQIDI2 FADD $GPU_MEMORY_ACTIVE_SQIDI3 FADD 8 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL", "GPU MEMORY REQUEST QUEUE FULL",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI0 $GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI1 FADD $GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI2 FADD $GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI3 FADD 4 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1641034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a410140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16610340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a610140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a810140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12410002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10610080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14610380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204b0b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090b0b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory7MetricSet::CMemory7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI0", "GPU MEMORY L3 WRITE SQIDI0",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SYSMEM_TRANSACTION_READ", "SYSMEM TRANSACTION READ",
                          "Number of system memory reads (upstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SYSMEM_TRANSACTION_WRITE", "SYSMEM TRANSACTION WRITE",
                          "Number of system memory writes (upstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c095000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18413800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a41000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06411c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08410248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c41034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory8MetricSet::CMemory8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI1", "GPU MEMORY L3 WRITE SQIDI1",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18613800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a61000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06611c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08610248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c61034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e6103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory9MetricSet::CMemory9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI2", "GPU MEMORY L3 WRITE SQIDI2",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18813800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c81034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory10MetricSet::CMemory10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI3", "GPU MEMORY L3 WRITE SQIDI3",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca1034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory11MetricSet::CMemory11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI0", "GPU MEMORY L3 READ SQIDI0",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a412540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18613800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a61000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06411400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08410288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a41030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c41038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e41000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10610288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1261030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1461038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1661000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory12MetricSet::CMemory12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI1", "GPU MEMORY L3 READ SQIDI1",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18413800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a41000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a612540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e410180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10410288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1241030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1441038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1641000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06611400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08610288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a61030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c61038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e61000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory13MetricSet::CMemory13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI2", "GPU MEMORY L3 READ SQIDI2",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a812540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c81038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e81000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0209ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory14MetricSet::CMemory14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI3", "GPU MEMORY L3 READ SQIDI3",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18813800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa12540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1681000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa1030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca1038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0209aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRasterizer1MetricSet::CRasterizer1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRasterizer1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "RASTERIZER_SAMPLE_OUTPUT", "RASTERIZER SAMPLE OUTPUT",
                          "Number of lit samples emitted by Rasterizer",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x64:0xb5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE0", "RASTERIZER INPUT AVAILABLE SLICE0",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE1", "RASTERIZER INPUT AVAILABLE SLICE1",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE2", "RASTERIZER INPUT AVAILABLE SLICE2",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE3", "RASTERIZER INPUT AVAILABLE SLICE3",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE0", "RASTERIZER OUTPUT READY SLICE0",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE1", "RASTERIZER OUTPUT READY SLICE1",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE2", "RASTERIZER OUTPUT READY SLICE2",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE3", "RASTERIZER OUTPUT READY SLICE3",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003400c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020530c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00068003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02087000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001400c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050c32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106400c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000310c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050c32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e050f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00062030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000110c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050c32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010610c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRasterizer2MetricSet::CRasterizer2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRasterizer2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE0", "RASTERIZER TRANSACTION OUTPUT SLICE0",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE1", "RASTERIZER TRANSACTION OUTPUT SLICE1",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE2", "RASTERIZER TRANSACTION OUTPUT SLICE2",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE3", "RASTERIZER TRANSACTION OUTPUT SLICE3",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0006c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01063000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208005f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing1MetricSet::CRayTracing1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE0", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE0",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE0", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE0",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE0", "RT TRAVERSAL INPUT RAY COUNT XECORE0",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE0", "RT QUAD TEST RAY COUNT XECORE0",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE0", "RT REQUEST COLLISION XECORE0",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE0", "RT INPUT MESSAGE RAY COUNT XECORE0",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE0", "RT MESSAGE STALL COUNT XECORE0",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE0", "RT TRANSFORM RAY COUNT XECORE0",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing2MetricSet::CRayTracing2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE1", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE1",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE1", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE1",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE1", "RT TRAVERSAL INPUT RAY COUNT XECORE1",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE1", "RT QUAD TEST RAY COUNT XECORE1",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE1", "RT REQUEST COLLISION XECORE1",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE1", "RT INPUT MESSAGE RAY COUNT XECORE1",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE1", "RT MESSAGE STALL COUNT XECORE1",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE1", "RT TRANSFORM RAY COUNT XECORE1",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing3MetricSet::CRayTracing3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE2", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE2",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE2", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE2",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE2", "RT TRAVERSAL INPUT RAY COUNT XECORE2",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE2", "RT QUAD TEST RAY COUNT XECORE2",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE2", "RT REQUEST COLLISION XECORE2",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE2", "RT INPUT MESSAGE RAY COUNT XECORE2",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE2", "RT MESSAGE STALL COUNT XECORE2",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE2", "RT TRANSFORM RAY COUNT XECORE2",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing4MetricSet::CRayTracing4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE3", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE3",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE3", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE3",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE3", "RT TRAVERSAL INPUT RAY COUNT XECORE3",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE3", "RT QUAD TEST RAY COUNT XECORE3",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE3", "RT REQUEST COLLISION XECORE3",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE3", "RT INPUT MESSAGE RAY COUNT XECORE3",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE3", "RT MESSAGE STALL COUNT XECORE3",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE3", "RT TRANSFORM RAY COUNT XECORE3",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing5MetricSet::CRayTracing5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE4", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE4",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE4", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE4",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE4", "RT TRAVERSAL INPUT RAY COUNT XECORE4",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE4", "RT QUAD TEST RAY COUNT XECORE4",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE4", "RT REQUEST COLLISION XECORE4",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE4", "RT INPUT MESSAGE RAY COUNT XECORE4",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE4", "RT MESSAGE STALL COUNT XECORE4",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE4", "RT TRANSFORM RAY COUNT XECORE4",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x118505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing6MetricSet::CRayTracing6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE5", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE5",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE5", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE5",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE5", "RT TRAVERSAL INPUT RAY COUNT XECORE5",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE5", "RT QUAD TEST RAY COUNT XECORE5",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE5", "RT REQUEST COLLISION XECORE5",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE5", "RT INPUT MESSAGE RAY COUNT XECORE5",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE5", "RT MESSAGE STALL COUNT XECORE5",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE5", "RT TRANSFORM RAY COUNT XECORE5",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing7MetricSet::CRayTracing7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE6", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE6",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE6", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE6",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE6", "RT TRAVERSAL INPUT RAY COUNT XECORE6",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE6", "RT QUAD TEST RAY COUNT XECORE6",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE6", "RT REQUEST COLLISION XECORE6",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE6", "RT INPUT MESSAGE RAY COUNT XECORE6",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE6", "RT MESSAGE STALL COUNT XECORE6",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE6", "RT TRANSFORM RAY COUNT XECORE6",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing8MetricSet::CRayTracing8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE7", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE7",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE7", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE7",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE7", "RT TRAVERSAL INPUT RAY COUNT XECORE7",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE7", "RT QUAD TEST RAY COUNT XECORE7",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE7", "RT REQUEST COLLISION XECORE7",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE7", "RT INPUT MESSAGE RAY COUNT XECORE7",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE7", "RT MESSAGE STALL COUNT XECORE7",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE7", "RT TRANSFORM RAY COUNT XECORE7",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing9MetricSet::CRayTracing9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE8", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE8",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE8", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE8",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE8", "RT TRAVERSAL INPUT RAY COUNT XECORE8",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE8", "RT QUAD TEST RAY COUNT XECORE8",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE8", "RT REQUEST COLLISION XECORE8",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE8", "RT INPUT MESSAGE RAY COUNT XECORE8",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE8", "RT MESSAGE STALL COUNT XECORE8",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE8", "RT TRANSFORM RAY COUNT XECORE8",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing10MetricSet::CRayTracing10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE9", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE9",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE9", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE9",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE9", "RT TRAVERSAL INPUT RAY COUNT XECORE9",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE9", "RT QUAD TEST RAY COUNT XECORE9",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE9", "RT REQUEST COLLISION XECORE9",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE9", "RT INPUT MESSAGE RAY COUNT XECORE9",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE9", "RT MESSAGE STALL COUNT XECORE9",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE9", "RT TRANSFORM RAY COUNT XECORE9",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing11MetricSet::CRayTracing11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE10", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE10",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE10", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE10",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE10", "RT TRAVERSAL INPUT RAY COUNT XECORE10",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE10", "RT QUAD TEST RAY COUNT XECORE10",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE10", "RT REQUEST COLLISION XECORE10",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE10", "RT INPUT MESSAGE RAY COUNT XECORE10",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE10", "RT MESSAGE STALL COUNT XECORE10",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE10", "RT TRANSFORM RAY COUNT XECORE10",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing12MetricSet::CRayTracing12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE11", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE11",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE11", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE11",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE11", "RT TRAVERSAL INPUT RAY COUNT XECORE11",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE11", "RT QUAD TEST RAY COUNT XECORE11",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE11", "RT REQUEST COLLISION XECORE11",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE11", "RT INPUT MESSAGE RAY COUNT XECORE11",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE11", "RT MESSAGE STALL COUNT XECORE11",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE11", "RT TRANSFORM RAY COUNT XECORE11",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing13MetricSet::CRayTracing13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE12", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE12",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE12", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE12",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE12", "RT TRAVERSAL INPUT RAY COUNT XECORE12",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE12", "RT QUAD TEST RAY COUNT XECORE12",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE12", "RT REQUEST COLLISION XECORE12",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE12", "RT INPUT MESSAGE RAY COUNT XECORE12",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE12", "RT MESSAGE STALL COUNT XECORE12",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE12", "RT TRANSFORM RAY COUNT XECORE12",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x118505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing14MetricSet::CRayTracing14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE13", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE13",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE13", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE13",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE13", "RT TRAVERSAL INPUT RAY COUNT XECORE13",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE13", "RT QUAD TEST RAY COUNT XECORE13",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE13", "RT REQUEST COLLISION XECORE13",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE13", "RT INPUT MESSAGE RAY COUNT XECORE13",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE13", "RT MESSAGE STALL COUNT XECORE13",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE13", "RT TRANSFORM RAY COUNT XECORE13",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing15MetricSet::CRayTracing15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE14", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE14",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE14", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE14",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE14", "RT TRAVERSAL INPUT RAY COUNT XECORE14",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE14", "RT QUAD TEST RAY COUNT XECORE14",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE14", "RT REQUEST COLLISION XECORE14",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE14", "RT INPUT MESSAGE RAY COUNT XECORE14",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE14", "RT MESSAGE STALL COUNT XECORE14",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE14", "RT TRANSFORM RAY COUNT XECORE14",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing16MetricSet::CRayTracing16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE15", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE15",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE15", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE15",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE15", "RT TRAVERSAL INPUT RAY COUNT XECORE15",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE15", "RT QUAD TEST RAY COUNT XECORE15",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE15", "RT REQUEST COLLISION XECORE15",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE15", "RT INPUT MESSAGE RAY COUNT XECORE15",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE15", "RT MESSAGE STALL COUNT XECORE15",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE15", "RT TRANSFORM RAY COUNT XECORE15",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing17MetricSet::CRayTracing17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE0", "RT INSTANCE NODE RAY COUNT XECORE0",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE0", "RT INTERNAL NODE RAY COUNT XECORE0",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE0", "RT TRAVERSAL STEP RAY COUNT XECORE0",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing18MetricSet::CRayTracing18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE1", "RT INSTANCE NODE RAY COUNT XECORE1",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE1", "RT INTERNAL NODE RAY COUNT XECORE1",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE1", "RT TRAVERSAL STEP RAY COUNT XECORE1",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing19MetricSet::CRayTracing19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE2", "RT INSTANCE NODE RAY COUNT XECORE2",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE2", "RT INTERNAL NODE RAY COUNT XECORE2",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE2", "RT TRAVERSAL STEP RAY COUNT XECORE2",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing20MetricSet::CRayTracing20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE3", "RT INSTANCE NODE RAY COUNT XECORE3",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE3", "RT INTERNAL NODE RAY COUNT XECORE3",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE3", "RT TRAVERSAL STEP RAY COUNT XECORE3",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing21MetricSet::CRayTracing21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE4", "RT INSTANCE NODE RAY COUNT XECORE4",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE4", "RT INTERNAL NODE RAY COUNT XECORE4",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE4", "RT TRAVERSAL STEP RAY COUNT XECORE4",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing22MetricSet::CRayTracing22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE5", "RT INSTANCE NODE RAY COUNT XECORE5",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE5", "RT INTERNAL NODE RAY COUNT XECORE5",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE5", "RT TRAVERSAL STEP RAY COUNT XECORE5",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing23MetricSet::CRayTracing23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE6", "RT INSTANCE NODE RAY COUNT XECORE6",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE6", "RT INTERNAL NODE RAY COUNT XECORE6",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE6", "RT TRAVERSAL STEP RAY COUNT XECORE6",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing24MetricSet::CRayTracing24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE7", "RT INSTANCE NODE RAY COUNT XECORE7",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE7", "RT INTERNAL NODE RAY COUNT XECORE7",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE7", "RT TRAVERSAL STEP RAY COUNT XECORE7",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing25MetricSet::CRayTracing25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE8", "RT INSTANCE NODE RAY COUNT XECORE8",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE8", "RT INTERNAL NODE RAY COUNT XECORE8",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE8", "RT TRAVERSAL STEP RAY COUNT XECORE8",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing26MetricSet::CRayTracing26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE9", "RT INSTANCE NODE RAY COUNT XECORE9",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE9", "RT INTERNAL NODE RAY COUNT XECORE9",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE9", "RT TRAVERSAL STEP RAY COUNT XECORE9",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing27MetricSet::CRayTracing27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE10", "RT INSTANCE NODE RAY COUNT XECORE10",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE10", "RT INTERNAL NODE RAY COUNT XECORE10",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE10", "RT TRAVERSAL STEP RAY COUNT XECORE10",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing28MetricSet::CRayTracing28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE11", "RT INSTANCE NODE RAY COUNT XECORE11",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE11", "RT INTERNAL NODE RAY COUNT XECORE11",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE11", "RT TRAVERSAL STEP RAY COUNT XECORE11",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing29MetricSet::CRayTracing29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE12", "RT INSTANCE NODE RAY COUNT XECORE12",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE12", "RT INTERNAL NODE RAY COUNT XECORE12",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE12", "RT TRAVERSAL STEP RAY COUNT XECORE12",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing30MetricSet::CRayTracing30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE13", "RT INSTANCE NODE RAY COUNT XECORE13",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE13", "RT INTERNAL NODE RAY COUNT XECORE13",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE13", "RT TRAVERSAL STEP RAY COUNT XECORE13",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing31MetricSet::CRayTracing31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE14", "RT INSTANCE NODE RAY COUNT XECORE14",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE14", "RT INTERNAL NODE RAY COUNT XECORE14",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE14", "RT TRAVERSAL STEP RAY COUNT XECORE14",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing32MetricSet::CRayTracing32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE15", "RT INSTANCE NODE RAY COUNT XECORE15",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE15", "RT INTERNAL NODE RAY COUNT XECORE15",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE15", "RT TRAVERSAL STEP RAY COUNT XECORE15",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing33MetricSet::CRayTracing33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE0", "RT QUAD LEAF RAY COUNT XECORE0",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE0", "RT PROCEDURAL NODE RAY COUNT XECORE0",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing34MetricSet::CRayTracing34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE1", "RT QUAD LEAF RAY COUNT XECORE1",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE1", "RT PROCEDURAL NODE RAY COUNT XECORE1",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing35MetricSet::CRayTracing35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE2", "RT QUAD LEAF RAY COUNT XECORE2",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE2", "RT PROCEDURAL NODE RAY COUNT XECORE2",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing36MetricSet::CRayTracing36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE3", "RT QUAD LEAF RAY COUNT XECORE3",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE3", "RT PROCEDURAL NODE RAY COUNT XECORE3",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing37MetricSet::CRayTracing37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE4", "RT QUAD LEAF RAY COUNT XECORE4",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE4", "RT PROCEDURAL NODE RAY COUNT XECORE4",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing38MetricSet::CRayTracing38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE5", "RT QUAD LEAF RAY COUNT XECORE5",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE5", "RT PROCEDURAL NODE RAY COUNT XECORE5",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing39MetricSet::CRayTracing39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE6", "RT QUAD LEAF RAY COUNT XECORE6",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE6", "RT PROCEDURAL NODE RAY COUNT XECORE6",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing40MetricSet::CRayTracing40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE7", "RT QUAD LEAF RAY COUNT XECORE7",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE7", "RT PROCEDURAL NODE RAY COUNT XECORE7",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing41MetricSet::CRayTracing41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE8", "RT QUAD LEAF RAY COUNT XECORE8",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE8", "RT PROCEDURAL NODE RAY COUNT XECORE8",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing42MetricSet::CRayTracing42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE9", "RT QUAD LEAF RAY COUNT XECORE9",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE9", "RT PROCEDURAL NODE RAY COUNT XECORE9",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing43MetricSet::CRayTracing43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE10", "RT QUAD LEAF RAY COUNT XECORE10",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE10", "RT PROCEDURAL NODE RAY COUNT XECORE10",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing44MetricSet::CRayTracing44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE11", "RT QUAD LEAF RAY COUNT XECORE11",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE11", "RT PROCEDURAL NODE RAY COUNT XECORE11",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing45MetricSet::CRayTracing45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE12", "RT QUAD LEAF RAY COUNT XECORE12",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE12", "RT PROCEDURAL NODE RAY COUNT XECORE12",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing46MetricSet::CRayTracing46MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing46MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE13", "RT QUAD LEAF RAY COUNT XECORE13",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE13", "RT PROCEDURAL NODE RAY COUNT XECORE13",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing47MetricSet::CRayTracing47MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing47MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE14", "RT QUAD LEAF RAY COUNT XECORE14",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE14", "RT PROCEDURAL NODE RAY COUNT XECORE14",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing48MetricSet::CRayTracing48MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing48MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE15", "RT QUAD LEAF RAY COUNT XECORE15",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE15", "RT PROCEDURAL NODE RAY COUNT XECORE15",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing49MetricSet::CRayTracing49MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing49MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE0", "RT TRAVERSAL OUTPUT RAY COUNT XECORE0",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE1", "RT TRAVERSAL OUTPUT RAY COUNT XECORE1",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE2", "RT TRAVERSAL OUTPUT RAY COUNT XECORE2",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE3", "RT TRAVERSAL OUTPUT RAY COUNT XECORE3",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing50MetricSet::CRayTracing50MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing50MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE4", "RT TRAVERSAL OUTPUT RAY COUNT XECORE4",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE5", "RT TRAVERSAL OUTPUT RAY COUNT XECORE5",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE6", "RT TRAVERSAL OUTPUT RAY COUNT XECORE6",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE7", "RT TRAVERSAL OUTPUT RAY COUNT XECORE7",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing51MetricSet::CRayTracing51MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing51MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE8", "RT TRAVERSAL OUTPUT RAY COUNT XECORE8",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE9", "RT TRAVERSAL OUTPUT RAY COUNT XECORE9",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE10", "RT TRAVERSAL OUTPUT RAY COUNT XECORE10",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE11", "RT TRAVERSAL OUTPUT RAY COUNT XECORE11",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing52MetricSet::CRayTracing52MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing52MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE12", "RT TRAVERSAL OUTPUT RAY COUNT XECORE12",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE13", "RT TRAVERSAL OUTPUT RAY COUNT XECORE13",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE14", "RT TRAVERSAL OUTPUT RAY COUNT XECORE14",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE15", "RT TRAVERSAL OUTPUT RAY COUNT XECORE15",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing53MetricSet::CRayTracing53MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing53MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE0", "RT ANY HIT THREAD RAY DISPATCH XECORE0",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE1", "RT ANY HIT THREAD RAY DISPATCH XECORE1",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE2", "RT ANY HIT THREAD RAY DISPATCH XECORE2",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE3", "RT ANY HIT THREAD RAY DISPATCH XECORE3",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing54MetricSet::CRayTracing54MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing54MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE4", "RT ANY HIT THREAD RAY DISPATCH XECORE4",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE5", "RT ANY HIT THREAD RAY DISPATCH XECORE5",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE6", "RT ANY HIT THREAD RAY DISPATCH XECORE6",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE7", "RT ANY HIT THREAD RAY DISPATCH XECORE7",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing55MetricSet::CRayTracing55MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing55MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE8", "RT ANY HIT THREAD RAY DISPATCH XECORE8",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE9", "RT ANY HIT THREAD RAY DISPATCH XECORE9",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE10", "RT ANY HIT THREAD RAY DISPATCH XECORE10",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE11", "RT ANY HIT THREAD RAY DISPATCH XECORE11",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing56MetricSet::CRayTracing56MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing56MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE12", "RT ANY HIT THREAD RAY DISPATCH XECORE12",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE13", "RT ANY HIT THREAD RAY DISPATCH XECORE13",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE14", "RT ANY HIT THREAD RAY DISPATCH XECORE14",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE15", "RT ANY HIT THREAD RAY DISPATCH XECORE15",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing57MetricSet::CRayTracing57MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing57MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE0", "RT CALLABLE THREAD RAY DISPATCH XECORE0",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE1", "RT CALLABLE THREAD RAY DISPATCH XECORE1",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE2", "RT CALLABLE THREAD RAY DISPATCH XECORE2",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE3", "RT CALLABLE THREAD RAY DISPATCH XECORE3",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing58MetricSet::CRayTracing58MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing58MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE4", "RT CALLABLE THREAD RAY DISPATCH XECORE4",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE5", "RT CALLABLE THREAD RAY DISPATCH XECORE5",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE6", "RT CALLABLE THREAD RAY DISPATCH XECORE6",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE7", "RT CALLABLE THREAD RAY DISPATCH XECORE7",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing59MetricSet::CRayTracing59MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing59MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE8", "RT CALLABLE THREAD RAY DISPATCH XECORE8",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE9", "RT CALLABLE THREAD RAY DISPATCH XECORE9",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE10", "RT CALLABLE THREAD RAY DISPATCH XECORE10",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE11", "RT CALLABLE THREAD RAY DISPATCH XECORE11",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing60MetricSet::CRayTracing60MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing60MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE12", "RT CALLABLE THREAD RAY DISPATCH XECORE12",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE13", "RT CALLABLE THREAD RAY DISPATCH XECORE13",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE14", "RT CALLABLE THREAD RAY DISPATCH XECORE14",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE15", "RT CALLABLE THREAD RAY DISPATCH XECORE15",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing61MetricSet::CRayTracing61MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing61MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE0", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE0",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE1", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE1",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE2", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE2",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE3", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE3",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing62MetricSet::CRayTracing62MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing62MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE4", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE4",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE5", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE5",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE6", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE6",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE7", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE7",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing63MetricSet::CRayTracing63MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing63MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE8", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE8",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE9", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE9",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE10", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE10",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE11", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE11",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing64MetricSet::CRayTracing64MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing64MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE12", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE12",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE13", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE13",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE14", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE14",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE15", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE15",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing65MetricSet::CRayTracing65MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing65MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE0", "RT INTERSECTION THREAD RAY DISPATCH XECORE0",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE1", "RT INTERSECTION THREAD RAY DISPATCH XECORE1",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE2", "RT INTERSECTION THREAD RAY DISPATCH XECORE2",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE3", "RT INTERSECTION THREAD RAY DISPATCH XECORE3",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing66MetricSet::CRayTracing66MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing66MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE4", "RT INTERSECTION THREAD RAY DISPATCH XECORE4",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE5", "RT INTERSECTION THREAD RAY DISPATCH XECORE5",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE6", "RT INTERSECTION THREAD RAY DISPATCH XECORE6",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE7", "RT INTERSECTION THREAD RAY DISPATCH XECORE7",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing67MetricSet::CRayTracing67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE8", "RT INTERSECTION THREAD RAY DISPATCH XECORE8",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE9", "RT INTERSECTION THREAD RAY DISPATCH XECORE9",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE10", "RT INTERSECTION THREAD RAY DISPATCH XECORE10",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE11", "RT INTERSECTION THREAD RAY DISPATCH XECORE11",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing68MetricSet::CRayTracing68MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing68MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE12", "RT INTERSECTION THREAD RAY DISPATCH XECORE12",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE13", "RT INTERSECTION THREAD RAY DISPATCH XECORE13",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE14", "RT INTERSECTION THREAD RAY DISPATCH XECORE14",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE15", "RT INTERSECTION THREAD RAY DISPATCH XECORE15",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing69MetricSet::CRayTracing69MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing69MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE0", "RT MISS THREAD RAY DISPATCH XECORE0",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE1", "RT MISS THREAD RAY DISPATCH XECORE1",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE2", "RT MISS THREAD RAY DISPATCH XECORE2",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE3", "RT MISS THREAD RAY DISPATCH XECORE3",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing70MetricSet::CRayTracing70MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing70MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE4", "RT MISS THREAD RAY DISPATCH XECORE4",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE5", "RT MISS THREAD RAY DISPATCH XECORE5",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE6", "RT MISS THREAD RAY DISPATCH XECORE6",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE7", "RT MISS THREAD RAY DISPATCH XECORE7",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing71MetricSet::CRayTracing71MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing71MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE8", "RT MISS THREAD RAY DISPATCH XECORE8",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE9", "RT MISS THREAD RAY DISPATCH XECORE9",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE10", "RT MISS THREAD RAY DISPATCH XECORE10",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE11", "RT MISS THREAD RAY DISPATCH XECORE11",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing72MetricSet::CRayTracing72MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing72MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE12", "RT MISS THREAD RAY DISPATCH XECORE12",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE13", "RT MISS THREAD RAY DISPATCH XECORE13",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE14", "RT MISS THREAD RAY DISPATCH XECORE14",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE15", "RT MISS THREAD RAY DISPATCH XECORE15",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing73MetricSet::CRayTracing73MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing73MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE0", "RT BVH CACHE MISS XECORE0",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE1", "RT BVH CACHE MISS XECORE1",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE2", "RT BVH CACHE MISS XECORE2",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE3", "RT BVH CACHE MISS XECORE3",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing74MetricSet::CRayTracing74MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing74MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE4", "RT BVH CACHE MISS XECORE4",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE5", "RT BVH CACHE MISS XECORE5",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE6", "RT BVH CACHE MISS XECORE6",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE7", "RT BVH CACHE MISS XECORE7",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing75MetricSet::CRayTracing75MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing75MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE8", "RT BVH CACHE MISS XECORE8",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE9", "RT BVH CACHE MISS XECORE9",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE10", "RT BVH CACHE MISS XECORE10",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE11", "RT BVH CACHE MISS XECORE11",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing76MetricSet::CRayTracing76MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing76MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE12", "RT BVH CACHE MISS XECORE12",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE13", "RT BVH CACHE MISS XECORE13",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE14", "RT BVH CACHE MISS XECORE14",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE15", "RT BVH CACHE MISS XECORE15",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing77MetricSet::CRayTracing77MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing77MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE0", "RT INPUT AVAILABLE XECORE0",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE1", "RT INPUT AVAILABLE XECORE1",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE2", "RT INPUT AVAILABLE XECORE2",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE3", "RT INPUT AVAILABLE XECORE3",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE4", "RT INPUT AVAILABLE XECORE4",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE5", "RT INPUT AVAILABLE XECORE5",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE6", "RT INPUT AVAILABLE XECORE6",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE7", "RT INPUT AVAILABLE XECORE7",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04850c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000065, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000185, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000605, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001805, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing78MetricSet::CRayTracing78MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing78MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE8", "RT INPUT AVAILABLE XECORE8",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE9", "RT INPUT AVAILABLE XECORE9",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE10", "RT INPUT AVAILABLE XECORE10",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE11", "RT INPUT AVAILABLE XECORE11",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE12", "RT INPUT AVAILABLE XECORE12",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE13", "RT INPUT AVAILABLE XECORE13",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE14", "RT INPUT AVAILABLE XECORE14",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE15", "RT INPUT AVAILABLE XECORE15",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04850c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000065, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000185, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000605, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001805, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler1MetricSet::CSampler1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE0", "SAMPLER OUTPUT READY XECORE0",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE1", "SAMPLER OUTPUT READY XECORE1",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE2", "SAMPLER OUTPUT READY XECORE2",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE3", "SAMPLER OUTPUT READY XECORE3",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler2MetricSet::CSampler2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE4", "SAMPLER OUTPUT READY XECORE4",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE5", "SAMPLER OUTPUT READY XECORE5",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE6", "SAMPLER OUTPUT READY XECORE6",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE7", "SAMPLER OUTPUT READY XECORE7",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler3MetricSet::CSampler3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE8", "SAMPLER OUTPUT READY XECORE8",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE9", "SAMPLER OUTPUT READY XECORE9",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE10", "SAMPLER OUTPUT READY XECORE10",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE11", "SAMPLER OUTPUT READY XECORE11",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler4MetricSet::CSampler4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE12", "SAMPLER OUTPUT READY XECORE12",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE13", "SAMPLER OUTPUT READY XECORE13",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE14", "SAMPLER OUTPUT READY XECORE14",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE15", "SAMPLER OUTPUT READY XECORE15",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler5MetricSet::CSampler5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE0", "SAMPLER BUSY XECORE0",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE1", "SAMPLER BUSY XECORE1",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE2", "SAMPLER BUSY XECORE2",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE3", "SAMPLER BUSY XECORE3",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE4", "SAMPLER BUSY XECORE4",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE5", "SAMPLER BUSY XECORE5",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE6", "SAMPLER BUSY XECORE6",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE7", "SAMPLER BUSY XECORE7",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE8", "SAMPLER BUSY XECORE8",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE9", "SAMPLER BUSY XECORE9",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE10", "SAMPLER BUSY XECORE10",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE11", "SAMPLER BUSY XECORE11",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE12", "SAMPLER BUSY XECORE12",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE13", "SAMPLER BUSY XECORE13",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE14", "SAMPLER BUSY XECORE14",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE15", "SAMPLER BUSY XECORE15",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030ee2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0314e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler6MetricSet::CSampler6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE0", "SAMPLER MEMORY LATENCY STALL XECORE0",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE1", "SAMPLER MEMORY LATENCY STALL XECORE1",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE2", "SAMPLER MEMORY LATENCY STALL XECORE2",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE3", "SAMPLER MEMORY LATENCY STALL XECORE3",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE4", "SAMPLER MEMORY LATENCY STALL XECORE4",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE5", "SAMPLER MEMORY LATENCY STALL XECORE5",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE6", "SAMPLER MEMORY LATENCY STALL XECORE6",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE7", "SAMPLER MEMORY LATENCY STALL XECORE7",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04846810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d840d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler7MetricSet::CSampler7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE8", "SAMPLER MEMORY LATENCY STALL XECORE8",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE9", "SAMPLER MEMORY LATENCY STALL XECORE9",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE10", "SAMPLER MEMORY LATENCY STALL XECORE10",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE11", "SAMPLER MEMORY LATENCY STALL XECORE11",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE12", "SAMPLER MEMORY LATENCY STALL XECORE12",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE13", "SAMPLER MEMORY LATENCY STALL XECORE13",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE14", "SAMPLER MEMORY LATENCY STALL XECORE14",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE15", "SAMPLER MEMORY LATENCY STALL XECORE15",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04846810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d840d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler8MetricSet::CSampler8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE0", "SAMPLER INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE1", "SAMPLER INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE2", "SAMPLER INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE3", "SAMPLER INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE4", "SAMPLER INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE5", "SAMPLER INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE6", "SAMPLER INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE7", "SAMPLER INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06824800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f820900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler9MetricSet::CSampler9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE8", "SAMPLER INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE9", "SAMPLER INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE10", "SAMPLER INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE11", "SAMPLER INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE12", "SAMPLER INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE13", "SAMPLER INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE14", "SAMPLER INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE15", "SAMPLER INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06824800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f820900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler10MetricSet::CSampler10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE0", "SAMPLER TEXTURE CACHE ACCESS XECORE0",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE1", "SAMPLER TEXTURE CACHE ACCESS XECORE1",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE2", "SAMPLER TEXTURE CACHE ACCESS XECORE2",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE3", "SAMPLER TEXTURE CACHE ACCESS XECORE3",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE4", "SAMPLER TEXTURE CACHE ACCESS XECORE4",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE5", "SAMPLER TEXTURE CACHE ACCESS XECORE5",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE6", "SAMPLER TEXTURE CACHE ACCESS XECORE6",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE7", "SAMPLER TEXTURE CACHE ACCESS XECORE7",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE8", "SAMPLER TEXTURE CACHE ACCESS XECORE8",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE9", "SAMPLER TEXTURE CACHE ACCESS XECORE9",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE10", "SAMPLER TEXTURE CACHE ACCESS XECORE10",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE11", "SAMPLER TEXTURE CACHE ACCESS XECORE11",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE12", "SAMPLER TEXTURE CACHE ACCESS XECORE12",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE13", "SAMPLER TEXTURE CACHE ACCESS XECORE13",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE14", "SAMPLER TEXTURE CACHE ACCESS XECORE14",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE15", "SAMPLER TEXTURE CACHE ACCESS XECORE15",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030ee2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0314e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler11MetricSet::CSampler11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE0", "SAMPLER TEXTURE CACHE MISS XECORE0",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE1", "SAMPLER TEXTURE CACHE MISS XECORE1",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE2", "SAMPLER TEXTURE CACHE MISS XECORE2",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE3", "SAMPLER TEXTURE CACHE MISS XECORE3",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE4", "SAMPLER TEXTURE CACHE MISS XECORE4",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE5", "SAMPLER TEXTURE CACHE MISS XECORE5",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE6", "SAMPLER TEXTURE CACHE MISS XECORE6",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE7", "SAMPLER TEXTURE CACHE MISS XECORE7",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE8", "SAMPLER TEXTURE CACHE MISS XECORE8",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE9", "SAMPLER TEXTURE CACHE MISS XECORE9",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE10", "SAMPLER TEXTURE CACHE MISS XECORE10",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE11", "SAMPLER TEXTURE CACHE MISS XECORE11",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE12", "SAMPLER TEXTURE CACHE MISS XECORE12",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE13", "SAMPLER TEXTURE CACHE MISS XECORE13",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE14", "SAMPLER TEXTURE CACHE MISS XECORE14",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE15", "SAMPLER TEXTURE CACHE MISS XECORE15",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030ee2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0314e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher1MetricSet::CThreadDispatcher1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE0", "GPGPU THREADGROUP COUNT XECORE0",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE4", "ASYNC GPGPU THREADGROUP COUNT XECORE4",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE8", "ASYNC GPGPU THREAD EXIT COUNT XECORE8",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher2MetricSet::CThreadDispatcher2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE1", "GPGPU THREADGROUP COUNT XECORE1",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE5", "ASYNC GPGPU THREADGROUP COUNT XECORE5",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE9", "ASYNC GPGPU THREAD EXIT COUNT XECORE9",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher3MetricSet::CThreadDispatcher3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE2", "GPGPU THREADGROUP COUNT XECORE2",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE6", "ASYNC GPGPU THREADGROUP COUNT XECORE6",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE10", "ASYNC GPGPU THREAD EXIT COUNT XECORE10",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher4MetricSet::CThreadDispatcher4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE3", "GPGPU THREADGROUP COUNT XECORE3",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE7", "ASYNC GPGPU THREADGROUP COUNT XECORE7",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE11", "ASYNC GPGPU THREAD EXIT COUNT XECORE11",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher5MetricSet::CThreadDispatcher5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE4", "GPGPU THREADGROUP COUNT XECORE4",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE8", "ASYNC GPGPU THREADGROUP COUNT XECORE8",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE12", "ASYNC GPGPU THREAD EXIT COUNT XECORE12",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher6MetricSet::CThreadDispatcher6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE5", "GPGPU THREADGROUP COUNT XECORE5",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE9", "ASYNC GPGPU THREADGROUP COUNT XECORE9",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE13", "ASYNC GPGPU THREAD EXIT COUNT XECORE13",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher7MetricSet::CThreadDispatcher7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE6", "GPGPU THREADGROUP COUNT XECORE6",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE10", "ASYNC GPGPU THREADGROUP COUNT XECORE10",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE14", "ASYNC GPGPU THREAD EXIT COUNT XECORE14",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher8MetricSet::CThreadDispatcher8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE7", "GPGPU THREADGROUP COUNT XECORE7",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE11", "ASYNC GPGPU THREADGROUP COUNT XECORE11",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE15", "ASYNC GPGPU THREAD EXIT COUNT XECORE15",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher9MetricSet::CThreadDispatcher9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE8", "GPGPU THREADGROUP COUNT XECORE8",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE12", "ASYNC GPGPU THREADGROUP COUNT XECORE12",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE0", "ASYNC GPGPU THREAD EXIT COUNT XECORE0",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher10MetricSet::CThreadDispatcher10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE9", "GPGPU THREADGROUP COUNT XECORE9",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE13", "ASYNC GPGPU THREADGROUP COUNT XECORE13",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE1", "ASYNC GPGPU THREAD EXIT COUNT XECORE1",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher11MetricSet::CThreadDispatcher11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE10", "GPGPU THREADGROUP COUNT XECORE10",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE14", "ASYNC GPGPU THREADGROUP COUNT XECORE14",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE2", "ASYNC GPGPU THREAD EXIT COUNT XECORE2",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher12MetricSet::CThreadDispatcher12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE11", "GPGPU THREADGROUP COUNT XECORE11",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE15", "ASYNC GPGPU THREADGROUP COUNT XECORE15",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE3", "ASYNC GPGPU THREAD EXIT COUNT XECORE3",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher13MetricSet::CThreadDispatcher13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE12", "GPGPU THREADGROUP COUNT XECORE12",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE0", "ASYNC GPGPU THREADGROUP COUNT XECORE0",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE4", "ASYNC GPGPU THREAD EXIT COUNT XECORE4",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher14MetricSet::CThreadDispatcher14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE13", "GPGPU THREADGROUP COUNT XECORE13",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE1", "ASYNC GPGPU THREADGROUP COUNT XECORE1",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE5", "ASYNC GPGPU THREAD EXIT COUNT XECORE5",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher15MetricSet::CThreadDispatcher15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE14", "GPGPU THREADGROUP COUNT XECORE14",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE2", "ASYNC GPGPU THREADGROUP COUNT XECORE2",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE6", "ASYNC GPGPU THREAD EXIT COUNT XECORE6",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher16MetricSet::CThreadDispatcher16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE15", "GPGPU THREADGROUP COUNT XECORE15",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE3", "ASYNC GPGPU THREADGROUP COUNT XECORE3",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE7", "ASYNC GPGPU THREAD EXIT COUNT XECORE7",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher17MetricSet::CThreadDispatcher17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE0", "TASK THREADGROUP COUNT XECORE0",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE4", "TASK THREAD EXIT COUNT XECORE4",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE8", "THREADGROUP DISPATCH RESOURCE STALL XECORE8",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031067, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher18MetricSet::CThreadDispatcher18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE1", "TASK THREADGROUP COUNT XECORE1",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE5", "TASK THREAD EXIT COUNT XECORE5",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE9", "THREADGROUP DISPATCH RESOURCE STALL XECORE9",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031067, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher19MetricSet::CThreadDispatcher19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE2", "TASK THREADGROUP COUNT XECORE2",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE6", "TASK THREAD EXIT COUNT XECORE6",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE10", "THREADGROUP DISPATCH RESOURCE STALL XECORE10",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031067, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher20MetricSet::CThreadDispatcher20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE3", "TASK THREADGROUP COUNT XECORE3",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE7", "TASK THREAD EXIT COUNT XECORE7",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE11", "THREADGROUP DISPATCH RESOURCE STALL XECORE11",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031067, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher21MetricSet::CThreadDispatcher21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE4", "TASK THREADGROUP COUNT XECORE4",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE8", "TASK THREAD EXIT COUNT XECORE8",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE12", "THREADGROUP DISPATCH RESOURCE STALL XECORE12",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher22MetricSet::CThreadDispatcher22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE5", "TASK THREADGROUP COUNT XECORE5",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE9", "TASK THREAD EXIT COUNT XECORE9",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE13", "THREADGROUP DISPATCH RESOURCE STALL XECORE13",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher23MetricSet::CThreadDispatcher23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE6", "TASK THREADGROUP COUNT XECORE6",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE10", "TASK THREAD EXIT COUNT XECORE10",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE14", "THREADGROUP DISPATCH RESOURCE STALL XECORE14",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher24MetricSet::CThreadDispatcher24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE7", "TASK THREADGROUP COUNT XECORE7",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE11", "TASK THREAD EXIT COUNT XECORE11",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE15", "THREADGROUP DISPATCH RESOURCE STALL XECORE15",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher25MetricSet::CThreadDispatcher25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE8", "TASK THREADGROUP COUNT XECORE8",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE12", "TASK THREAD EXIT COUNT XECORE12",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE0", "THREADGROUP DISPATCH RESOURCE STALL XECORE0",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031069, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher26MetricSet::CThreadDispatcher26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE9", "TASK THREADGROUP COUNT XECORE9",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE13", "TASK THREAD EXIT COUNT XECORE13",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE1", "THREADGROUP DISPATCH RESOURCE STALL XECORE1",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031069, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher27MetricSet::CThreadDispatcher27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE10", "TASK THREADGROUP COUNT XECORE10",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE14", "TASK THREAD EXIT COUNT XECORE14",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE2", "THREADGROUP DISPATCH RESOURCE STALL XECORE2",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031069, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher28MetricSet::CThreadDispatcher28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE11", "TASK THREADGROUP COUNT XECORE11",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE15", "TASK THREAD EXIT COUNT XECORE15",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE3", "THREADGROUP DISPATCH RESOURCE STALL XECORE3",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031069, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher29MetricSet::CThreadDispatcher29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE12", "TASK THREADGROUP COUNT XECORE12",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE0", "TASK THREAD EXIT COUNT XECORE0",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE4", "THREADGROUP DISPATCH RESOURCE STALL XECORE4",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher30MetricSet::CThreadDispatcher30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE13", "TASK THREADGROUP COUNT XECORE13",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE1", "TASK THREAD EXIT COUNT XECORE1",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE5", "THREADGROUP DISPATCH RESOURCE STALL XECORE5",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher31MetricSet::CThreadDispatcher31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE14", "TASK THREADGROUP COUNT XECORE14",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE2", "TASK THREAD EXIT COUNT XECORE2",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE6", "THREADGROUP DISPATCH RESOURCE STALL XECORE6",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher32MetricSet::CThreadDispatcher32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE15", "TASK THREADGROUP COUNT XECORE15",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE3", "TASK THREAD EXIT COUNT XECORE3",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE7", "THREADGROUP DISPATCH RESOURCE STALL XECORE7",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher33MetricSet::CThreadDispatcher33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE0", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE1", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE2", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE3", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE4", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE5", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE6", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE7", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE8", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE9", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE10", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE11", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE12", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE13", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE14", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE15", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030ee2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0314e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher34MetricSet::CThreadDispatcher34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE0", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE1", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE2", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE3", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE4", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE5", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE6", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE7", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE8", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE9", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE10", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE11", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE12", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE13", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE14", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE15", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030ee2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c0314e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher35MetricSet::CThreadDispatcher35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE0", "THREAD DISPATCH QUEUE0 ACTIVE XECORE0",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE1", "THREAD DISPATCH QUEUE0 ACTIVE XECORE1",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE2", "THREAD DISPATCH QUEUE0 ACTIVE XECORE2",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE3", "THREAD DISPATCH QUEUE0 ACTIVE XECORE3",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE4", "THREAD DISPATCH QUEUE0 ACTIVE XECORE4",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE5", "THREAD DISPATCH QUEUE0 ACTIVE XECORE5",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE6", "THREAD DISPATCH QUEUE0 ACTIVE XECORE6",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE7", "THREAD DISPATCH QUEUE0 ACTIVE XECORE7",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE0", "THREAD DISPATCH STALL XECORE0",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE1", "THREAD DISPATCH STALL XECORE1",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE2", "THREAD DISPATCH STALL XECORE2",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE3", "THREAD DISPATCH STALL XECORE3",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE4", "THREAD DISPATCH STALL XECORE4",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE5", "THREAD DISPATCH STALL XECORE5",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE6", "THREAD DISPATCH STALL XECORE6",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE7", "THREAD DISPATCH STALL XECORE7",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher36MetricSet::CThreadDispatcher36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE8", "THREAD DISPATCH QUEUE0 ACTIVE XECORE8",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE9", "THREAD DISPATCH QUEUE0 ACTIVE XECORE9",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE10", "THREAD DISPATCH QUEUE0 ACTIVE XECORE10",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE11", "THREAD DISPATCH QUEUE0 ACTIVE XECORE11",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE12", "THREAD DISPATCH QUEUE0 ACTIVE XECORE12",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE13", "THREAD DISPATCH QUEUE0 ACTIVE XECORE13",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE14", "THREAD DISPATCH QUEUE0 ACTIVE XECORE14",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE15", "THREAD DISPATCH QUEUE0 ACTIVE XECORE15",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE8", "THREAD DISPATCH STALL XECORE8",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE9", "THREAD DISPATCH STALL XECORE9",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE10", "THREAD DISPATCH STALL XECORE10",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE11", "THREAD DISPATCH STALL XECORE11",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE12", "THREAD DISPATCH STALL XECORE12",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE13", "THREAD DISPATCH STALL XECORE13",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE14", "THREAD DISPATCH STALL XECORE14",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE15", "THREAD DISPATCH STALL XECORE15",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher37MetricSet::CThreadDispatcher37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE0", "THREAD DISPATCH QUEUE1 ACTIVE XECORE0",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE1", "THREAD DISPATCH QUEUE1 ACTIVE XECORE1",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE2", "THREAD DISPATCH QUEUE1 ACTIVE XECORE2",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE3", "THREAD DISPATCH QUEUE1 ACTIVE XECORE3",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE4", "THREAD DISPATCH QUEUE1 ACTIVE XECORE4",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE5", "THREAD DISPATCH QUEUE1 ACTIVE XECORE5",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE6", "THREAD DISPATCH QUEUE1 ACTIVE XECORE6",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE7", "THREAD DISPATCH QUEUE1 ACTIVE XECORE7",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE0", "THREAD DISPATCH INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE1", "THREAD DISPATCH INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE2", "THREAD DISPATCH INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE3", "THREAD DISPATCH INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE4", "THREAD DISPATCH INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE5", "THREAD DISPATCH INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE6", "THREAD DISPATCH INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE7", "THREAD DISPATCH INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810e80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a1003a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10e80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1003a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810e80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1003a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10e80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e1003a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher38MetricSet::CThreadDispatcher38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE8", "THREAD DISPATCH QUEUE1 ACTIVE XECORE8",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE9", "THREAD DISPATCH QUEUE1 ACTIVE XECORE9",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE10", "THREAD DISPATCH QUEUE1 ACTIVE XECORE10",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE11", "THREAD DISPATCH QUEUE1 ACTIVE XECORE11",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE12", "THREAD DISPATCH QUEUE1 ACTIVE XECORE12",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE13", "THREAD DISPATCH QUEUE1 ACTIVE XECORE13",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE14", "THREAD DISPATCH QUEUE1 ACTIVE XECORE14",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE15", "THREAD DISPATCH QUEUE1 ACTIVE XECORE15",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE8", "THREAD DISPATCH INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE9", "THREAD DISPATCH INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE10", "THREAD DISPATCH INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE11", "THREAD DISPATCH INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE12", "THREAD DISPATCH INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE13", "THREAD DISPATCH INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE14", "THREAD DISPATCH INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE15", "THREAD DISPATCH INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810e80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a1003a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10e80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1003a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810e80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1003a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10e80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e1003a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher39MetricSet::CThreadDispatcher39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE0", "THREAD DISPATCH PS ACTIVE XECORE0",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE1", "THREAD DISPATCH PS ACTIVE XECORE1",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE2", "THREAD DISPATCH PS ACTIVE XECORE2",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE3", "THREAD DISPATCH PS ACTIVE XECORE3",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE4", "THREAD DISPATCH PS ACTIVE XECORE4",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE5", "THREAD DISPATCH PS ACTIVE XECORE5",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE6", "THREAD DISPATCH PS ACTIVE XECORE6",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE7", "THREAD DISPATCH PS ACTIVE XECORE7",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher40MetricSet::CThreadDispatcher40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE8", "THREAD DISPATCH PS ACTIVE XECORE8",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE9", "THREAD DISPATCH PS ACTIVE XECORE9",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE10", "THREAD DISPATCH PS ACTIVE XECORE10",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE11", "THREAD DISPATCH PS ACTIVE XECORE11",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE12", "THREAD DISPATCH PS ACTIVE XECORE12",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE13", "THREAD DISPATCH PS ACTIVE XECORE13",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE14", "THREAD DISPATCH PS ACTIVE XECORE14",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE15", "THREAD DISPATCH PS ACTIVE XECORE15",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030e83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030221, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher41MetricSet::CThreadDispatcher41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE0", "GPGPU DISPATCH XECORE0",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE1", "GPGPU DISPATCH XECORE1",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE2", "GPGPU DISPATCH XECORE2",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher42MetricSet::CThreadDispatcher42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE3", "GPGPU DISPATCH XECORE3",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE4", "GPGPU DISPATCH XECORE4",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE5", "GPGPU DISPATCH XECORE5",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x380308e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher43MetricSet::CThreadDispatcher43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE6", "GPGPU DISPATCH XECORE6",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE7", "GPGPU DISPATCH XECORE7",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE8", "GPGPU DISPATCH XECORE8",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010756aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02832aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00847c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02861550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02871550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher44MetricSet::CThreadDispatcher44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE9", "GPGPU DISPATCH XECORE9",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE10", "GPGPU DISPATCH XECORE10",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE11", "GPGPU DISPATCH XECORE11",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207155a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032943, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher45MetricSet::CThreadDispatcher45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE12", "GPGPU DISPATCH XECORE12",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE13", "GPGPU DISPATCH XECORE13",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE14", "GPGPU DISPATCH XECORE14",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01027c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher46MetricSet::CThreadDispatcher46MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher46MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE15", "GPGPU DISPATCH XECORE15",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CURB1MetricSet::CURB1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CURB1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "URB_READ_SLICE0", "URB READ SLICE0",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "URB_WRITE_SLICE0", "URB WRITE SLICE0",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE0", "URB CROSS SLICE READ SLICE0",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0608c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CURB2MetricSet::CURB2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CURB2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "URB_READ_SLICE1", "URB READ SLICE1",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "URB_WRITE_SLICE1", "URB WRITE SLICE1",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE1", "URB CROSS SLICE READ SLICE1",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0708c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CURB3MetricSet::CURB3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CURB3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "URB_READ_SLICE2", "URB READ SLICE2",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "URB_WRITE_SLICE2", "URB WRITE SLICE2",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE2", "URB CROSS SLICE READ SLICE2",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0608c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CURB4MetricSet::CURB4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CURB4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "URB_READ_SLICE3", "URB READ SLICE3",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "URB_WRITE_SLICE3", "URB WRITE SLICE3",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE3", "URB CROSS SLICE READ SLICE3",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0708c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine1MetricSet::CVectorEngine1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE0_XVE0_THREAD0", "XVE STALL ALUWR XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE0_XVE0_THREAD0", "XVE STALL BARRIER XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE0_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE0_XVE0_THREAD0", "XVE STALL OTHER XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE0_XVE0_THREAD0", "XVE STALL SBID XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE0_XVE0_THREAD0", "XVE STALL SENDWR XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE0_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x069000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine2MetricSet::CVectorEngine2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE1_XVE0_THREAD0", "XVE STALL ALUWR XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE1_XVE0_THREAD0", "XVE STALL BARRIER XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE1_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE1_XVE0_THREAD0", "XVE STALL OTHER XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE1_XVE0_THREAD0", "XVE STALL SBID XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE1_XVE0_THREAD0", "XVE STALL SENDWR XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE1_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine3MetricSet::CVectorEngine3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE2_XVE0_THREAD0", "XVE STALL ALUWR XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE2_XVE0_THREAD0", "XVE STALL BARRIER XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE2_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE2_XVE0_THREAD0", "XVE STALL OTHER XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE2_XVE0_THREAD0", "XVE STALL SBID XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE2_XVE0_THREAD0", "XVE STALL SENDWR XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE2_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine4MetricSet::CVectorEngine4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE3_XVE0_THREAD0", "XVE STALL ALUWR XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE3_XVE0_THREAD0", "XVE STALL BARRIER XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE3_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE3_XVE0_THREAD0", "XVE STALL OTHER XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE3_XVE0_THREAD0", "XVE STALL SBID XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE3_XVE0_THREAD0", "XVE STALL SENDWR XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE3_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine5MetricSet::CVectorEngine5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE4_XVE0_THREAD0", "XVE STALL ALUWR XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE4_XVE0_THREAD0", "XVE STALL BARRIER XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE4_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE4_XVE0_THREAD0", "XVE STALL OTHER XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE4_XVE0_THREAD0", "XVE STALL SBID XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE4_XVE0_THREAD0", "XVE STALL SENDWR XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE4_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x079000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine6MetricSet::CVectorEngine6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE5_XVE0_THREAD0", "XVE STALL ALUWR XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE5_XVE0_THREAD0", "XVE STALL BARRIER XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE5_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE5_XVE0_THREAD0", "XVE STALL OTHER XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE5_XVE0_THREAD0", "XVE STALL SBID XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE5_XVE0_THREAD0", "XVE STALL SENDWR XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE5_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine7MetricSet::CVectorEngine7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE6_XVE0_THREAD0", "XVE STALL ALUWR XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE6_XVE0_THREAD0", "XVE STALL BARRIER XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE6_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE6_XVE0_THREAD0", "XVE STALL OTHER XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE6_XVE0_THREAD0", "XVE STALL SBID XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE6_XVE0_THREAD0", "XVE STALL SENDWR XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE6_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine8MetricSet::CVectorEngine8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE7_XVE0_THREAD0", "XVE STALL ALUWR XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE7_XVE0_THREAD0", "XVE STALL BARRIER XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE7_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE7_XVE0_THREAD0", "XVE STALL OTHER XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE7_XVE0_THREAD0", "XVE STALL SBID XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE7_XVE0_THREAD0", "XVE STALL SENDWR XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE7_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine9MetricSet::CVectorEngine9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE8_XVE0_THREAD0", "XVE STALL ALUWR XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE8_XVE0_THREAD0", "XVE STALL BARRIER XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE8_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE8_XVE0_THREAD0", "XVE STALL OTHER XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE8_XVE0_THREAD0", "XVE STALL SBID XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE8_XVE0_THREAD0", "XVE STALL SENDWR XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE8_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x069000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine10MetricSet::CVectorEngine10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE9_XVE0_THREAD0", "XVE STALL ALUWR XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE9_XVE0_THREAD0", "XVE STALL BARRIER XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE9_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE9_XVE0_THREAD0", "XVE STALL OTHER XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE9_XVE0_THREAD0", "XVE STALL SBID XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE9_XVE0_THREAD0", "XVE STALL SENDWR XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE9_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine11MetricSet::CVectorEngine11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE10_XVE0_THREAD0", "XVE STALL ALUWR XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE10_XVE0_THREAD0", "XVE STALL BARRIER XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE10_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE10_XVE0_THREAD0", "XVE STALL OTHER XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE10_XVE0_THREAD0", "XVE STALL SBID XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE10_XVE0_THREAD0", "XVE STALL SENDWR XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE10_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine12MetricSet::CVectorEngine12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE11_XVE0_THREAD0", "XVE STALL ALUWR XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE11_XVE0_THREAD0", "XVE STALL BARRIER XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE11_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE11_XVE0_THREAD0", "XVE STALL OTHER XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE11_XVE0_THREAD0", "XVE STALL SBID XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE11_XVE0_THREAD0", "XVE STALL SENDWR XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE11_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine13MetricSet::CVectorEngine13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE12_XVE0_THREAD0", "XVE STALL ALUWR XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE12_XVE0_THREAD0", "XVE STALL BARRIER XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE12_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE12_XVE0_THREAD0", "XVE STALL OTHER XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE12_XVE0_THREAD0", "XVE STALL SBID XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE12_XVE0_THREAD0", "XVE STALL SENDWR XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE12_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x079000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine14MetricSet::CVectorEngine14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE13_XVE0_THREAD0", "XVE STALL ALUWR XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE13_XVE0_THREAD0", "XVE STALL BARRIER XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE13_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE13_XVE0_THREAD0", "XVE STALL OTHER XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE13_XVE0_THREAD0", "XVE STALL SBID XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE13_XVE0_THREAD0", "XVE STALL SENDWR XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE13_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine15MetricSet::CVectorEngine15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE14_XVE0_THREAD0", "XVE STALL ALUWR XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE14_XVE0_THREAD0", "XVE STALL BARRIER XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE14_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE14_XVE0_THREAD0", "XVE STALL OTHER XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE14_XVE0_THREAD0", "XVE STALL SBID XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE14_XVE0_THREAD0", "XVE STALL SENDWR XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE14_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine16MetricSet::CVectorEngine16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE15_XVE0_THREAD0", "XVE STALL ALUWR XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE15_XVE0_THREAD0", "XVE STALL BARRIER XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE15_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE15_XVE0_THREAD0", "XVE STALL OTHER XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE15_XVE0_THREAD0", "XVE STALL SBID XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE15_XVE0_THREAD0", "XVE STALL SENDWR XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE15_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine17MetricSet::CVectorEngine17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE0", "ICACHE HIT BANK0 XECORE0",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE1", "ICACHE HIT BANK0 XECORE1",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE2", "ICACHE HIT BANK0 XECORE2",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE3", "ICACHE HIT BANK0 XECORE3",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE4", "ICACHE HIT BANK0 XECORE4",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE5", "ICACHE HIT BANK0 XECORE5",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE6", "ICACHE HIT BANK0 XECORE6",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE7", "ICACHE HIT BANK0 XECORE7",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE0", "ICACHE MISS BANK0 XECORE0",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE1", "ICACHE MISS BANK0 XECORE1",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE2", "ICACHE MISS BANK0 XECORE2",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE3", "ICACHE MISS BANK0 XECORE3",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE4", "ICACHE MISS BANK0 XECORE4",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE5", "ICACHE MISS BANK0 XECORE5",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE6", "ICACHE MISS BANK0 XECORE6",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE7", "ICACHE MISS BANK0 XECORE7",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine18MetricSet::CVectorEngine18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE8", "ICACHE HIT BANK0 XECORE8",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE9", "ICACHE HIT BANK0 XECORE9",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE10", "ICACHE HIT BANK0 XECORE10",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE11", "ICACHE HIT BANK0 XECORE11",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE12", "ICACHE HIT BANK0 XECORE12",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE13", "ICACHE HIT BANK0 XECORE13",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE14", "ICACHE HIT BANK0 XECORE14",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE15", "ICACHE HIT BANK0 XECORE15",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE8", "ICACHE MISS BANK0 XECORE8",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE9", "ICACHE MISS BANK0 XECORE9",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE10", "ICACHE MISS BANK0 XECORE10",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE11", "ICACHE MISS BANK0 XECORE11",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE12", "ICACHE MISS BANK0 XECORE12",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE13", "ICACHE MISS BANK0 XECORE13",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE14", "ICACHE MISS BANK0 XECORE14",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE15", "ICACHE MISS BANK0 XECORE15",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine19MetricSet::CVectorEngine19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE0", "ICACHE HIT BANK1 XECORE0",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE1", "ICACHE HIT BANK1 XECORE1",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE2", "ICACHE HIT BANK1 XECORE2",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE3", "ICACHE HIT BANK1 XECORE3",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE4", "ICACHE HIT BANK1 XECORE4",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE5", "ICACHE HIT BANK1 XECORE5",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE6", "ICACHE HIT BANK1 XECORE6",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE7", "ICACHE HIT BANK1 XECORE7",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE0", "ICACHE MISS BANK1 XECORE0",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE1", "ICACHE MISS BANK1 XECORE1",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE2", "ICACHE MISS BANK1 XECORE2",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE3", "ICACHE MISS BANK1 XECORE3",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE4", "ICACHE MISS BANK1 XECORE4",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE5", "ICACHE MISS BANK1 XECORE5",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE6", "ICACHE MISS BANK1 XECORE6",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE7", "ICACHE MISS BANK1 XECORE7",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine20MetricSet::CVectorEngine20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE8", "ICACHE HIT BANK1 XECORE8",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE9", "ICACHE HIT BANK1 XECORE9",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE10", "ICACHE HIT BANK1 XECORE10",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE11", "ICACHE HIT BANK1 XECORE11",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE12", "ICACHE HIT BANK1 XECORE12",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE13", "ICACHE HIT BANK1 XECORE13",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE14", "ICACHE HIT BANK1 XECORE14",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE15", "ICACHE HIT BANK1 XECORE15",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE8", "ICACHE MISS BANK1 XECORE8",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE9", "ICACHE MISS BANK1 XECORE9",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE10", "ICACHE MISS BANK1 XECORE10",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE11", "ICACHE MISS BANK1 XECORE11",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE12", "ICACHE MISS BANK1 XECORE12",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE13", "ICACHE MISS BANK1 XECORE13",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE14", "ICACHE MISS BANK1 XECORE14",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE15", "ICACHE MISS BANK1 XECORE15",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine21MetricSet::CVectorEngine21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE0", "ICACHE HIT BANK2 XECORE0",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE1", "ICACHE HIT BANK2 XECORE1",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE2", "ICACHE HIT BANK2 XECORE2",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE3", "ICACHE HIT BANK2 XECORE3",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE4", "ICACHE HIT BANK2 XECORE4",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE5", "ICACHE HIT BANK2 XECORE5",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE6", "ICACHE HIT BANK2 XECORE6",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE7", "ICACHE HIT BANK2 XECORE7",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE0", "ICACHE MISS BANK2 XECORE0",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE1", "ICACHE MISS BANK2 XECORE1",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE2", "ICACHE MISS BANK2 XECORE2",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE3", "ICACHE MISS BANK2 XECORE3",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE4", "ICACHE MISS BANK2 XECORE4",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE5", "ICACHE MISS BANK2 XECORE5",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE6", "ICACHE MISS BANK2 XECORE6",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE7", "ICACHE MISS BANK2 XECORE7",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine22MetricSet::CVectorEngine22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE8", "ICACHE HIT BANK2 XECORE8",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE9", "ICACHE HIT BANK2 XECORE9",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE10", "ICACHE HIT BANK2 XECORE10",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE11", "ICACHE HIT BANK2 XECORE11",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE12", "ICACHE HIT BANK2 XECORE12",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE13", "ICACHE HIT BANK2 XECORE13",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE14", "ICACHE HIT BANK2 XECORE14",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE15", "ICACHE HIT BANK2 XECORE15",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE8", "ICACHE MISS BANK2 XECORE8",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE9", "ICACHE MISS BANK2 XECORE9",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE10", "ICACHE MISS BANK2 XECORE10",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE11", "ICACHE MISS BANK2 XECORE11",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE12", "ICACHE MISS BANK2 XECORE12",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE13", "ICACHE MISS BANK2 XECORE13",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE14", "ICACHE MISS BANK2 XECORE14",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE15", "ICACHE MISS BANK2 XECORE15",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine23MetricSet::CVectorEngine23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE0", "ICACHE HIT BANK3 XECORE0",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE1", "ICACHE HIT BANK3 XECORE1",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE2", "ICACHE HIT BANK3 XECORE2",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE3", "ICACHE HIT BANK3 XECORE3",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE4", "ICACHE HIT BANK3 XECORE4",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE5", "ICACHE HIT BANK3 XECORE5",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE6", "ICACHE HIT BANK3 XECORE6",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE7", "ICACHE HIT BANK3 XECORE7",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE0", "ICACHE MISS BANK3 XECORE0",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE1", "ICACHE MISS BANK3 XECORE1",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE2", "ICACHE MISS BANK3 XECORE2",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE3", "ICACHE MISS BANK3 XECORE3",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE4", "ICACHE MISS BANK3 XECORE4",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE5", "ICACHE MISS BANK3 XECORE5",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE6", "ICACHE MISS BANK3 XECORE6",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE7", "ICACHE MISS BANK3 XECORE7",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine24MetricSet::CVectorEngine24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE8", "ICACHE HIT BANK3 XECORE8",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE9", "ICACHE HIT BANK3 XECORE9",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE10", "ICACHE HIT BANK3 XECORE10",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE11", "ICACHE HIT BANK3 XECORE11",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE12", "ICACHE HIT BANK3 XECORE12",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE13", "ICACHE HIT BANK3 XECORE13",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE14", "ICACHE HIT BANK3 XECORE14",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE15", "ICACHE HIT BANK3 XECORE15",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE8", "ICACHE MISS BANK3 XECORE8",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE9", "ICACHE MISS BANK3 XECORE9",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE10", "ICACHE MISS BANK3 XECORE10",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE11", "ICACHE MISS BANK3 XECORE11",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE12", "ICACHE MISS BANK3 XECORE12",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE13", "ICACHE MISS BANK3 XECORE13",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE14", "ICACHE MISS BANK3 XECORE14",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE15", "ICACHE MISS BANK3 XECORE15",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3603200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030427, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine25MetricSet::CVectorEngine25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE0_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE0 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE1_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE1 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE2_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE2 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE3_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE3 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine26MetricSet::CVectorEngine26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE4_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE4 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE5_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE5 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE6_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE6 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE7_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE7 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine27MetricSet::CVectorEngine27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE8_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE8 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE9_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE9 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE10_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE10 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE11_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE11 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine28MetricSet::CVectorEngine28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE12_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE12 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE13_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE13 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE14_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE14 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE15_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE15 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine29MetricSet::CVectorEngine29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE0_XVE0", "XVE INST ISSUED ALL XECORE0 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE1_XVE0", "XVE INST ISSUED ALL XECORE1 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE2_XVE0", "XVE INST ISSUED ALL XECORE2 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00904eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02900166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04b01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06b0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine30MetricSet::CVectorEngine30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE3_XVE0", "XVE INST ISSUED ALL XECORE3 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE4_XVE0", "XVE INST ISSUED ALL XECORE4 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE5_XVE0", "XVE INST ISSUED ALL XECORE5 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03905000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05901a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0790000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01900000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01815400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09b02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x380308e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine31MetricSet::CVectorEngine31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE6_XVE0", "XVE INST ISSUED ALL XECORE6 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE7_XVE0", "XVE INST ISSUED ALL XECORE7 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE8_XVE0", "XVE INST ISSUED ALL XECORE8 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010756aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06905680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08902cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00900000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02811550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02832aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00847c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02861550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02871550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine32MetricSet::CVectorEngine32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE9_XVE0", "XVE INST ISSUED ALL XECORE9 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE10_XVE0", "XVE INST ISSUED ALL XECORE10 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE11_XVE0", "XVE INST ISSUED ALL XECORE11 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207155a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32032943, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3403294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine33MetricSet::CVectorEngine33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE12_XVE0", "XVE INST ISSUED ALL XECORE12 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE13_XVE0", "XVE INST ISSUED ALL XECORE13 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE14_XVE0", "XVE INST ISSUED ALL XECORE14 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01904eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03900166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05b01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01027c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3a030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine34MetricSet::CVectorEngine34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE15_XVE0", "XVE INST ISSUED ALL XECORE15 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x36030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x52030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine35MetricSet::CVectorEngine35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL", "XVE INST EXECUTED ALU0 ALL",
                          "Number of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL", "XVE INST EXECUTED ALU1 ALL",
                          "Number of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL", "XVE INST EXECUTED XMX ALL",
                          "Number of execution slots taken by instructions executed in XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL", "XVE INST EXECUTED SEND ALL",
                          "Number of instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_CONTROL_ALL", "XVE INST EXECUTED CONTROL ALL",
                          "Number of instructions executed on Jump Pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_ALU1_ACTIVE", "XVE PIPE ALU0 AND ALU1 ACTIVE",
                          "Percentage of time in which ALU0 and ALU1 pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_XMX_ACTIVE", "XVE PIPE ALU0 AND XMX ACTIVE",
                          "Percentage of time in which ALU0 and XMX pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL_UTILIZATION", "XVE INST EXECUTED ALU0 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL_UTILIZATION", "XVE INST EXECUTED ALU1 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL_UTILIZATION", "XVE INST EXECUTED XMX ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed in XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL_UTILIZATION", "XVE INST EXECUTED SEND ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_CONTROL_ALL_UTILIZATION", "XVE INST EXECUTED CONTROL ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on Jump Pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE_CYCLES", "XVE ACTIVE CYCLES",
                          "Number of cycles at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_ACTIVE" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES", "XVE STALL CYCLES",
                          "Number of cycles any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_CYCLES_ALL", "XVE THREADS OCCUPANCY CYCLES ALL",
                          "Number of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "8 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount $VectorEngineThreadsCount UMUL UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_ALU1_ACTIVE_CYCLES", "XVE PIPE ALU0 AND ALU1 ACTIVE CYCLES",
                          "Number of cycles in ALU0 and ALU1 pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_PIPE_ALU0_AND_ALU1_ACTIVE" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_XMX_ACTIVE_CYCLES", "XVE PIPE ALU0 AND XMX ACTIVE CYCLES",
                          "Number of cycles ALU0 and XMX pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_PIPE_ALU0_AND_XMX_ACTIVE" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00009001, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x02001002, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x0000a003, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine36MetricSet::CVectorEngine36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_VS", "XVE INST EXECUTED ALU0 VS",
                          "Number of execution slots taken by instructions executed by Vertex Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_HS", "XVE INST EXECUTED ALU0 HS",
                          "Number of execution slots taken by instructions executed by Hull Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_DS", "XVE INST EXECUTED ALU0 DS",
                          "Number of execution slots taken by instructions executed by Domain Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_PS", "XVE INST EXECUTED ALU0 PS",
                          "Number of execution slots taken by instructions executed by Pixel Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_CS", "XVE INST EXECUTED ALU0 CS",
                          "Number of execution slots taken by instructions executed by Compute Shader (from Render Engine) on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ASYNC_CS", "XVE INST EXECUTED ALU0 ASYNC CS",
                          "Number of execution slots taken by instructions executed by Async Compute Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_VS", "XVE INST EXECUTED ALU1 VS",
                          "Number of execution slots taken by instructions executed by Vertex Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_HS", "XVE INST EXECUTED ALU1 HS",
                          "Number of execution slots taken by instructions executed by Hull Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_DS", "XVE INST EXECUTED ALU1 DS",
                          "Number of execution slots taken by instructions executed by Domain Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_PS", "XVE INST EXECUTED ALU1 PS",
                          "Number of execution slots taken by instructions executed by Pixel Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_CS", "XVE INST EXECUTED ALU1 CS",
                          "Number of execution slots taken by instructions executed by Compute Shader (from Render Engine) on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ASYNC_CS", "XVE INST EXECUTED ALU1 ASYNC CS",
                          "Number of execution slots taken by instructions executed by Async Compute Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_VS_UTILIZATION", "XVE INST EXECUTED ALU0 VS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Vertex Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_HS_UTILIZATION", "XVE INST EXECUTED ALU0 HS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Hull Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_DS_UTILIZATION", "XVE INST EXECUTED ALU0 DS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Domain Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_PS_UTILIZATION", "XVE INST EXECUTED ALU0 PS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Pixel Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_CS_UTILIZATION", "XVE INST EXECUTED ALU0 CS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Compute Shader (from Render Engine) on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ASYNC_CS_UTILIZATION", "XVE INST EXECUTED ALU0 ASYNC CS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Async Compute Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_VS_UTILIZATION", "XVE INST EXECUTED ALU1 VS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Vertex Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_HS_UTILIZATION", "XVE INST EXECUTED ALU1 HS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Hull Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_DS_UTILIZATION", "XVE INST EXECUTED ALU1 DS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Domain Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_PS_UTILIZATION", "XVE INST EXECUTED ALU1 PS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Pixel Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_CS_UTILIZATION", "XVE INST EXECUTED ALU1 CS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Compute Shader (from Render Engine) on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ASYNC_CS_UTILIZATION", "XVE INST EXECUTED ALU1 ASYNC CS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Async Compute Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 26 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00020010, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00050030, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00090060, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x00021011, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00051031, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe55c, 0x00091061, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine37MetricSet::CVectorEngine37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_AHS_UTILIZATION", "XVE INST EXECUTED ALU0 RT AHS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Any Hit Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_AHS_UTILIZATION", "XVE INST EXECUTED ALU1 RT AHS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Any Hit Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_AHS_UTILIZATION", "XVE INST EXECUTED SEND RT AHS UTILIZATION",
                          "Percentage of time taken by instructions executed by BTD Any Hit Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_CHS_UTILIZATION", "XVE INST EXECUTED ALU0 RT CHS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Closest Hit Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_CHS_UTILIZATION", "XVE INST EXECUTED ALU1 RT CHS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Closest Hit Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_CHS_UTILIZATION", "XVE INST EXECUTED SEND RT CHS UTILIZATION",
                          "Percentage of time taken by instructions executed by BTD Closest Hit Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_MS_UTILIZATION", "XVE INST EXECUTED ALU0 RT MS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Miss Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_MS_UTILIZATION", "XVE INST EXECUTED ALU1 RT MS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Miss Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_MS_UTILIZATION", "XVE INST EXECUTED SEND RT MS UTILIZATION",
                          "Percentage of time taken by instructions executed by BTD Miss Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_AHS", "XVE INST EXECUTED ALU0 RT AHS",
                          "Number of execution slots taken by instructions executed by BTD Any Hit Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU0_RT_AHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_AHS", "XVE INST EXECUTED ALU1 RT AHS",
                          "Number of execution slots taken by instructions executed by BTD Any Hit Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU1_RT_AHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_AHS", "XVE INST EXECUTED SEND RT AHS",
                          "Number of instructions executed by BTD Any Hit Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_SEND_RT_AHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_CHS", "XVE INST EXECUTED ALU0 RT CHS",
                          "Number of execution slots taken by instructions executed by BTD Closest Hit Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU0_RT_CHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_CHS", "XVE INST EXECUTED ALU1 RT CHS",
                          "Number of execution slots taken by instructions executed by BTD Closest Hit Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU1_RT_CHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_CHS", "XVE INST EXECUTED SEND RT CHS",
                          "Number of instructions executed by BTD Closest Hit Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_SEND_RT_CHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_MS", "XVE INST EXECUTED ALU0 RT MS",
                          "Number of execution slots taken by instructions executed by BTD Miss Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU0_RT_MS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_MS", "XVE INST EXECUTED ALU1 RT MS",
                          "Number of execution slots taken by instructions executed by BTD Miss Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU1_RT_MS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_MS", "XVE INST EXECUTED SEND RT MS",
                          "Number of instructions executed by BTD Miss Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_SEND_RT_MS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x000c10c0, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x000d00c2, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x000d20d1, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x000e10e0, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x000000e2, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine38MetricSet::CVectorEngine38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_ASYNC_CS", "XVE STALL ASYNC CS",
                          "Percentage of time in which there are Async Compute Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CS", "XVE STALL CS",
                          "Percentage of time in which there are Compute Shader (from Render Engine) threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_DS", "XVE STALL DS",
                          "Percentage of time in which there are Domain Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_HS", "XVE STALL HS",
                          "Percentage of time in which there are Hull Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_MS", "XVE STALL MS",
                          "Percentage of time in which there are Mesh Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_PS", "XVE STALL PS",
                          "Percentage of time in which there are Pixel Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_TS", "XVE STALL TS",
                          "Percentage of time in which there are Task Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_VS", "XVE STALL VS",
                          "Percentage of time in which there are Vertex Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_RT", "XVE STALL RT",
                          "Percentage of time in which there are Ray Tracing Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES", "XVE STALL CYCLES",
                          "Number of cycles any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_ASYNC_CS", "XVE STALL CYCLES ASYNC CS",
                          "Number of cycles there are Async Compute Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_ASYNC_CS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_CS", "XVE STALL CYCLES CS",
                          "Number of cycles there are Compute Shader (from Render Engine) threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_CS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_DS", "XVE STALL CYCLES DS",
                          "Number of cycles there are Domain Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_DS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_HS", "XVE STALL CYCLES HS",
                          "Number of cycles there are Hull Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_HS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_MS", "XVE STALL CYCLES MS",
                          "Number of cycles there are Mesh Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_MS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_PS", "XVE STALL CYCLES PS",
                          "Number of cycles there are Pixel Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_PS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_TS", "XVE STALL CYCLES TS",
                          "Number of cycles there are Task Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_TS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_VS", "XVE STALL CYCLES VS",
                          "Number of cycles there are Vertex Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_VS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_RT", "XVE STALL CYCLES RT",
                          "Number of cycles there are Ray Tracing Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_RT" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00095005, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00035065, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x000b5025, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x000a5055, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x000c5015, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine39MetricSet::CVectorEngine39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL", "XVE INST EXECUTED ALU0 ALL",
                          "Number of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP16", "XVE INST EXECUTED FP16",
                          "Number of execution slots taken by FP16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP32", "XVE INST EXECUTED FP32",
                          "Number of execution slots taken by FP32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP64", "XVE INST EXECUTED FP64",
                          "The number of FLT64 instructions executed in ALU0 INT64 pipeline.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL", "XVE INST EXECUTED ALU1 ALL",
                          "Number of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT16", "XVE INST EXECUTED INT16",
                          "Number of execution slots taken by INT16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT32", "XVE INST EXECUTED INT32",
                          "Number of execution slots taken by INT32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_MATH", "XVE INST EXECUTED MATH",
                          "Number of execution slots taken by extended math instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL", "XVE INST EXECUTED XMX ALL",
                          "Number of execution slots taken by instructions executed in XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_BF16", "XVE INST EXECUTED XMX BF16",
                          "Number of execution slots taken by BF16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_FP16", "XVE INST EXECUTED XMX FP16",
                          "Number of execution slots taken by FP16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT8", "XVE INST EXECUTED XMX INT8",
                          "Number of execution slots taken by INT8 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL_UTILIZATION", "XVE INST EXECUTED ALU0 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP16_UTILIZATION", "XVE INST EXECUTED FP16 UTILIZATION",
                          "Percentage of execution slots taken by FP16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP32_UTILIZATION", "XVE INST EXECUTED FP32 UTILIZATION",
                          "Percentage of execution slots taken by FP32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP64_UTILIZATION", "XVE INST EXECUTED FP64 UTILIZATION",
                          "The percentage of time in which FLT64 instruction were processed actively on FPU INT64 pipeline.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL_UTILIZATION", "XVE INST EXECUTED ALU1 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT16_UTILIZATION", "XVE INST EXECUTED INT16 UTILIZATION",
                          "Percentage of execution slots taken by INT16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT32_UTILIZATION", "XVE INST EXECUTED INT32 UTILIZATION",
                          "Percentage of execution slots taken by INT32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_MATH_UTILIZATION", "XVE INST EXECUTED MATH UTILIZATION",
                          "Percentage of execution slots taken by extended math instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL_UTILIZATION", "XVE INST EXECUTED XMX ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed in XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_BF16_UTILIZATION", "XVE INST EXECUTED XMX BF16 UTILIZATION",
                          "Percentage of execution slots taken by BF16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_FP16_UTILIZATION", "XVE INST EXECUTED XMX FP16 UTILIZATION",
                          "Percentage of execution slots taken by FP16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT8_UTILIZATION", "XVE INST EXECUTED XMX INT8 UTILIZATION",
                          "Percentage of execution slots taken by INT8 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 26 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00006000, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x0000b007, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x0000c001, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x0200000d, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x0000e009, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe55c, 0x0100f002, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine40MetricSet::CVectorEngine40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL", "XVE INST EXECUTED SEND ALL",
                          "Number of instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ASYNC_CS", "XVE INST EXECUTED SEND ASYNC CS",
                          "Number of instructions executed by Async Compute Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_CS", "XVE INST EXECUTED SEND CS",
                          "Number of instructions executed by Compute Shader (from Render Engine) threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_DS", "XVE INST EXECUTED SEND DS",
                          "Number of instructions executed by Domain Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_GS", "XVE INST EXECUTED SEND GS",
                          "Number of instructions executed by Geometry Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_HS", "XVE INST EXECUTED SEND HS",
                          "Number of instructions executed by Hull Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_MS", "XVE INST EXECUTED SEND MS",
                          "Number of instructions executed by Mesh Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_PS", "XVE INST EXECUTED SEND PS",
                          "Number of instructions executed by Pixel Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_TS", "XVE INST EXECUTED SEND TS",
                          "Number of instructions executed by Task Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_VS", "XVE INST EXECUTED SEND VS",
                          "Number of instructions executed by Vertex Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL_UTILIZATION", "XVE INST EXECUTED SEND ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ASYNC_CS_UTILIZATION", "XVE INST EXECUTED SEND ASYNC CS UTILIZATION",
                          "Percentage of time taken by instructions executed by Async Compute Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_CS_UTILIZATION", "XVE INST EXECUTED SEND CS UTILIZATION",
                          "Percentage of time taken by instructions executed by Compute Shader (from Render Engine) threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_DS_UTILIZATION", "XVE INST EXECUTED SEND DS UTILIZATION",
                          "Percentage of time taken by instructions executed by Domain Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_GS_UTILIZATION", "XVE INST EXECUTED SEND GS UTILIZATION",
                          "Percentage of time taken by instructions executed by Geometry Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_HS_UTILIZATION", "XVE INST EXECUTED SEND HS UTILIZATION",
                          "Percentage of time taken by instructions executed by Hull Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_MS_UTILIZATION", "XVE INST EXECUTED SEND MS UTILIZATION",
                          "Percentage of time taken by instructions executed by Mesh Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_PS_UTILIZATION", "XVE INST EXECUTED SEND PS UTILIZATION",
                          "Percentage of time taken by instructions executed by Pixel Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_TS_UTILIZATION", "XVE INST EXECUTED SEND TS UTILIZATION",
                          "Percentage of time taken by instructions executed by Task Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_VS_UTILIZATION", "XVE INST EXECUTED SEND VS UTILIZATION",
                          "Percentage of time taken by instructions executed by Vertex Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00092002, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00032062, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00022042, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x000520b2, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x000120a2, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine41MetricSet::CVectorEngine41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_GS", "XVE STALL GS",
                          "Percentage of time in which there are Geometry Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_GS", "XVE INST EXECUTED ALU0 GS",
                          "Number of execution slots taken by instructions executed by Geometry Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_GS", "XVE INST EXECUTED ALU1 GS",
                          "Number of execution slots taken by instructions executed by Geometry Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_GS", "XVE STALL CYCLES GS",
                          "Number of cycles there are Geometry Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_GS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_MS", "XVE INST EXECUTED ALU0 MS",
                          "Number of execution slots taken by instructions executed by Mesh Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_TS", "XVE INST EXECUTED ALU0 TS",
                          "Number of execution slots taken by instructions executed by Task Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_MS", "XVE INST EXECUTED ALU1 MS",
                          "Number of execution slots taken by instructions executed by Mesh Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_TS", "XVE INST EXECUTED ALU1 TS",
                          "Number of execution slots taken by instructions executed by Task Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_GS_UTILIZATION", "XVE INST EXECUTED ALU0 GS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Geometry Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_GS_UTILIZATION", "XVE INST EXECUTED ALU1 GS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Geometry Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_MS_UTILIZATION", "XVE INST EXECUTED ALU0 MS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Mesh Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_TS_UTILIZATION", "XVE INST EXECUTED ALU0 TS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Task Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_MS_UTILIZATION", "XVE INST EXECUTED ALU1 MS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Mesh Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_TS_UTILIZATION", "XVE INST EXECUTED ALU1 TS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Task Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00040045, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x000b0041, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x000b10a0, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x000000a1, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
} // namespace MetricsDiscoveryInternal::MetricSets_ACM_GT2_OA

#endif
